@@ -42,7 +42,7 @@
 
 */
 
-/* (C) Gabriel "Salsaman" Finch, 2005 - 2012 */
+/* (C) Gabriel "Salsaman" Finch, 2005 - 2016 */
 
 #ifndef __WEED_COMPAT_H__
 #define __WEED_COMPAT_H__
@@ -595,6 +595,8 @@ const AVCodecTag codec_bmp_tags[] = {
 #include <weed/weed-palettes.h>
 #endif
 
+#ifdef FF_API_PIX_FMT
+
 int avi_pix_fmt_to_weed_palette(enum PixelFormat pix_fmt, int *clamped) {
   // clamped may be set to NULL if you are not interested in the value
 
@@ -642,53 +644,139 @@ int avi_pix_fmt_to_weed_palette(enum PixelFormat pix_fmt, int *clamped) {
 }
 
 
-
-
 enum PixelFormat weed_palette_to_avi_pix_fmt(int pal, int *clamped) {
-
   switch (pal) {
   case WEED_PALETTE_RGB24:
-      return PIX_FMT_RGB24;
-  case WEED_PALETTE_BGR24:
-    return PIX_FMT_BGR24;
-  case WEED_PALETTE_RGBA32:
-    return PIX_FMT_RGBA;
-  case WEED_PALETTE_BGRA32:
-    return PIX_FMT_BGRA;
-  case WEED_PALETTE_ARGB32:
-    return PIX_FMT_ARGB;
-  case WEED_PALETTE_YUV444P:
-    if (clamped && *clamped==WEED_YUV_CLAMPING_UNCLAMPED)
-      return PIX_FMT_YUVJ444P;
-    return PIX_FMT_YUV444P;
-  case WEED_PALETTE_YUV422P:
-    if (clamped && *clamped==WEED_YUV_CLAMPING_UNCLAMPED)
-      return PIX_FMT_YUVJ422P;
-    return PIX_FMT_YUV422P;
-  case WEED_PALETTE_YUV420P:
-    if (clamped && *clamped==WEED_YUV_CLAMPING_UNCLAMPED)
-      return PIX_FMT_YUVJ420P;
-    return PIX_FMT_YUV420P;
-  case WEED_PALETTE_YUYV:
-    return PIX_FMT_YUYV422;
-  case WEED_PALETTE_UYVY:
-    return PIX_FMT_UYVY422;
-  case WEED_PALETTE_YUV411:
-    return PIX_FMT_UYYVYY411;
+        return PIX_FMT_RGB24;
+    case WEED_PALETTE_BGR24:
+      return PIX_FMT_BGR24;
+    case WEED_PALETTE_RGBA32:
+      return PIX_FMT_RGBA;
+    case WEED_PALETTE_BGRA32:
+      return PIX_FMT_BGRA;
+    case WEED_PALETTE_ARGB32:
+      return PIX_FMT_ARGB;
+    case WEED_PALETTE_YUV444P:
+      if (clamped && *clamped==WEED_YUV_CLAMPING_UNCLAMPED)
+        return PIX_FMT_YUVJ444P;
+      return PIX_FMT_YUV444P;
+    case WEED_PALETTE_YUV422P:
+      if (clamped && *clamped==WEED_YUV_CLAMPING_UNCLAMPED)
+        return PIX_FMT_YUVJ422P;
+      return PIX_FMT_YUV422P;
+    case WEED_PALETTE_YUV420P:
+      if (clamped && *clamped==WEED_YUV_CLAMPING_UNCLAMPED)
+        return PIX_FMT_YUVJ420P;
+      return PIX_FMT_YUV420P;
+    case WEED_PALETTE_YUYV:
+      return PIX_FMT_YUYV422;
+    case WEED_PALETTE_UYVY:
+      return PIX_FMT_UYVY422;
+    case WEED_PALETTE_YUV411:
+      return PIX_FMT_UYYVYY411;
 
-  case WEED_PALETTE_A8:
-    return PIX_FMT_GRAY8;
-  case WEED_PALETTE_A1:
-    return PIX_FMT_MONOBLACK;
+    case WEED_PALETTE_A8:
+      return PIX_FMT_GRAY8;
+    case WEED_PALETTE_A1:
+      return PIX_FMT_MONOBLACK;
 
-  default:
-    return PIX_FMT_NONE;
+    default:
+      return PIX_FMT_NONE;
+    }
   }
 
-  return PIX_FMT_NONE;
+#else
 
+int avi_pix_fmt_to_weed_palette(enum AVPixelFormat pix_fmt, int *clamped) {
+  // clamped may be set to NULL if you are not interested in the value
+
+  switch (pix_fmt) {
+  case AV_PIX_FMT_RGB24:
+    return WEED_PALETTE_RGB24;
+  case AV_PIX_FMT_BGR24:
+    return WEED_PALETTE_BGR24;
+  case AV_PIX_FMT_RGBA:
+    return WEED_PALETTE_RGBA32;
+  case AV_PIX_FMT_BGRA:
+    return WEED_PALETTE_BGRA32;
+  case AV_PIX_FMT_ARGB:
+    return WEED_PALETTE_ARGB32;
+  case AV_PIX_FMT_YUV444P:
+    return WEED_PALETTE_YUV444P;
+  case AV_PIX_FMT_YUV422P:
+    return WEED_PALETTE_YUV422P;
+  case AV_PIX_FMT_YUV420P:
+    return WEED_PALETTE_YUV420P;
+  case AV_PIX_FMT_YUYV422:
+    return WEED_PALETTE_YUYV;
+  case AV_PIX_FMT_UYVY422:
+    return WEED_PALETTE_UYVY;
+  case AV_PIX_FMT_UYYVYY411:
+    return WEED_PALETTE_YUV411;
+  case AV_PIX_FMT_GRAY8:
+    return WEED_PALETTE_A8;
+  case AV_PIX_FMT_MONOWHITE:
+  case AV_PIX_FMT_MONOBLACK:
+    return WEED_PALETTE_A1;
+  case AV_PIX_FMT_YUVJ422P:
+    if (clamped) *clamped=WEED_YUV_CLAMPING_UNCLAMPED;
+    return WEED_PALETTE_YUV422P;
+  case AV_PIX_FMT_YUVJ444P:
+    if (clamped) *clamped=WEED_YUV_CLAMPING_UNCLAMPED;
+    return WEED_PALETTE_YUV444P;
+  case AV_PIX_FMT_YUVJ420P:
+    if (clamped) *clamped=WEED_YUV_CLAMPING_UNCLAMPED;
+    return WEED_PALETTE_YUV420P;
+
+  default:
+    return WEED_PALETTE_END;
+  }
 }
 
+
+enum AVPixelFormat weed_palette_to_avi_pix_fmt(int pal, int *clamped) {
+  switch (pal) {
+  case WEED_PALETTE_RGB24:
+        return AV_PIX_FMT_RGB24;
+    case WEED_PALETTE_BGR24:
+      return AV_PIX_FMT_BGR24;
+    case WEED_PALETTE_RGBA32:
+      return AV_PIX_FMT_RGBA;
+    case WEED_PALETTE_BGRA32:
+      return AV_PIX_FMT_BGRA;
+    case WEED_PALETTE_ARGB32:
+      return AV_PIX_FMT_ARGB;
+    case WEED_PALETTE_YUV444P:
+      if (clamped && *clamped==WEED_YUV_CLAMPING_UNCLAMPED)
+        return AV_PIX_FMT_YUVJ444P;
+      return AV_PIX_FMT_YUV444P;
+    case WEED_PALETTE_YUV422P:
+      if (clamped && *clamped==WEED_YUV_CLAMPING_UNCLAMPED)
+        return AV_PIX_FMT_YUVJ422P;
+      return AV_PIX_FMT_YUV422P;
+    case WEED_PALETTE_YUV420P:
+      if (clamped && *clamped==WEED_YUV_CLAMPING_UNCLAMPED)
+        return AV_PIX_FMT_YUVJ420P;
+      return AV_PIX_FMT_YUV420P;
+    case WEED_PALETTE_YUYV:
+      return AV_PIX_FMT_YUYV422;
+    case WEED_PALETTE_UYVY:
+      return AV_PIX_FMT_UYVY422;
+    case WEED_PALETTE_YUV411:
+      return AV_PIX_FMT_UYYVYY411;
+
+    case WEED_PALETTE_A8:
+      return AV_PIX_FMT_GRAY8;
+    case WEED_PALETTE_A1:
+      return AV_PIX_FMT_MONOBLACK;
+
+    default:
+      return AV_PIX_FMT_NONE;
+    }
+  }
+
+#endif
+
 #endif // HAVE_AVUTIL
 #endif // HAVE_AVCODEC
 
