@@ -42,7 +42,7 @@
 
 */
 
-/* (C) Gabriel "Salsaman" Finch, 2005 - 2010 */
+/* (C) Gabriel "Salsaman" Finch, 2005 - 2013 */
 
 #ifndef __WEED_PLUGIN_H__
 #define __WEED_PLUGIN_H__
@@ -56,19 +56,40 @@ extern "C"
 {
 #endif /* __cplusplus */
 
-weed_leaf_set_f weed_leaf_set;
-weed_leaf_get_f weed_leaf_get;
-weed_plant_new_f weed_plant_new;
-weed_plant_list_leaves_f weed_plant_list_leaves;
-weed_leaf_num_elements_f weed_leaf_num_elements;
-weed_leaf_element_size_f weed_leaf_element_size;
-weed_leaf_seed_type_f weed_leaf_seed_type;
-weed_leaf_get_flags_f weed_leaf_get_flags;
+#ifndef __WEED_INTERNAL__
+/// functions defined as static so as not to overwrite the host versions
 
-weed_malloc_f weed_malloc;
-weed_free_f weed_free;
-weed_memcpy_f weed_memcpy;
-weed_memset_f weed_memset;
+static weed_leaf_set_f weed_leaf_set;
+static weed_leaf_get_f weed_leaf_get;
+static weed_plant_new_f weed_plant_new;
+static weed_plant_list_leaves_f weed_plant_list_leaves;
+static weed_leaf_num_elements_f weed_leaf_num_elements;
+static weed_leaf_element_size_f weed_leaf_element_size;
+static weed_leaf_seed_type_f weed_leaf_seed_type;
+static weed_leaf_get_flags_f weed_leaf_get_flags;
+
+static weed_malloc_f weed_malloc;
+static weed_free_f weed_free;
+static weed_memcpy_f weed_memcpy;
+static weed_memset_f weed_memset;
+
+#else
+/// weed libs which #include this should use the plugin's version
+
+extern weed_leaf_set_f weed_leaf_set;
+extern weed_leaf_get_f weed_leaf_get;
+extern weed_plant_new_f weed_plant_new;
+extern weed_plant_list_leaves_f weed_plant_list_leaves;
+extern weed_leaf_num_elements_f weed_leaf_num_elements;
+extern weed_leaf_element_size_f weed_leaf_element_size;
+extern weed_leaf_seed_type_f weed_leaf_seed_type;
+extern weed_leaf_get_flags_f weed_leaf_get_flags;
+
+extern weed_malloc_f weed_malloc;
+extern weed_free_f weed_free;
+extern weed_memcpy_f weed_memcpy;
+extern weed_memset_f weed_memset;
+#endif
 
 #ifdef __cplusplus
 }
