@@ -47,26 +47,31 @@
 
 #include <string.h>
 
+#ifdef HAVE_SYSTEM_WEED
+#include <weed/weed.h>
+#else
 #include "weed.h"
+#endif
 
- extern weed_leaf_set_f weed_leaf_set;
- extern weed_leaf_get_f weed_leaf_get;
- extern weed_plant_new_f weed_plant_new;
- extern weed_plant_list_leaves_f weed_plant_list_leaves;
- extern weed_leaf_num_elements_f weed_leaf_num_elements;
- extern weed_leaf_element_size_f weed_leaf_element_size;
- extern weed_leaf_seed_type_f weed_leaf_seed_type;
- extern weed_leaf_get_flags_f weed_leaf_get_flags;
- extern weed_malloc_f weed_malloc;
- extern weed_free_f weed_free;
- extern weed_memcpy_f weed_memcpy;
- extern weed_memset_f weed_memset;
+
+extern weed_leaf_set_f weed_leaf_set;
+extern weed_leaf_get_f weed_leaf_get;
+extern weed_plant_new_f weed_plant_new;
+extern weed_plant_list_leaves_f weed_plant_list_leaves;
+extern weed_leaf_num_elements_f weed_leaf_num_elements;
+extern weed_leaf_element_size_f weed_leaf_element_size;
+extern weed_leaf_seed_type_f weed_leaf_seed_type;
+extern weed_leaf_get_flags_f weed_leaf_get_flags;
+extern weed_malloc_f weed_malloc;
+extern weed_free_f weed_free;
+extern weed_memcpy_f weed_memcpy;
+extern weed_memset_f weed_memset;
 
 
 
 /////////////////////////////////////////////////////////////////
 
-int weed_plant_has_leaf (weed_plant_t *plant, const char *key) {
+int weed_plant_has_leaf(weed_plant_t *plant, const char *key) {
   if (weed_leaf_get(plant,key,0,NULL)==WEED_ERROR_NOSUCH_LEAF) return WEED_FALSE;
   return WEED_TRUE;
 }
@@ -74,92 +79,91 @@ int weed_plant_has_leaf (weed_plant_t *plant, const char *key) {
 /////////////////////////////////////////////////////////////////
 // leaf setters
 
-int weed_set_int_value (weed_plant_t *plant, const char *key, int value) {
+int weed_set_int_value(weed_plant_t *plant, const char *key, int value) {
   // returns a WEED_ERROR
-  return weed_leaf_set (plant,key,WEED_SEED_INT,1,&value);
+  return weed_leaf_set(plant,key,WEED_SEED_INT,1,&value);
 }
 
-int weed_set_double_value (weed_plant_t *plant, const char *key, double value) {
+int weed_set_double_value(weed_plant_t *plant, const char *key, double value) {
   // returns a WEED_ERROR
-  return weed_leaf_set (plant,key,WEED_SEED_DOUBLE,1,&value);
+  return weed_leaf_set(plant,key,WEED_SEED_DOUBLE,1,&value);
 }
 
-int weed_set_boolean_value (weed_plant_t *plant, const char *key, int value) {
+int weed_set_boolean_value(weed_plant_t *plant, const char *key, int value) {
   // returns a WEED_ERROR
-  return weed_leaf_set (plant,key,WEED_SEED_BOOLEAN,1,&value);
+  return weed_leaf_set(plant,key,WEED_SEED_BOOLEAN,1,&value);
 }
 
-int weed_set_int64_value (weed_plant_t *plant, const char *key, int64_t value) {
+int weed_set_int64_value(weed_plant_t *plant, const char *key, int64_t value) {
   // returns a WEED_ERROR
-  return weed_leaf_set (plant,key,WEED_SEED_INT64,1,&value);
+  return weed_leaf_set(plant,key,WEED_SEED_INT64,1,&value);
 }
 
-int weed_set_string_value (weed_plant_t *plant, const char *key, const char *value) {
+int weed_set_string_value(weed_plant_t *plant, const char *key, const char *value) {
   // returns a WEED_ERROR
-  return weed_leaf_set (plant,key,WEED_SEED_STRING,1,&value);
+  return weed_leaf_set(plant,key,WEED_SEED_STRING,1,&value);
 }
 
-int weed_set_plantptr_value (weed_plant_t *plant, const char *key, weed_plant_t *value) {
+int weed_set_plantptr_value(weed_plant_t *plant, const char *key, weed_plant_t *value) {
   // returns a WEED_ERROR
-  return weed_leaf_set (plant,key,WEED_SEED_PLANTPTR,1,&value);
+  return weed_leaf_set(plant,key,WEED_SEED_PLANTPTR,1,&value);
 }
 
-int weed_set_voidptr_value (weed_plant_t *plant, const char *key, void *value) {
+int weed_set_voidptr_value(weed_plant_t *plant, const char *key, void *value) {
   // returns a WEED_ERROR
-  return weed_leaf_set (plant,key,WEED_SEED_VOIDPTR,1,&value);
+  return weed_leaf_set(plant,key,WEED_SEED_VOIDPTR,1,&value);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////
 // general leaf getter
 
-inline int weed_get_value (weed_plant_t *plant, const char *key, void *value) {
+inline int weed_get_value(weed_plant_t *plant, const char *key, void *value) {
   // returns a WEED_ERROR
   return weed_leaf_get(plant, key, 0, value);
 }
 
 ////////////////////////////////////////////////////////////
 
-int weed_get_int_value (weed_plant_t *plant, const char *key, int *error) {
+int weed_get_int_value(weed_plant_t *plant, const char *key, int *error) {
   int retval=0;
   if (weed_plant_has_leaf(plant,key)&&weed_leaf_seed_type(plant,key)!=WEED_SEED_INT) {
     *error=WEED_ERROR_WRONG_SEED_TYPE;
     return retval;
-  }
-  else *error=weed_get_value (plant,key,&retval);
+  } else *error=weed_get_value(plant,key,&retval);
   return retval;
 }
 
-double weed_get_double_value (weed_plant_t *plant, const char *key, int *error) {
+double weed_get_double_value(weed_plant_t *plant, const char *key, int *error) {
   double retval=0.;
   if (weed_plant_has_leaf(plant,key)&&weed_leaf_seed_type(plant,key)!=WEED_SEED_DOUBLE) {
     *error=WEED_ERROR_WRONG_SEED_TYPE;
     return retval;
   }
-  *error=weed_get_value (plant,key,&retval);
+  *error=weed_get_value(plant,key,&retval);
   return retval;
 }
 
-int weed_get_boolean_value (weed_plant_t *plant, const char *key, int *error) {
+int weed_get_boolean_value(weed_plant_t *plant, const char *key, int *error) {
   int retval=0;
   if (weed_plant_has_leaf(plant,key)&&weed_leaf_seed_type(plant,key)!=WEED_SEED_BOOLEAN) {
     *error=WEED_ERROR_WRONG_SEED_TYPE;
     return retval;
   }
-  *error=weed_get_value (plant,key,&retval);
+  *error=weed_get_value(plant,key,&retval);
   return retval;
 }
 
-int64_t weed_get_int64_value (weed_plant_t *plant, const char *key, int *error) {
+int64_t weed_get_int64_value(weed_plant_t *plant, const char *key, int *error) {
   int64_t retval=0;
   if (weed_plant_has_leaf(plant,key)&&weed_leaf_seed_type(plant,key)!=WEED_SEED_INT64) {
     *error=WEED_ERROR_WRONG_SEED_TYPE;
     return retval;
   }
-  *error=weed_get_value (plant,key,&retval);
+  *error=weed_get_value(plant,key,&retval);
   return retval;
 }
 
-char *weed_get_string_value (weed_plant_t *plant, const char *key, int *error) {
+char *weed_get_string_value(weed_plant_t *plant, const char *key, int *error) {
   size_t size;
   char *retval=NULL;
   if (weed_plant_has_leaf(plant,key)&&weed_leaf_seed_type(plant,key)!=WEED_SEED_STRING) {
@@ -170,38 +174,38 @@ char *weed_get_string_value (weed_plant_t *plant, const char *key, int *error) {
     *error=WEED_ERROR_MEMORY_ALLOCATION;
     return NULL;
   }
-  if ((*error=weed_get_value (plant,key,&retval))!=WEED_NO_ERROR) {
-    weed_free (retval);
+  if ((*error=weed_get_value(plant,key,&retval))!=WEED_NO_ERROR) {
+    weed_free(retval);
     return NULL;
   }
   weed_memset(retval+size,0,1);
   return retval;
 }
 
-void *weed_get_voidptr_value (weed_plant_t *plant, const char *key, int *error) {
+void *weed_get_voidptr_value(weed_plant_t *plant, const char *key, int *error) {
   void *retval=NULL;
   if (weed_plant_has_leaf(plant,key)&&weed_leaf_seed_type(plant,key)!=WEED_SEED_VOIDPTR) {
     *error=WEED_ERROR_WRONG_SEED_TYPE;
     return retval;
   }
-  *error=weed_get_value (plant,key,&retval);
+  *error=weed_get_value(plant,key,&retval);
   return retval;
 }
 
-weed_plant_t *weed_get_plantptr_value (weed_plant_t *plant, const char *key, int *error) {
+weed_plant_t *weed_get_plantptr_value(weed_plant_t *plant, const char *key, int *error) {
   weed_plant_t *retval=NULL;
   if (weed_plant_has_leaf(plant,key)&&weed_leaf_seed_type(plant,key)!=WEED_SEED_PLANTPTR) {
     *error=WEED_ERROR_WRONG_SEED_TYPE;
     return retval;
   }
-  *error=weed_get_value (plant,key,&retval);
+  *error=weed_get_value(plant,key,&retval);
   return retval;
 }
 
 
 ////////////////////////////////////////////////////////////
 
-int *weed_get_int_array (weed_plant_t *plant, const char *key, int *error) {
+int *weed_get_int_array(weed_plant_t *plant, const char *key, int *error) {
   int i;
   int num_elems;
   int *retval;
@@ -211,23 +215,23 @@ int *weed_get_int_array (weed_plant_t *plant, const char *key, int *error) {
     return NULL;
   }
 
-  if ((num_elems=weed_leaf_num_elements (plant,key))==0) return NULL;
+  if ((num_elems=weed_leaf_num_elements(plant,key))==0) return NULL;
 
   if ((retval=(int *)weed_malloc(num_elems*4))==NULL) {
     *error=WEED_ERROR_MEMORY_ALLOCATION;
     return NULL;
   }
 
-  for (i=0;i<num_elems;i++) {
+  for (i=0; i<num_elems; i++) {
     if ((*error=weed_leaf_get(plant, key, i, &retval[i]))!=WEED_NO_ERROR) {
-      weed_free (retval);
+      weed_free(retval);
       return NULL;
     }
   }
   return retval;
 }
 
-double *weed_get_double_array (weed_plant_t *plant, const char *key, int *error) {
+double *weed_get_double_array(weed_plant_t *plant, const char *key, int *error) {
   int i;
   int num_elems;
   double *retval;
@@ -236,23 +240,23 @@ double *weed_get_double_array (weed_plant_t *plant, const char *key, int *error)
     *error=WEED_ERROR_WRONG_SEED_TYPE;
     return NULL;
   }
-  if ((num_elems=weed_leaf_num_elements (plant,key))==0) return NULL;
+  if ((num_elems=weed_leaf_num_elements(plant,key))==0) return NULL;
 
   if ((retval=(double *)weed_malloc(num_elems*sizeof(double)))==NULL) {
     *error=WEED_ERROR_MEMORY_ALLOCATION;
     return NULL;
   }
 
-  for (i=0;i<num_elems;i++) {
+  for (i=0; i<num_elems; i++) {
     if ((*error=weed_leaf_get(plant, key, i, &retval[i]))!=WEED_NO_ERROR) {
-      weed_free (retval);
+      weed_free(retval);
       return NULL;
     }
   }
   return retval;
 }
 
-int *weed_get_boolean_array (weed_plant_t *plant, const char *key, int *error) {
+int *weed_get_boolean_array(weed_plant_t *plant, const char *key, int *error) {
   int i;
   int num_elems;
   int *retval;
@@ -262,23 +266,23 @@ int *weed_get_boolean_array (weed_plant_t *plant, const char *key, int *error) {
     return NULL;
   }
 
-  if ((num_elems=weed_leaf_num_elements (plant,key))==0) return NULL;
+  if ((num_elems=weed_leaf_num_elements(plant,key))==0) return NULL;
 
   if ((retval=(int *)weed_malloc(num_elems*4))==NULL) {
     *error=WEED_ERROR_MEMORY_ALLOCATION;
     return NULL;
   }
 
-  for (i=0;i<num_elems;i++) {
+  for (i=0; i<num_elems; i++) {
     if ((*error=weed_leaf_get(plant, key, i, &retval[i]))!=WEED_NO_ERROR) {
-      weed_free (retval);
+      weed_free(retval);
       return NULL;
     }
   }
   return retval;
 }
 
-int64_t *weed_get_int64_array (weed_plant_t *plant, const char *key, int *error) {
+int64_t *weed_get_int64_array(weed_plant_t *plant, const char *key, int *error) {
   int i;
   int num_elems;
   int64_t *retval;
@@ -288,23 +292,23 @@ int64_t *weed_get_int64_array (weed_plant_t *plant, const char *key, int *error)
     return NULL;
   }
 
-  if ((num_elems=weed_leaf_num_elements (plant,key))==0) return NULL;
+  if ((num_elems=weed_leaf_num_elements(plant,key))==0) return NULL;
 
   if ((retval=(int64_t *)weed_malloc(num_elems*8))==NULL) {
     *error=WEED_ERROR_MEMORY_ALLOCATION;
     return NULL;
   }
 
-  for (i=0;i<num_elems;i++) {
+  for (i=0; i<num_elems; i++) {
     if ((*error=weed_leaf_get(plant, key, i, &retval[i]))!=WEED_NO_ERROR) {
-      weed_free (retval);
+      weed_free(retval);
       return NULL;
     }
   }
   return retval;
 }
 
-char **weed_get_string_array (weed_plant_t *plant, const char *key, int *error) {
+char **weed_get_string_array(weed_plant_t *plant, const char *key, int *error) {
   int i;
   int num_elems;
   char **retval;
@@ -315,23 +319,23 @@ char **weed_get_string_array (weed_plant_t *plant, const char *key, int *error)
     return NULL;
   }
 
-  if ((num_elems=weed_leaf_num_elements (plant,key))==0) return NULL;
+  if ((num_elems=weed_leaf_num_elements(plant,key))==0) return NULL;
 
   if ((retval=(char **)weed_malloc(num_elems*sizeof(char *)))==NULL) {
     *error=WEED_ERROR_MEMORY_ALLOCATION;
     return NULL;
   }
 
-  for (i=0;i<num_elems;i++) {
+  for (i=0; i<num_elems; i++) {
     if ((retval[i]=(char *)weed_malloc((size=weed_leaf_element_size(plant,key,i))+1))==NULL) {
-      for (--i;i>=0;i--) weed_free(retval[i]);
+      for (--i; i>=0; i--) weed_free(retval[i]);
       *error=WEED_ERROR_MEMORY_ALLOCATION;
-      weed_free (retval);
+      weed_free(retval);
       return NULL;
     }
     if ((*error=weed_leaf_get(plant, key, i, &retval[i]))!=WEED_NO_ERROR) {
-      for (--i;i>=0;i--) weed_free(retval[i]);
-      weed_free (retval);
+      for (--i; i>=0; i--) weed_free(retval[i]);
+      weed_free(retval);
       return NULL;
     }
     weed_memset(retval[i]+size,0,1);
@@ -339,7 +343,7 @@ char **weed_get_string_array (weed_plant_t *plant, const char *key, int *error)
   return retval;
 }
 
-void **weed_get_voidptr_array (weed_plant_t *plant, const char *key, int *error) {
+void **weed_get_voidptr_array(weed_plant_t *plant, const char *key, int *error) {
   int i;
   int num_elems;
   void **retval;
@@ -349,23 +353,23 @@ void **weed_get_voidptr_array (weed_plant_t *plant, const char *key, int *error)
     return NULL;
   }
 
-  if ((num_elems=weed_leaf_num_elements (plant,key))==0) return NULL;
+  if ((num_elems=weed_leaf_num_elements(plant,key))==0) return NULL;
 
   if ((retval=(void **)weed_malloc(num_elems*sizeof(void *)))==NULL) {
     *error=WEED_ERROR_MEMORY_ALLOCATION;
     return NULL;
   }
 
-  for (i=0;i<num_elems;i++) {
+  for (i=0; i<num_elems; i++) {
     if ((*error=weed_leaf_get(plant, key, i, &retval[i]))!=WEED_NO_ERROR) {
-      weed_free (retval);
+      weed_free(retval);
       return NULL;
     }
   }
   return retval;
 }
 
-weed_plant_t **weed_get_plantptr_array (weed_plant_t *plant, const char *key, int *error) {
+weed_plant_t **weed_get_plantptr_array(weed_plant_t *plant, const char *key, int *error) {
   int i;
   int num_elems;
   weed_plant_t **retval;
@@ -375,16 +379,16 @@ weed_plant_t **weed_get_plantptr_array (weed_plant_t *plant, const char *key, in
     return NULL;
   }
 
-  if ((num_elems=weed_leaf_num_elements (plant,key))==0) return NULL;
+  if ((num_elems=weed_leaf_num_elements(plant,key))==0) return NULL;
 
   if ((retval=(weed_plant_t **)weed_malloc(num_elems*sizeof(weed_plant_t *)))==NULL) {
     *error=WEED_ERROR_MEMORY_ALLOCATION;
     return NULL;
   }
 
-  for (i=0;i<num_elems;i++) {
+  for (i=0; i<num_elems; i++) {
     if ((*error=weed_leaf_get(plant, key, i, &retval[i]))!=WEED_NO_ERROR) {
-      weed_free (retval);
+      weed_free(retval);
       return NULL;
     }
   }
@@ -393,39 +397,39 @@ weed_plant_t **weed_get_plantptr_array (weed_plant_t *plant, const char *key, in
 
 /////////////////////////////////////////////////////
 
-int weed_set_int_array (weed_plant_t *plant, const char *key, int num_elems, int *values) {
-  return weed_leaf_set (plant,key,WEED_SEED_INT,num_elems,values);
+int weed_set_int_array(weed_plant_t *plant, const char *key, int num_elems, int *values) {
+  return weed_leaf_set(plant,key,WEED_SEED_INT,num_elems,values);
 }
 
-int weed_set_double_array (weed_plant_t *plant, const char *key, int num_elems, double *values) {
-  return weed_leaf_set (plant,key,WEED_SEED_DOUBLE,num_elems,values);
+int weed_set_double_array(weed_plant_t *plant, const char *key, int num_elems, double *values) {
+  return weed_leaf_set(plant,key,WEED_SEED_DOUBLE,num_elems,values);
 }
 
-int weed_set_boolean_array (weed_plant_t *plant, const char *key, int num_elems, int *values) {
-  return weed_leaf_set (plant,key,WEED_SEED_BOOLEAN,num_elems,values);
+int weed_set_boolean_array(weed_plant_t *plant, const char *key, int num_elems, int *values) {
+  return weed_leaf_set(plant,key,WEED_SEED_BOOLEAN,num_elems,values);
 }
 
-int weed_set_int64_array (weed_plant_t *plant, const char *key, int num_elems, int64_t *values) {
-  return weed_leaf_set (plant,key,WEED_SEED_INT64,num_elems,values);
+int weed_set_int64_array(weed_plant_t *plant, const char *key, int num_elems, int64_t *values) {
+  return weed_leaf_set(plant,key,WEED_SEED_INT64,num_elems,values);
 }
 
-int weed_set_string_array (weed_plant_t *plant, const char *key, int num_elems, char **values) {
-  return weed_leaf_set (plant,key,WEED_SEED_STRING,num_elems,values);
+int weed_set_string_array(weed_plant_t *plant, const char *key, int num_elems, char **values) {
+  return weed_leaf_set(plant,key,WEED_SEED_STRING,num_elems,values);
 }
 
-int weed_set_voidptr_array (weed_plant_t *plant, const char *key, int num_elems, void **values) {
-  return weed_leaf_set (plant,key,WEED_SEED_VOIDPTR,num_elems,values);
+int weed_set_voidptr_array(weed_plant_t *plant, const char *key, int num_elems, void **values) {
+  return weed_leaf_set(plant,key,WEED_SEED_VOIDPTR,num_elems,values);
 }
 
-int weed_set_plantptr_array (weed_plant_t *plant, const char *key, int num_elems, weed_plant_t **values) {
-  return weed_leaf_set (plant,key,WEED_SEED_PLANTPTR,num_elems,values);
+int weed_set_plantptr_array(weed_plant_t *plant, const char *key, int num_elems, weed_plant_t **values) {
+  return weed_leaf_set(plant,key,WEED_SEED_PLANTPTR,num_elems,values);
 }
 
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 
-int weed_leaf_copy (weed_plant_t *dst, const char *keyt, weed_plant_t *src, const char *keyf) {
+int weed_leaf_copy(weed_plant_t *dst, const char *keyt, weed_plant_t *src, const char *keyf) {
   int num,seed_type,i,error;
   int *datai;
   double *datad;
@@ -475,8 +479,8 @@ int weed_leaf_copy (weed_plant_t *dst, const char *keyt, weed_plant_t *src, cons
     case WEED_SEED_STRING:
       datac=weed_get_string_array(src,keyf,&error);
       error=weed_set_string_array(dst,keyt,num,datac);
-      for (i=0;i<num;i++) {
-	weed_free(datac[i]);
+      for (i=0; i<num; i++) {
+        weed_free(datac[i]);
       }
       weed_free(datac);
       break;
@@ -486,14 +490,14 @@ int weed_leaf_copy (weed_plant_t *dst, const char *keyt, weed_plant_t *src, cons
 }
 
 
-weed_plant_t *weed_plant_copy (weed_plant_t *src) {
+weed_plant_t *weed_plant_copy(weed_plant_t *src) {
   int i=0,error;
   char **proplist=weed_plant_list_leaves(src);
   char *prop;
   weed_plant_t *plant=weed_plant_new(weed_get_int_value(src,"type",&error));
   if (plant==NULL) return NULL;
 
-  for (prop=proplist[0];(prop=proplist[i])!=NULL&&error==WEED_NO_ERROR;i++) {
+  for (prop=proplist[0]; (prop=proplist[i])!=NULL&&error==WEED_NO_ERROR; i++) {
     if (strcmp(prop,"type")) error=weed_leaf_copy(plant,prop,src,prop);
     weed_free(prop);
   }
@@ -508,7 +512,7 @@ weed_plant_t *weed_plant_copy (weed_plant_t *src) {
 }
 
 
-int weed_get_plant_type (weed_plant_t *plant) {
+int weed_get_plant_type(weed_plant_t *plant) {
   int error;
   return weed_get_int_value(plant,"type",&error);
 }
