@@ -606,7 +606,7 @@ static void detach_stream(lives_clip_data_t *cdata) {
   if (priv->idxc!=NULL) idxc_release(cdata);
   priv->idxc=NULL;
 
-  if (priv->picture!=NULL) av_frame_free(&priv->picture);
+  if (priv->picture!=NULL) av_frame_unref(&priv->picture);
 
   priv->ctx=NULL;
   priv->codec=NULL;
@@ -1272,38 +1272,10 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
     }
   }
 
-#ifndef IS_MINGW
   if (cdata->fps==0.||cdata->fps==1000.) {
-    // use mplayer to get fps if we can...it seems to have some magical way
-    char cmd[1024];
-    char tmpfname[32];
-    int ofd;
-
-    sprintf(tmpfname,"/tmp/mkvdec=XXXXXX");
-    ofd=mkstemp(tmpfname);
-    if (ofd!=-1) {
-      int res;
-      snprintf(cmd,1024,"LANGUAGE=en LANG=en mplayer \"%s\" -identify -frames 0 2>/dev/null | grep ID_VIDEO_FPS > %s",cdata->URI,tmpfname);
-      res=system(cmd);
-
-      if (res) {
-        snprintf(cmd,1024,"LANGUAGE=en LANG=en mplayer2 \"%s\" -identify -frames 0 2>/dev/null | grep ID_VIDEO_FPS > %s",cdata->URI,tmpfname);
-        res=system(cmd);
-      }
-
-      if (!res) {
-        char buffer[1024];
-        ssize_t bytes=read(ofd,buffer,1024);
-        memset(buffer+bytes,0,1);
-        if (!(strncmp(buffer,"ID_VIDEO_FPS=",13))) {
-          cdata->fps=strtod(buffer+13,NULL);
-        }
-      }
-      close(ofd);
-      unlink(tmpfname);
-    }
+    int res = get_fps(cdata->URI);
+    if (res >= 0) cdata->fps = res;
   }
-#endif
 
   if (cdata->fps==0.&&ctx->time_base.num==0) {
     // not sure about this
@@ -1482,7 +1454,7 @@ static lives_clip_data_t *flv_clone(lives_clip_data_t *cdata) {
 
   }
 
-  if (dpriv->picture!=NULL) av_frame_free(&dpriv->picture);
+  if (dpriv->picture!=NULL) av_frame_unref(&dpriv->picture);
   dpriv->picture=NULL;
 
   dpriv->last_frame=-1;
@@ -1564,7 +1536,7 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
   cdata->asigned=TRUE;
   cdata->ainterleaf=TRUE;
 
-  if (priv->picture!=NULL) av_frame_free(&priv->picture);
+  if (priv->picture!=NULL) av_frame_unref(&priv->picture);
   priv->picture=NULL;
 
   if (cdata->width!=cdata->frame_width||cdata->height!=cdata->frame_height)
