@@ -205,11 +205,12 @@ static int get_texture_type(int tnum) {
   return textures[tnum].type;
 }
 
-
+/*
 static int get_texture_typesize(int tnum) {
   tnum=get_real_tnum(tnum,TRUE);
   return textures[tnum].type;
 }
+*/
 
 ///////////////////////////////////////////////
 
@@ -219,6 +220,8 @@ const char *module_check_init(void) {
     return error;
   }
 
+  XInitThreads();
+  
   pbo_available=FALSE;
 
   if (GL_ARB_pixel_buffer_object) {
@@ -241,6 +244,9 @@ const char *module_check_init(void) {
   glClearColor( 0.0, 0.0, 0.0, 0.0 );
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
+  texID=(GLuint *)malloc(nbuf * sizeof(GLuint));
+  glGenTextures(nbuf, texID);
+
   mypalette=WEED_PALETTE_END;
 
   zsubtitles=NULL;
@@ -600,13 +606,13 @@ static void render_to_gpumem_inner(int tnum, int width, int height, int type, in
 
 
 
-
+/*
 static void render_to_gpumem(int tnum, uint8_t *texturebuf) {
   render_to_gpumem_inner(get_real_tnum(tnum,TRUE),get_texture_width(tnum),get_texture_height(tnum),
 			 get_texture_type(tnum),get_size_for_type(get_texture_type(tnum)),texturebuf);
 }
 
-
+*/
 
 
 boolean init_screen (int width, int height, boolean fullscreen, uint64_t window_id, int argc, char **argv) {
@@ -644,10 +650,6 @@ boolean init_screen (int width, int height, boolean fullscreen, uint64_t window_
 	    fsover=atoi(argv[4]);
 	  }}}}}
 
-  texID=(GLuint *)malloc(nbuf * sizeof(GLuint));
-
-  glGenTextures(nbuf, texID);
-
   textures=(_texture *)malloc(nbuf*sizeof(_texture));
 
   for (i=0;i<nbuf;i++) {
@@ -742,6 +744,7 @@ static boolean init_screen_inner (int width, int height, boolean fullscreen, uin
 
   swa.event_mask = StructureNotifyMask | ButtonPressMask | KeyPressMask | KeyReleaseMask;
 
+  
   if (window_id) {
     XVisualInfo *xvis;
     XVisualInfo xvtmpl;
@@ -910,6 +913,12 @@ static boolean init_screen_inner (int width, int height, boolean fullscreen, uin
   else
     is_direct=FALSE;
 
+  /*
+  XMapWindow(dpy, xWin);
+  XSync(dpy, xWin);
+  XSetInputFocus(dpy, xWin, RevertToNone, CurrentTime);
+  XSelectInput(dpy, xWin, KeyPressMask | KeyReleaseMask);
+  */
   return TRUE;
 }
 
@@ -944,7 +953,7 @@ static void set_priorities(void) {
 
 }
 
-
+/*
 static void resize_buffer(uint8_t *out, int owidth, int oheight, uint8_t *in, int iwidth, int iheight, int type) {
   int xi,xj;
   int typesize=get_size_for_type(type);
@@ -970,7 +979,7 @@ static void resize_buffer(uint8_t *out, int owidth, int oheight, uint8_t *in, in
     
   }
 }
-
+*/
 
 
 static boolean Upload(int width, int height) {
@@ -1953,7 +1962,6 @@ static boolean Upload(int width, int height) {
  
       for (int i=0; i<NOF_PARTS2; i++) {
 
-	int pos;
 	if ((parts[i].start_time==NOT_CREATED) || (ticks>=parts[i].end_time)) {
 	  parts[i].start_time=ticks;
 	  parts[i].x=(rand() % 2000)/1000.0-1.0;
@@ -2198,12 +2206,8 @@ void exit_screen (int16_t mouse_x, int16_t mouse_y) {
 
   if (use_pbo) glDeleteBuffers(1, &video_pbo);
 
-  if (ntextures>0) glDeleteTextures(ntextures,texID);
-
   free(textures);
 
-  free(texID);
-
   if (!is_ext) {
     XUnmapWindow (dpy, xWin);
     XDestroyWindow (dpy, xWin);
@@ -2223,36 +2227,8 @@ void exit_screen (int16_t mouse_x, int16_t mouse_y) {
 
 
 void module_unload(void) {
+  if (ntextures>0) glDeleteTextures(ntextures,texID);
+  free(texID);
   if (zsubtitles!=NULL) weed_free(zsubtitles);
 }
 
-
-
-
-boolean send_keycodes (keyfunc host_key_fn) {
-  // poll for keyboard events, pass them back to the caller
-  // return FALSE on error
-  uint16_t mod_mask;
-  XEvent xEvent;
-  KeySym keySymbol;
-
-  if (host_key_fn==NULL || dpy == NULL) return FALSE;
-
-  if ((volatile Display *)dpy!=NULL) {
-    pthread_mutex_lock(&dpy_mutex);
-    if ((volatile Display *)dpy!=NULL) {
-      while (XCheckWindowEvent( dpy, xWin, KeyPressMask | KeyReleaseMask, &xEvent ) ) {
-	int keysyms_per_keycode_return;
-	keySymbol = (KeySym)XGetKeyboardMapping(dpy,xEvent.xkey.keycode,0,&keysyms_per_keycode_return);
-	mod_mask=xEvent.xkey.state;
-	host_key_fn (xEvent.type == KeyPress, keySymbol, mod_mask);
-      }
-    }
-    pthread_mutex_unlock(&dpy_mutex);
-  }
-
-  return TRUE;
-
-}
-
-
