@@ -34,9 +34,9 @@ static int vdevfd;
 
 static char *vdevname;
 
-static char *tmpdir;
+static char *workdir;
 
-static char xfile[4096];
+static char xfile[PATH_MAX];
 
 static int aforms[2];
 
@@ -133,12 +133,12 @@ static char **get_vloopback2_devices(void) {
 const char *module_check_init(void) {
   char **vdevs = get_vloopback2_devices();
 
-  char buf[16384];
+  FILE *fp;
+  char buffer[PATH_MAX];
+  const char *dummy;
 
-  int i=0;
-  int dummyvar,rfd;
 
-  size_t ret;
+  register int i=0;
 
   if (vdevs[0]==NULL) {
     free(vdevs);
@@ -149,15 +149,11 @@ const char *module_check_init(void) {
   free(vdevs);
 
   // get tempdir
-  dummyvar=system("smogrify get_tempdir oggstream");
-  rfd=open("/tmp/.smogrify.oggstream",O_RDONLY);
-  ret=read(rfd,(void *)buf,16383);
-  memset(buf+ret,0,1);
-
-  tmpdir=strdup(buf);
-
-  dummyvar=dummyvar; // keep compiler happy
-
+  fp=popen("smogrify get_workdir","r");
+  dummy=fgets(buffer,PATH_MAX,fp);
+  pclose(fp);
+  workdir=strdup(buffer);
+  dummy=dummy;
 
   return NULL;
 }
@@ -189,8 +185,10 @@ const char rfx[32768];
 const char *get_init_rfx(void) {
   char **vdevs = get_vloopback2_devices();
   char devstr[30000];
+
   size_t slen=0;
-  int i=0;
+
+  register int i=0;
 
   if (vdevs[0]==NULL) {
     free(vdevs);
@@ -206,7 +204,7 @@ const char *get_init_rfx(void) {
   }
   free(vdevs);
 
-  snprintf((char *)rfx,32768,"%s%s%s",
+  snprintf((char *)rfx,32768,"%s%s%s%s%s",
            "<define>\\n\
 |1.7\\n\
 </define>\\n\
@@ -217,7 +215,7 @@ const char *get_init_rfx(void) {
 vdevname|Video _device|string_list|0|",
            devstr,
            "\\n\
-afname|Send _audio to|string|/tmp/audio.wav|1024|\\n\
+afname|Send _audio to|string|",workdir,"/audio.wav|1024|\\n\
 </params> \\n\
 <param_window> \\n\
 </param_window> \\n\
@@ -274,7 +272,7 @@ boolean set_yuv_palette_clamping(int clamping_type) {
 }
 
 static void make_path(const char *fname, int pid, const char *ext) {
-  snprintf(xfile,4096,"%s/%s-%d.%s",tmpdir,fname,pid,ext);
+  snprintf(xfile,PATH_MAX,"%s/%s-%d.%s",workdir,fname,pid,ext);
 }
 
 
@@ -288,7 +286,7 @@ boolean init_screen(int width, int height, boolean fullscreen, uint64_t window_i
 
   int dummyvar;
 
-  char cmd[8192];
+  char cmd[PATH_MAX*2];
 
   char *audfile=NULL;
 
@@ -374,7 +372,7 @@ boolean init_screen(int width, int height, boolean fullscreen, uint64_t window_i
     }
 
     if (audio) {
-      snprintf(cmd,8192,"/bin/cat %s > \"%s\" &",xfile,audfile);
+      snprintf(cmd,PATH_MAX*2,"/bin/cat %s > \"%s\" &",xfile,audfile);
       dummyvar=system(cmd);
     }
     dummyvar=dummyvar; // keep compiler happy
