@@ -1,6 +1,6 @@
 // audio.c
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2014
+// (c) G. Finch 2005 - 2016
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -26,8 +26,6 @@
 #include "effects.h"
 #include "support.h"
 
-// keep first 16 audio_in filesysten handles open - multitrack only
-#define NSTOREDFDS 16
 static char *storedfnames[NSTOREDFDS];
 static int storedfds[NSTOREDFDS];
 static boolean storedfdsset=FALSE;
@@ -52,8 +50,7 @@ void audio_free_fnames(void) {
 
   for (i=0; i<NSTOREDFDS; i++) {
     if (storedfnames!=NULL) {
-      lives_free(storedfnames[i]);
-      storedfnames[i]=NULL;
+      lives_freep((void **)&storedfnames[i]);
       if (storedfds[i]>-1) close(storedfds[i]);
       storedfds[i]=-1;
     }
@@ -91,6 +88,8 @@ void append_to_audio_buffer16(lives_audio_buf_t *abuf, void *src, uint64_t nsamp
   // append 16 bit audio to the audio frame buffer
   size_t nsampsize;
 
+  if (abuf==NULL) return;
+
   if (!prefs->push_audio_to_gens) return;
 
   if (abuf->buffer16==NULL) free_audio_frame_buffer(abuf);
@@ -152,6 +151,7 @@ void init_audio_frame_buffer(short aplayer) {
 
 void free_audio_frame_buffer(lives_audio_buf_t *abuf) {
   // function should be called to clear samples
+  // cannot use lives_freep
   register int i;
   if (abuf!=NULL) {
     if (abuf->bufferf!=NULL) {
@@ -863,14 +863,14 @@ static void audio_process_events_to(weed_timecode_t tc) {
     switch (hint) {
 
     case WEED_EVENT_HINT_FILTER_INIT: {
-      weed_plant_t *deinit_event=(weed_plant_t *)weed_get_voidptr_value(event,"deinit_event",&error);
+      weed_plant_t *deinit_event=(weed_plant_t *)weed_get_voidptr_value(event,WEED_LEAF_DEINIT_EVENT,&error);
       if (get_event_timecode(deinit_event)<tc) break;
       process_events(event,TRUE,ctc);
     }
     break;
     case WEED_EVENT_HINT_FILTER_DEINIT: {
-      weed_plant_t *init_event=(weed_plant_t *)weed_get_voidptr_value(event,"init_event",&error);
-      if (weed_plant_has_leaf(init_event,"host_tag")) {
+      weed_plant_t *init_event=(weed_plant_t *)weed_get_voidptr_value(event,WEED_LEAF_INIT_EVENT,&error);
+      if (weed_plant_has_leaf(init_event,WEED_LEAF_HOST_TAG)) {
         process_events(event,TRUE,ctc);
       }
     }
@@ -976,7 +976,7 @@ int64_t render_audio_segment(int nfiles, int *from_files, int to_file, double *a
   boolean is_silent[nfiles];
   int first_nonsilent=-1;
 
-  int64_t tsamples=((tc_end-tc_start)/U_SEC*out_arate+.5);
+  int64_t tsamples=((double)(tc_end-tc_start)/U_SEC*out_arate+.5);
 
   int64_t blocksize,zsamples,xsamples;
 
@@ -1000,24 +1000,20 @@ int64_t render_audio_segment(int nfiles, int *from_files, int to_file, double *a
 
   if (to_file>-1) {
     // prepare outfile stuff
-    outfilename=lives_build_filename(prefs->tmpdir,outfile->handle,"audio",NULL);
+    outfilename=lives_build_filename(prefs->workdir,outfile->handle,"audio",NULL);
 #ifdef DEBUG_ARENDER
     g_print("writing to %s\n",outfilename);
 #endif
-    out_fd=open(outfilename,O_WRONLY|O_CREAT|O_SYNC,S_IRUSR|S_IWUSR);
+    out_fd=lives_open3(outfilename,O_WRONLY|O_CREAT|O_SYNC,S_IRUSR|S_IWUSR);
     lives_free(outfilename);
 
     if (out_fd<0) {
-      if (mainw->write_failed_file!=NULL) lives_free(mainw->write_failed_file);
+      lives_freep((void **)&mainw->write_failed_file);
       mainw->write_failed_file=lives_strdup(outfilename);
       mainw->write_failed=TRUE;
       return 0l;
     }
 
-#ifdef IS_MINGW
-    setmode(out_fd, O_BINARY);
-#endif
-
     cur_size=get_file_size(out_fd);
 
     ins_pt*=out_achans*out_arate*out_asamps;
@@ -1082,7 +1078,7 @@ int64_t render_audio_segment(int nfiles, int *from_files, int to_file, double *a
       zavel=avels[track]*(double)in_arate[track]/(double)out_arate*in_asamps[track]*in_achans[track]/sizeof(float);
       if (ABS(zavel)>zavel_max) zavel_max=ABS(zavel);
 
-      infilename=lives_build_filename(prefs->tmpdir,infile->handle,"audio",NULL);
+      infilename=lives_build_filename(prefs->workdir,infile->handle,"audio",NULL);
 
 
       // try to speed up access by keeping some files open
@@ -1090,16 +1086,13 @@ int64_t render_audio_segment(int nfiles, int *from_files, int to_file, double *a
         in_fd[track]=storedfds[track];
       } else {
         if (track<NSTOREDFDS&&storedfds[track]>-1) close(storedfds[track]);
-        in_fd[track]=open(infilename,O_RDONLY);
+        in_fd[track]=lives_open2(infilename,O_RDONLY);
         if (in_fd[track]<0) {
-          if (mainw->read_failed_file!=NULL) lives_free(mainw->read_failed_file);
+          lives_freep((void **)&mainw->read_failed_file);
           mainw->read_failed_file=lives_strdup(infilename);
           mainw->read_failed=TRUE;
         }
 
-#ifdef IS_MINGW
-        setmode(in_fd[track], O_BINARY);
-#endif
         if (track<NSTOREDFDS) {
           storedfds[track]=in_fd[track];
           storedfnames[track]=lives_strdup(infilename);
@@ -1136,10 +1129,12 @@ int64_t render_audio_segment(int nfiles, int *from_files, int to_file, double *a
           if (prefs->audio_player==AUD_PLAYER_JACK) {
             obuf->bufferf[i][j]=0.;
           } else {
-            if (!out_unsigned) obuf->buffer16[0][j*out_achans+i]=0;
+            if (!out_unsigned) obuf->buffer16[0][j*out_achans+i]=0x00;
             else {
-              if (out_bendian) obuf->buffer16[0][j*out_achans+i]=0x8000;
-              else obuf->buffer16[0][j*out_achans+i]=0x80;
+              if (out_bendian) {
+                memset(&obuf->buffer16_8[0][(j*out_achans+i)*2],0x80,1);
+                memset(&obuf->buffer16_8[0][(j*out_achans+i)*2+1],0x00,1);
+              } else obuf->buffer16[0][j*out_achans+i]=0x0080;
             }
           }
         }
@@ -1174,10 +1169,10 @@ int64_t render_audio_segment(int nfiles, int *from_files, int to_file, double *a
 
   xsamples=zsamples+(tsamples-(max_segments*zsamples)); // e.g 10 + 30 - 3 * 10 == 10
 
-  holding_buff=(short *)lives_malloc(xsamples*sizeof(short)*out_achans);
+  holding_buff=(short *)lives_malloc(xsamples*sizeof(short)*out_achans+128);
 
   for (i=0; i<out_achans*nfiles; i++) {
-    float_buffer[i]=(float *)lives_malloc(xsamples*sizeof(float));
+    float_buffer[i]=(float *)lives_malloc(xsamples*sizeof(float)+128);
   }
 
   finish_buff=lives_malloc(tsamples*out_achans*out_asamps);
@@ -1294,7 +1289,7 @@ int64_t render_audio_segment(int nfiles, int *from_files, int to_file, double *a
         weed_apply_audio_effects(mainw->afilter_map,chunk_float_buffer,nbtracks,
                                  out_achans,blocksize,out_arate,tc,vis);
 
-        if (vis!=NULL) lives_free(vis);
+        lives_freep((void **)&vis);
 
       }
 
@@ -1343,7 +1338,6 @@ int64_t render_audio_segment(int nfiles, int *from_files, int to_file, double *a
   }
 
 
-
   if (xsamples>0) {
     for (i=0; i<out_achans*nfiles; i++) {
       if (float_buffer[i]!=NULL) lives_free(float_buffer[i]);
@@ -1378,12 +1372,12 @@ LIVES_INLINE void aud_fade(int fileno, double startt, double endt, double startv
   render_audio_segment(1,&fileno,fileno,&vel,&startt,startt*U_SECL,endt*U_SECL,&vol,startv,endv,NULL);
 
   if (mainw->write_failed) {
-    char *outfilename=lives_build_filename(prefs->tmpdir,mainw->files[fileno]->handle,"audio",NULL);
+    char *outfilename=lives_build_filename(prefs->workdir,mainw->files[fileno]->handle,"audio",NULL);
     do_write_failed_error_s(outfilename,NULL);
   }
 
   if (mainw->read_failed) {
-    char *infilename=lives_build_filename(prefs->tmpdir,mainw->files[fileno]->handle,"audio",NULL);
+    char *infilename=lives_build_filename(prefs->workdir,mainw->files[fileno]->handle,"audio",NULL);
     do_read_failed_error_s(infilename,NULL);
   }
 
@@ -1418,10 +1412,10 @@ void jack_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t rec
   outfile=mainw->files[fileno];
 
   if (mainw->aud_rec_fd==-1) {
-    char *outfilename=lives_build_filename(prefs->tmpdir,outfile->handle,"audio",NULL);
+    char *outfilename=lives_build_filename(prefs->workdir,outfile->handle,"audio",NULL);
     do {
       retval=0;
-      mainw->aud_rec_fd=open(outfilename,O_WRONLY|O_CREAT|O_APPEND,S_IRUSR|S_IWUSR);
+      mainw->aud_rec_fd=lives_open3(outfilename,O_WRONLY|O_CREAT|O_APPEND,S_IRUSR|S_IWUSR);
       if (mainw->aud_rec_fd<0) {
         retval=do_write_failed_error_s_with_retry(outfilename,lives_strerror(errno),NULL);
         if (retval==LIVES_RESPONSE_CANCEL) {
@@ -1431,6 +1425,7 @@ void jack_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t rec
       }
     } while (retval==LIVES_RESPONSE_RETRY);
     lives_free(outfilename);
+    if (fileno==mainw->ascrap_file) mainw->files[mainw->ascrap_file]->cb_src=mainw->aud_rec_fd;
   }
 
   if (rec_type==RECA_GENERATED) {
@@ -1442,10 +1437,6 @@ void jack_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t rec
   }
 
 
-#ifdef IS_MINGW
-  setmode(mainw->aud_rec_fd, O_BINARY);
-#endif
-
   if (rec_type==RECA_EXTERNAL||rec_type==RECA_GENERATED) {
     int asigned;
     int aendian;
@@ -1549,6 +1540,7 @@ void jack_rec_audio_end(boolean close_device, boolean close_fd) {
 
 
 #ifdef HAVE_PULSE_AUDIO
+
 void pulse_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t rec_type) {
   // open audio file for writing
   lives_clip_t *outfile;
@@ -1571,10 +1563,10 @@ void pulse_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t re
   outfile=mainw->files[fileno];
 
   if (mainw->aud_rec_fd==-1) {
-    char *outfilename=lives_build_filename(prefs->tmpdir,outfile->handle,"audio",NULL);
+    char *outfilename=lives_build_filename(prefs->workdir,outfile->handle,"audio",NULL);
     do {
       retval=0;
-      mainw->aud_rec_fd=open(outfilename,O_WRONLY|O_CREAT|O_APPEND,S_IRUSR|S_IWUSR);
+      mainw->aud_rec_fd=lives_open3(outfilename,O_WRONLY|O_CREAT|O_APPEND,S_IRUSR|S_IWUSR);
       if (mainw->aud_rec_fd<0) {
         retval=do_write_failed_error_s_with_retry(outfilename,lives_strerror(errno),NULL);
         if (retval==LIVES_RESPONSE_CANCEL) {
@@ -1584,6 +1576,20 @@ void pulse_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t re
       }
     } while (retval==LIVES_RESPONSE_RETRY);
     lives_free(outfilename);
+    if (fileno==mainw->ascrap_file) {
+      mainw->files[mainw->ascrap_file]->cb_src=mainw->aud_rec_fd;
+      if (mainw->pulsed_read!=NULL) {
+        // flush all data from buffer; this seems like the only way
+        void *data;
+        size_t rbytes;
+        pa_mloop_lock();
+        do {
+          pa_stream_peek(mainw->pulsed_read->pstream,(const void **)&data,&rbytes);
+          if (rbytes>0) pa_stream_drop(mainw->pulsed_read->pstream);
+        } while (rbytes>0);
+        pa_mloop_unlock();
+      }
+    }
   }
 
   if (rec_type==RECA_GENERATED) {
@@ -1594,10 +1600,6 @@ void pulse_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t re
     mainw->pulsed_read->frames_written=0;
   }
 
-#ifdef IS_MINGW
-  setmode(mainw->aud_rec_fd, O_BINARY);
-#endif
-
   if (rec_type==RECA_EXTERNAL||rec_type==RECA_GENERATED) {
     int asigned;
     int aendian;
@@ -1676,15 +1678,11 @@ void pulse_rec_audio_end(boolean close_device, boolean close_fd) {
   // stop recording
 
   if (mainw->pulsed_read!=NULL) {
-    pa_threaded_mainloop_lock(mainw->pulsed_read->mloop);
-
     if (mainw->pulsed_read->playing_file>-1)
       pulse_flush_read_data(mainw->pulsed_read,mainw->pulsed_read->playing_file,0,mainw->pulsed_read->reverse_endian,NULL);
 
     if (close_device) pulse_close_client(mainw->pulsed_read);
 
-    pa_threaded_mainloop_unlock(mainw->pulsed_read->mloop);
-
     if (close_device) mainw->pulsed_read=NULL;
     else {
       mainw->pulsed_read->in_use=FALSE;
@@ -1733,7 +1731,7 @@ static lives_audio_track_state_t *resize_audstate(lives_audio_track_state_t *ost
     }
   }
 
-  if (ostate!=NULL) lives_free(ostate);
+  lives_freep((void **)&ostate);
 
   return audstate;
 }
@@ -1748,9 +1746,9 @@ static lives_audio_track_state_t *aframe_to_atstate(weed_plant_t *event) {
 
 
   int error,atrack;
-  int num_aclips=weed_leaf_num_elements(event,"audio_clips");
-  int *aclips=weed_get_int_array(event,"audio_clips",&error);
-  double *aseeks=weed_get_double_array(event,"audio_seeks",&error);
+  int num_aclips=weed_leaf_num_elements(event,WEED_LEAF_AUDIO_CLIPS);
+  int *aclips=weed_get_int_array(event,WEED_LEAF_AUDIO_CLIPS,&error);
+  double *aseeks=weed_get_double_array(event,WEED_LEAF_AUDIO_SEEKS,&error);
   int naudstate=0;
   lives_audio_track_state_t *atstate=NULL;
 
@@ -1812,7 +1810,7 @@ lives_audio_track_state_t *get_audio_and_effects_state_at(weed_plant_t *event_li
     if (WEED_EVENT_IS_FILTER_MAP(event)) {
       mainw->afilter_map=mainw->filter_map=event;
     } else if (WEED_EVENT_IS_FILTER_INIT(event)) {
-      deinit_event=(weed_plant_t *)weed_get_voidptr_value(event,"deinit_event",&error);
+      deinit_event=(weed_plant_t *)weed_get_voidptr_value(event,WEED_LEAF_DEINIT_EVENT,&error);
       if (get_event_timecode(deinit_event)>=fill_tc) {
         // this effect should be activated
         process_events(event,FALSE,get_event_timecode(event));
@@ -1904,11 +1902,11 @@ void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_p
     event=st_event;
     last_tc=get_event_timecode(event);
 
-    if (from_files!=NULL) lives_free(from_files);
-    if (avels!=NULL) lives_free(avels);
-    if (aseeks!=NULL) lives_free(aseeks);
+    lives_freep((void **)&from_files);
+    lives_freep((void **)&avels);
+    lives_freep((void **)&aseeks);
 
-    if (mainw->multitrack!=NULL) nfiles=weed_leaf_num_elements(mainw->multitrack->avol_init_event,"in_tracks");
+    if (mainw->multitrack!=NULL) nfiles=weed_leaf_num_elements(mainw->multitrack->avol_init_event,WEED_LEAF_IN_TRACKS);
 
     else nfiles=1;
 
@@ -1979,8 +1977,7 @@ void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_p
       tc+=(U_SEC/cfile->fps*!is_blank_frame(event,FALSE));
 
       mainw->read_failed=FALSE;
-      if (mainw->read_failed_file!=NULL) lives_free(mainw->read_failed_file);
-      mainw->read_failed_file=NULL;
+      lives_freep((void **)&mainw->read_failed_file);
 
       render_audio_segment(nfiles, from_files, -1, avels, aseeks, last_tc, tc, chvols, 1., 1., abuf);
 
@@ -2018,8 +2015,7 @@ void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_p
     // flush the rest of the audio
 
     mainw->read_failed=FALSE;
-    if (mainw->read_failed_file!=NULL) lives_free(mainw->read_failed_file);
-    mainw->read_failed_file=NULL;
+    lives_freep((void **)&mainw->read_failed_file);
 
     render_audio_segment(nfiles, from_files, -1, avels, aseeks, last_tc, fill_tc, chvols, 1., 1., abuf);
     for (i=0; i<nfiles; i++) {
@@ -2233,7 +2229,6 @@ static void *cache_my_audio(void *arg) {
     cbuffer->eof=FALSE;
 
     // TODO - if out_asamps changed, we need to free all buffers and set _cachans==0
-
     if (cbuffer->out_asamps!=cbuffer->_casamps) {
       if (cbuffer->bufferf!=NULL) {
         // free float channels
@@ -2391,6 +2386,7 @@ static void *cache_my_audio(void *arg) {
       break;
     }
 
+
     // update _cinterleaf, etc.
     cbuffer->_cin_interleaf=cbuffer->in_interleaf;
     cbuffer->_cout_interleaf=cbuffer->out_interleaf;
@@ -2406,10 +2402,10 @@ static void *cache_my_audio(void *arg) {
       if (cbuffer->_fd!=-1) close(cbuffer->_fd);
 
       if (afile->opening)
-        filename=lives_strdup_printf("%s/%s/audiodump.pcm",prefs->tmpdir,mainw->files[cbuffer->fileno]->handle);
-      else filename=lives_strdup_printf("%s/%s/audio",prefs->tmpdir,mainw->files[cbuffer->fileno]->handle);
+        filename=lives_strdup_printf("%s/%s/audiodump.pcm",prefs->workdir,mainw->files[cbuffer->fileno]->handle);
+      else filename=lives_strdup_printf("%s/%s/audio",prefs->workdir,mainw->files[cbuffer->fileno]->handle);
 
-      cbuffer->_fd=open(filename,O_RDONLY);
+      cbuffer->_fd=lives_open2(filename,O_RDONLY);
       if (cbuffer->_fd==-1) {
         lives_printerr("audio cache thread: error opening %s\n",filename);
         cbuffer->in_achans=0;
@@ -2418,10 +2414,6 @@ static void *cache_my_audio(void *arg) {
         continue;
       }
 
-#ifdef IS_MINGW
-      setmode(cbuffer->_fd, O_BINARY);
-#endif
-
       lives_free(filename);
     }
 
@@ -2603,35 +2595,35 @@ getaud1:
   channel=get_enabled_channel(inst,0,FALSE);
 
   if (channel!=NULL) {
-    ctmpl=weed_get_plantptr_value(channel,"template",&error);
+    ctmpl=weed_get_plantptr_value(channel,WEED_LEAF_TEMPLATE,&error);
 
-    if (weed_plant_has_leaf(ctmpl,"audio_rate")&&weed_get_int_value(ctmpl,"audio_rate",&error)!=arate) {
+    if (weed_plant_has_leaf(ctmpl,WEED_LEAF_AUDIO_RATE)&&weed_get_int_value(ctmpl,WEED_LEAF_AUDIO_RATE,&error)!=arate) {
       // TODO - resample if audio rate is wrong
       return FALSE;
     }
 
-    if (weed_plant_has_leaf(ctmpl,"audio_interleaf")) aint=weed_get_boolean_value(ctmpl,"audio_interleaf",&error);
-    if (weed_plant_has_leaf(ctmpl,"audio_channels")) xnchans=weed_get_int_value(ctmpl,"audio_channels",&error);
+    if (weed_plant_has_leaf(ctmpl,WEED_LEAF_AUDIO_INTERLEAF)) aint=weed_get_boolean_value(ctmpl,WEED_LEAF_AUDIO_INTERLEAF,&error);
+    if (weed_plant_has_leaf(ctmpl,WEED_LEAF_AUDIO_CHANNELS)) xnchans=weed_get_int_value(ctmpl,WEED_LEAF_AUDIO_CHANNELS,&error);
 
     // stop video thread from possibly interpolating/deiniting
     if (pthread_mutex_trylock(&mainw->interp_mutex)) return FALSE;
 
 
     // make sure values match, else we need to reinit the plugin
-    if (xnchans!=weed_get_int_value(channel,"audio_channels",&error)||
-        arate!=weed_get_int_value(channel,"audio_rate",&error)||
-        weed_get_boolean_value(channel,"audio_interleaf",&error)!=aint) {
+    if (xnchans!=weed_get_int_value(channel,WEED_LEAF_AUDIO_CHANNELS,&error)||
+        arate!=weed_get_int_value(channel,WEED_LEAF_AUDIO_RATE,&error)||
+        weed_get_boolean_value(channel,WEED_LEAF_AUDIO_INTERLEAF,&error)!=aint) {
       // reinit plugin
       mainw->agen_needs_reinit=TRUE;
     }
 
-    weed_set_int_value(channel,"audio_channels",xnchans);
-    weed_set_int_value(channel,"audio_rate",arate);
-    weed_set_boolean_value(channel,"audio_interleaf",aint);
-    weed_set_int_value(channel,"audio_data_length",nsamps);
-    weed_set_voidptr_value(channel,"audio_data",fbuffer);
+    weed_set_int_value(channel,WEED_LEAF_AUDIO_CHANNELS,xnchans);
+    weed_set_int_value(channel,WEED_LEAF_AUDIO_RATE,arate);
+    weed_set_boolean_value(channel,WEED_LEAF_AUDIO_INTERLEAF,aint);
+    weed_set_int_value(channel,WEED_LEAF_AUDIO_DATA_LENGTH,nsamps);
+    weed_set_voidptr_value(channel,WEED_LEAF_AUDIO_DATA,fbuffer);
 
-    weed_set_double_value(inst,"fps",cfile->pb_fps);
+    weed_set_double_value(inst,WEED_LEAF_FPS,cfile->pb_fps);
 
     if (mainw->agen_needs_reinit) {
       // allow main thread to complete the reinit so we do not delay; just return silence
@@ -2640,7 +2632,7 @@ getaud1:
       return FALSE;
     }
 
-    weed_set_int64_value(channel,"timecode",tc);
+    weed_set_int64_value(channel,WEED_LEAF_TIMECODE,tc);
   }
 
 
@@ -2661,7 +2653,7 @@ getaud1:
 
 
 
-  weed_leaf_get(filter,"process_func",0,(void *)&process_func_ptr_ptr);
+  weed_leaf_get(filter,WEED_LEAF_PROCESS_FUNC,0,(void *)&process_func_ptr_ptr);
   process_func=process_func_ptr_ptr[0];
 
   if ((*process_func)(inst,tc)==WEED_ERROR_PLUGIN_INVALID) {
@@ -2679,9 +2671,9 @@ getaud1:
     lives_memcpy(&fbuffer[nsamps],fbuffer,nsamps*sizeof(float));
   }
 
-  if (weed_plant_has_leaf(inst,"host_next_instance")) {
+  if (weed_plant_has_leaf(inst,WEED_LEAF_HOST_NEXT_INSTANCE)) {
     // handle compound fx
-    inst=weed_get_plantptr_value(inst,"host_next_instance",&error);
+    inst=weed_get_plantptr_value(inst,WEED_LEAF_HOST_NEXT_INSTANCE,&error);
     goto getaud1;
   }
 
@@ -2731,16 +2723,12 @@ boolean apply_rte_audio_init(void) {
   }
 
   audio_pos=(double)((cfile->start-1)*cfile->arate*cfile->achans*cfile->asampsize/8)/cfile->fps;
-  audio_file=lives_build_filename(prefs->tmpdir,cfile->handle,"audio",NULL);
+  audio_file=lives_build_filename(prefs->workdir,cfile->handle,"audio",NULL);
 
-  audio_fd=open(audio_file,O_RDWR|O_CREAT,DEF_FILE_PERMS);
+  audio_fd=lives_open3(audio_file,O_RDWR|O_CREAT,DEF_FILE_PERMS);
 
   if (audio_fd==-1) return FALSE;
 
-#ifdef IS_MINGW
-  setmode(audio_fd,O_BINARY);
-#endif
-
   if (audio_pos>cfile->afilesize) {
     off64_t audio_end_pos=(double)((cfile->start-1)*cfile->arate*cfile->achans*cfile->asampsize/8)/cfile->fps;
     pad_with_silence(audio_fd, audio_pos, audio_end_pos, cfile->asampsize, cfile->signed_endian&AFORM_UNSIGNED,
@@ -2755,7 +2743,7 @@ boolean apply_rte_audio_init(void) {
 
 void apply_rte_audio_end(boolean del) {
   close(audio_fd);
-  if (del) unlink(audio_file);
+  if (del) lives_rm(audio_file);
   lives_free(audio_file);
 }
 
@@ -2808,11 +2796,10 @@ boolean apply_rte_audio(int nframes) {
 
     if (mainw->read_failed) {
       do_read_failed_error_s(audio_file,NULL);
-      if (mainw->read_failed_file!=NULL) lives_free(mainw->read_failed_file);
-      mainw->read_failed_file=NULL;
+      lives_freep((void **)&mainw->read_failed_file);
       lives_free(fltbuf);
       lives_free(in_buff);
-      if (shortbuf!=NULL) lives_free(shortbuf);
+      lives_freep((void **)&shortbuf);
       return FALSE;
     }
 
@@ -2921,7 +2908,7 @@ boolean push_audio_to_channel(weed_plant_t *achan, lives_audio_buf_t *abuf) {
 
   // NB: if player is jack, we will have non-interleaved float
   // if player is pulse, we will have interleaved S16
-  void *dst,*src;
+  float *dst,*src;
 
   weed_plant_t *ctmpl;
 
@@ -2937,26 +2924,26 @@ boolean push_audio_to_channel(weed_plant_t *achan, lives_audio_buf_t *abuf) {
   register int i;
 
   if (abuf->samples_filled==0) {
-    weed_set_int_value(achan,"audio_data_length",0);
-    weed_set_voidptr_value(achan,"audio_data",NULL);
+    weed_set_int_value(achan,WEED_LEAF_AUDIO_DATA_LENGTH,0);
+    weed_set_voidptr_value(achan,WEED_LEAF_AUDIO_DATA,NULL);
     return FALSE;
   }
 
-  ctmpl=weed_get_plantptr_value(achan,"template",&error);
+  ctmpl=weed_get_plantptr_value(achan,WEED_LEAF_TEMPLATE,&error);
 
-  if (weed_plant_has_leaf(achan,"audio_rate")) trate=weed_get_int_value(achan,"audio_rate",&error);
-  else if (weed_plant_has_leaf(ctmpl,"audio_rate")) trate=weed_get_int_value(ctmpl,"audio_rate",&error);
+  if (weed_plant_has_leaf(achan,WEED_LEAF_AUDIO_RATE)) trate=weed_get_int_value(achan,WEED_LEAF_AUDIO_RATE,&error);
+  else if (weed_plant_has_leaf(ctmpl,WEED_LEAF_AUDIO_RATE)) trate=weed_get_int_value(ctmpl,WEED_LEAF_AUDIO_RATE,&error);
   else trate=DEFAULT_AUDIO_RATE;
 
-  if (weed_plant_has_leaf(achan,"audio_channels")) tchans=weed_get_int_value(achan,"audio_channels",&error);
-  else if (weed_plant_has_leaf(ctmpl,"audio_channels")) tchans=weed_get_int_value(ctmpl,"audio_channels",&error);
+  if (weed_plant_has_leaf(achan,WEED_LEAF_AUDIO_CHANNELS)) tchans=weed_get_int_value(achan,WEED_LEAF_AUDIO_CHANNELS,&error);
+  else if (weed_plant_has_leaf(ctmpl,WEED_LEAF_AUDIO_CHANNELS)) tchans=weed_get_int_value(ctmpl,WEED_LEAF_AUDIO_CHANNELS,&error);
   else tchans=DEFAULT_AUDIO_CHANS;
 
-  if (weed_plant_has_leaf(achan,"audio_interleaf")) tinter=weed_get_boolean_value(achan,"audio_interleaf",&error);
-  else if (weed_plant_has_leaf(ctmpl,"audio_interleaf")) tinter=weed_get_boolean_value(ctmpl,"audio_interleaf",&error);
+  if (weed_plant_has_leaf(achan,WEED_LEAF_AUDIO_INTERLEAF)) tinter=weed_get_boolean_value(achan,WEED_LEAF_AUDIO_INTERLEAF,&error);
+  else if (weed_plant_has_leaf(ctmpl,WEED_LEAF_AUDIO_INTERLEAF)) tinter=weed_get_boolean_value(ctmpl,WEED_LEAF_AUDIO_INTERLEAF,&error);
   else tinter=FALSE;
 
-  if (weed_plant_has_leaf(ctmpl,"audio_data_length")) tlen=weed_get_int_value(ctmpl,"audio_data_length",&error);
+  if (weed_plant_has_leaf(ctmpl,WEED_LEAF_AUDIO_DATA_LENGTH)) tlen=weed_get_int_value(ctmpl,WEED_LEAF_AUDIO_DATA_LENGTH,&error);
   else tlen=0;
 
 #ifdef DEBUG_AFB
@@ -3002,7 +2989,7 @@ boolean push_audio_to_channel(weed_plant_t *achan, lives_audio_buf_t *abuf) {
 
   samps=abuf->samples_filled;
 
-  // push to achan "audio_data", taking into account "audio_data_length", "audio_interleaf", "audio_channels"
+  // push to achan WEED_LEAF_AUDIO_DATA, taking into account WEED_LEAF_AUDIO_DATA_LENGTH, WEED_LEAF_AUDIO_INTERLEAF, WEED_LEAF_AUDIO_CHANNELS
 
   alen=samps;
   if (alen>tlen&&tlen>0) alen=tlen;
@@ -3012,16 +2999,16 @@ boolean push_audio_to_channel(weed_plant_t *achan, lives_audio_buf_t *abuf) {
   scale=(float)trate/(float)abuf->arate;
 
   // malloc audio_data
-  dst=lives_malloc(alen*tchans*sizeof(float));
+  dst=(float *)lives_malloc(alen*tchans*sizeof(float));
 
   // set channel values
-  weed_set_voidptr_value(achan,"audio_data",dst);
-  weed_set_boolean_value(achan,"audio_interleaf",tinter);
-  weed_set_int_value(achan,"audio_data_length",alen);
-  weed_set_int_value(achan,"audio_channels",tchans);
-  weed_set_int_value(achan,"audio_rate",trate);
+  weed_set_voidptr_value(achan,WEED_LEAF_AUDIO_DATA,(void *)dst);
+  weed_set_boolean_value(achan,WEED_LEAF_AUDIO_INTERLEAF,tinter);
+  weed_set_int_value(achan,WEED_LEAF_AUDIO_DATA_LENGTH,alen);
+  weed_set_int_value(achan,WEED_LEAF_AUDIO_CHANNELS,tchans);
+  weed_set_int_value(achan,WEED_LEAF_AUDIO_RATE,trate);
 
-  // copy data from abuf->bufferf[] to "audio_data"
+  // copy data from abuf->bufferf[] to WEED_LEAF_AUDIO_DATA
   for (i=0; i<tchans; i++) {
     src=abuf->bufferf[i%abuf->out_achans]+offs;
     if (!tinter) {
@@ -3029,12 +3016,12 @@ boolean push_audio_to_channel(weed_plant_t *achan, lives_audio_buf_t *abuf) {
         lives_memcpy(dst,src,alen*sizeof(float));
       } else {
         // needs resample
-        sample_move_float_float((float *)dst,(float *)src,alen,scale,1);
+        sample_move_float_float(dst,src,alen,scale,1);
       }
-      dst+=alen*sizeof(float);
+      dst+=alen;
     } else {
-      sample_move_float_float((float *)dst,(float *)src,alen,scale,tchans);
-      dst+=sizeof(float);
+      sample_move_float_float(dst,src,alen,scale,tchans);
+      dst++;
     }
   }
   return TRUE;
@@ -3065,11 +3052,11 @@ boolean start_audio_stream(void) {
 
   boolean timeout=FALSE;
 
-  astream_name=lives_build_filename(prefs->tmpdir,astname,NULL);
+  astream_name=lives_build_filename(prefs->workdir,astname,NULL);
 
   mkfifo(astream_name,S_IRUSR|S_IWUSR);
 
-  astream_name_out=lives_build_filename(prefs->tmpdir,astname_out,NULL);
+  astream_name_out=lives_build_filename(prefs->workdir,astname_out,NULL);
 
   lives_free(astname);
   lives_free(astname_out);
@@ -3095,21 +3082,17 @@ boolean start_audio_stream(void) {
 
   astream_pgid=lives_fork(com);
 
-  alarm_handle=lives_alarm_set(LIVES_ACONNECT_TIMEOUT);
+  alarm_handle=lives_alarm_set(LIVES_DEFAULT_TIMEOUT);
 
   do {
     // wait for other thread to create stream (or timeout)
-    afd=open(astream_name,O_WRONLY|O_SYNC);
+    afd=lives_open2(astream_name,O_WRONLY|O_SYNC);
     if (afd!=-1) break;
     lives_usleep(prefs->sleep_time);
   } while (!(timeout=lives_alarm_get(alarm_handle)));
 
   lives_alarm_clear(alarm_handle);
 
-#ifdef IS_MINGW
-  setmode(afd, O_BINARY);
-#endif
-
   if (prefs->audio_player==AUD_PLAYER_PULSE) {
 #ifdef HAVE_PULSE_AUDIO
     mainw->pulsed->astream_fd=afd;
@@ -3122,10 +3105,6 @@ boolean start_audio_stream(void) {
 #endif
   }
 
-#ifdef IS_MINGW
-  setmode(afd, O_BINARY);
-#endif
-
   lives_free(astream_name);
   lives_free(astream_name_out);
 
@@ -3142,8 +3121,8 @@ void stop_audio_stream(void) {
     char *astname_out=lives_strdup_printf("livesaudio-%d.stream",capable->mainpid);
     char *astreamer=lives_build_filename(prefs->lib_dir,PLUGIN_EXEC_DIR,PLUGIN_AUDIO_STREAM,playername,NULL);
 
-    char *astream_name=lives_build_filename(prefs->tmpdir,astname,NULL);
-    char *astream_name_out=lives_build_filename(prefs->tmpdir,astname_out,NULL);
+    char *astream_name=lives_build_filename(prefs->workdir,astname,NULL);
+    char *astream_name_out=lives_build_filename(prefs->workdir,astname_out,NULL);
 
     char *com;
 
@@ -3164,7 +3143,7 @@ void stop_audio_stream(void) {
     }
 
     lives_killpg(astream_pgid,LIVES_SIGKILL);
-    unlink(astream_name);
+    lives_rm(astream_name);
     lives_free(astream_name);
 
     // astreamer should remove cooked stream
@@ -3182,11 +3161,11 @@ void stop_audio_stream(void) {
 void clear_audio_stream(void) {
   // remove raw and cooked streams
   char *astname=lives_strdup_printf("livesaudio-%d.pcm",capable->mainpid);
-  char *astream_name=lives_build_filename(prefs->tmpdir,astname,NULL);
+  char *astream_name=lives_build_filename(prefs->workdir,astname,NULL);
   char *astname_out=lives_strdup_printf("livesaudio-%d.stream",capable->mainpid);
-  char *astream_name_out=lives_build_filename(prefs->tmpdir,astname_out,NULL);
-  unlink(astream_name);
-  unlink(astream_name_out);
+  char *astream_name_out=lives_build_filename(prefs->workdir,astname_out,NULL);
+  lives_rm(astream_name);
+  lives_rm(astream_name_out);
   lives_free(astname);
   lives_free(astream_name);
   lives_free(astname_out);
