@@ -1,16 +1,49 @@
 // colourspace.h
 // LiVES
-// (c) G. Finch 2004 - 2012 <salsaman@gmail.com>
+// (c) G. Finch 2004 - 2016 <salsaman@gmail.com>
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
+
 // headers for palette conversions
 
 #ifndef HAS_LIVES_COLOURSPACE_H
 #define HAS_LIVES_COLOURSPACE_H
 
+#define WEED_LEAF_HOST_PIXEL_DATA_CONTIGUOUS "host_pixel_data_contiguous"
+#define WEED_LEAF_HOST_PIXBUF_SRC "host_pixbuf_src"
+
 #define SCREEN_GAMMA 2.2
 
+
+
+// rgb / yuv conversion factors ////////////
+#define FP_BITS 16 /// max fp bits
+#define SCALE_FACTOR (1<<FP_BITS)
+
+#define KR_YCBCR 0.299
+#define KB_YCBCR 0.114
+
+#define KR_BT701 0.2126
+#define KB_BT701 0.0722
+
+#define YUV_CLAMP_MIN 16.
+#define YUV_CLAMP_MINI 16
+
+#define Y_CLAMP_MAX 235.
+
+#define UV_CLAMP_MAX 240.
+#define UV_CLAMP_MAXI 240
+
+#define CLAMP_FACTOR_Y ((Y_CLAMP_MAX-YUV_CLAMP_MIN)/255.) // unclamped -> clamped
+#define CLAMP_FACTOR_UV ((UV_CLAMP_MAX-YUV_CLAMP_MIN)/255.) // unclamped -> clamped
+
+#define UV_BIAS 128.
+
+/////////////////////////////////////////////
+
+
+
 typedef struct {
   uint8_t u0;
   uint8_t y0;
