@@ -53,7 +53,7 @@ boolean save_frame_index(int fileno) {
 
   if (sfile==NULL||sfile->frame_index==NULL) return FALSE;
 
-  fname=lives_build_filename(prefs->tmpdir,sfile->handle,"file_index",NULL);
+  fname=lives_build_filename(prefs->workdir,sfile->handle,"file_index",NULL);
 
   do {
     retval=0;
@@ -80,73 +80,73 @@ boolean save_frame_index(int fileno) {
 
   if (retval==LIVES_RESPONSE_CANCEL) return FALSE;
 
-   return TRUE;
- }
+  return TRUE;
+}
 
 
 
- // load frame_index from disk
- // returns -1 (error)
- // or maxframe pointed to in clip
+// load frame_index from disk
+// returns -1 (error)
+// or maxframe pointed to in clip
 
- int load_frame_index(int fileno) {
-   lives_clip_t *sfile=mainw->files[fileno];
+int load_frame_index(int fileno) {
+  lives_clip_t *sfile=mainw->files[fileno];
 
-   char *fname;
+  char *fname;
 
-   int fd;
-   int retval;
-   int maxframe=0;
+  int fd;
+  int retval;
+  int maxframe=0;
 
-   register int i;
+  register int i;
 
-   if (sfile==NULL||sfile->frame_index!=NULL) return -1;
+  if (sfile==NULL||sfile->frame_index!=NULL) return -1;
 
-   lives_freep((void **)&sfile->frame_index);
+  lives_freep((void **)&sfile->frame_index);
 
-   fname=lives_build_filename(prefs->tmpdir,sfile->handle,"file_index",NULL);
+  fname=lives_build_filename(prefs->workdir,sfile->handle,"file_index",NULL);
 
-   if (!lives_file_test(fname,LIVES_FILE_TEST_EXISTS)) {
-     lives_free(fname);
-     return 0;
-   }
+  if (!lives_file_test(fname,LIVES_FILE_TEST_EXISTS)) {
+    lives_free(fname);
+    return 0;
+  }
 
 
-   do {
-     retval=0;
+  do {
+    retval=0;
 
-     fd=lives_open_buffered_rdonly(fname);
+    fd=lives_open_buffered_rdonly(fname);
 
-     if (fd<0) {
-       retval=do_read_failed_error_s_with_retry(fname,lives_strerror(errno),NULL);
-       if (retval==LIVES_RESPONSE_CANCEL) {
-	 lives_free(fname);
-	 return -1;
-       }
-     } else {
+    if (fd<0) {
+      retval=do_read_failed_error_s_with_retry(fname,lives_strerror(errno),NULL);
+      if (retval==LIVES_RESPONSE_CANCEL) {
+        lives_free(fname);
+        return -1;
+      }
+    } else {
 
-       create_frame_index(fileno,FALSE,0,sfile->frames);
+      create_frame_index(fileno,FALSE,0,sfile->frames);
 
-       mainw->read_failed=FALSE;
-       for (i=0; i<sfile->frames; i++) {
-	 lives_read_le_buffered(fd,&sfile->frame_index[i],4,FALSE);
-	 if (mainw->read_failed) break;
-	 if (sfile->frame_index[i]>maxframe) maxframe=sfile->frame_index[i];
-       }
+      mainw->read_failed=FALSE;
+      for (i=0; i<sfile->frames; i++) {
+        lives_read_le_buffered(fd,&sfile->frame_index[i],4,FALSE);
+        if (mainw->read_failed) break;
+        if (sfile->frame_index[i]>maxframe) maxframe=sfile->frame_index[i];
+      }
 
-       lives_close_buffered(fd);
+      lives_close_buffered(fd);
 
-       if (mainw->read_failed) {
-	 mainw->read_failed=FALSE;
-	 retval=do_read_failed_error_s_with_retry(fname,NULL,NULL);
-       }
+      if (mainw->read_failed) {
+        mainw->read_failed=FALSE;
+        retval=do_read_failed_error_s_with_retry(fname,NULL,NULL);
+      }
 
-     }
-   } while (retval==LIVES_RESPONSE_RETRY);
+    }
+  } while (retval==LIVES_RESPONSE_RETRY);
 
-   lives_free(fname);
+  lives_free(fname);
 
-   return ++maxframe;
+  return ++maxframe;
 }
 
 
@@ -170,7 +170,7 @@ void del_frame_index(lives_clip_t *sfile) {
   }
 
   if (sfile!=clipboard) {
-    idxfile=lives_build_filename(prefs->tmpdir,sfile->handle,"file_index",NULL);
+    idxfile=lives_build_filename(prefs->workdir,sfile->handle,"file_index",NULL);
     lives_rm(idxfile);
     lives_free(idxfile);
   }
