@@ -53,25 +53,7 @@ static void start_preview(LiVESButton *button, lives_rfx_t *rfx) {
   lives_widget_context_update();
 
   if (mainw->did_rfx_preview) {
-#ifndef IS_MINGW
-    com=lives_strdup_printf("%s stopsubsub \"%s\" 2>/dev/null",prefs->backend_sync,cfile->handle);
-    lives_system(com,TRUE); // try to stop any in-progress preview
-#else
-    // get pid from backend
-    FILE *rfile;
-    ssize_t rlen;
-    char val[16];
-    int pid;
-    com=lives_strdup_printf("%s get_pid_for_handle \"%s\"",prefs->backend_sync,cfile->handle);
-    rfile=popen(com,"r");
-    rlen=fread(val,1,16,rfile);
-    pclose(rfile);
-    memset(val+rlen,0,1);
-    pid=atoi(val);
-
-    lives_win32_kill_subprocesses(pid,TRUE);
-#endif
-    lives_free(com);
+    lives_kill_subprocesses(cfile->handle,TRUE);
 
     if (cfile->start==0) {
       cfile->start=1;
@@ -81,11 +63,7 @@ static void start_preview(LiVESButton *button, lives_rfx_t *rfx) {
     do_rfx_cleanup(rfx);
   }
 
-#ifndef IS_MINGW
-  com=lives_strdup_printf("%s clear_pre_files \"%s\" 2>/dev/null",prefs->backend_sync,cfile->handle);
-#else
-  com=lives_strdup_printf("%s clear_pre_files \"%s\" 2>NUL",prefs->backend_sync,cfile->handle);
-#endif
+  com=lives_strdup_printf("%s clear_pre_files \"%s\" 2>%s",prefs->backend_sync,cfile->handle,LIVES_DEVNULL);
   lives_system(com,TRUE); // clear any .pre files from before
 
   for (i=0; i<rfx->num_params; i++) {
@@ -187,12 +165,11 @@ void widget_add_framedraw(LiVESVBox *box, int start, int end, boolean add_previe
   // after calling this function
 
   // an example of this is in 'trim frames'
+  LiVESAdjustment *spinbutton_adj;
 
   LiVESWidget *vseparator;
   LiVESWidget *vbox;
   LiVESWidget *hbox;
-  LiVESWidget *label;
-  LiVESAdjustment *spinbutton_adj;
   LiVESWidget *frame;
 
   lives_rfx_t *rfx;
@@ -221,22 +198,19 @@ void widget_add_framedraw(LiVESVBox *box, int start, int end, boolean add_previe
   fbord_eventbox=lives_event_box_new();
   lives_container_set_border_width(LIVES_CONTAINER(fbord_eventbox),widget_opts.border_width);
 
-  frame = lives_frame_new(NULL);
+  frame = lives_standard_frame_new(_("Preview"),0.,TRUE);
 
-  lives_box_pack_start(LIVES_BOX(hbox), frame, FALSE, FALSE, 0);
-
-  if (palette->style&STYLE_1) {
-    lives_widget_set_bg_color(fbord_eventbox, LIVES_WIDGET_STATE_NORMAL, &palette->normal_fore);
-    lives_widget_set_bg_color(frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
-    lives_widget_set_fg_color(frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_fore);
-  }
+  lives_box_pack_start(LIVES_BOX(hbox), frame, TRUE, TRUE, 0);
 
   mainw->fd_frame=frame;
 
-  label = lives_standard_label_new(_("Preview"));
-  lives_frame_set_label_widget(LIVES_FRAME(frame), label);
+  hbox = lives_hbox_new(FALSE, 0);
+  lives_container_set_border_width(LIVES_CONTAINER(hbox),0);
+  lives_container_add(LIVES_CONTAINER(frame), hbox);
 
-  lives_frame_set_shadow_type(LIVES_FRAME(frame), LIVES_SHADOW_NONE);
+  if (palette->style&STYLE_1) {
+    lives_widget_set_bg_color(hbox, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
+  }
 
   mainw->framedraw=lives_event_box_new();
   lives_widget_set_size_request(mainw->framedraw, width, height);
@@ -247,7 +221,9 @@ void widget_add_framedraw(LiVESVBox *box, int start, int end, boolean add_previe
 
   mainw->framedraw_frame=start;
 
-  lives_container_add(LIVES_CONTAINER(frame), fbord_eventbox);
+  lives_box_pack_start(LIVES_BOX(hbox), fbord_eventbox, FALSE, FALSE, 0);
+
+  //lives_container_add(LIVES_CONTAINER(frame), fbord_eventbox);
   lives_container_add(LIVES_CONTAINER(fbord_eventbox), mainw->framedraw);
 
   if (palette->style&STYLE_1) {
@@ -260,7 +236,7 @@ void widget_add_framedraw(LiVESVBox *box, int start, int end, boolean add_previe
 
 
   hbox = lives_hbox_new(FALSE, 2);
-  lives_box_pack_start(LIVES_BOX(vbox), hbox, FALSE, FALSE, 0);
+  lives_box_pack_start(LIVES_BOX(vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
   mainw->framedraw_spinbutton = lives_standard_spin_button_new(_("_Frame"),
                                 TRUE,start,start,end,1.,10.,0,LIVES_BOX(hbox),NULL);
@@ -499,11 +475,9 @@ void load_rfx_preview(lives_rfx_t *rfx) {
   mainw->write_failed=FALSE;
 
 
-#define LIVES_RFX_TIMER 10*U_SEC
-
   if (cfile->clip_type==CLIP_TYPE_FILE&&vend<=cfile->end) {
     // pull some frames for 10 seconds
-    alarm_handle=lives_alarm_set(LIVES_RFX_TIMER);
+    alarm_handle=lives_alarm_set(LIVES_DEFAULT_TIMEOUT);
     do {
       lives_widget_context_update();
       if (is_virtual_frame(mainw->current_file,vend)) {
@@ -704,6 +678,7 @@ void redraw_framedraw_image(void) {
   // layer to pixbuf
   pixbuf=layer_to_pixbuf(mainw->fd_layer);
 
+
   // get lives_painter for window
   cr = lives_painter_create_from_widget(mainw->framedraw);
 
