@@ -70,9 +70,7 @@ boolean lives_jack_init(void) {
 #endif
         lives_system(com,FALSE);
         lives_free(com);
-        com=lives_strdup_printf("%s o+x \"%s\"",capable->chmod_cmd,prefs->jack_aserver);
-        lives_system(com,FALSE);
-        lives_free(com);
+        lives_chmod(prefs->jack_aserver,"o+x");
       }
     }
 
@@ -342,7 +340,7 @@ static int audio_process(nframes_t nframes, void *arg) {
     default:
       msg->data=NULL;
     }
-    if (msg->data!=NULL) lives_free((char *)msg->data);
+    lives_freep((void **)&msg->data);
     msg->command=ASERVER_CMD_PROCESSED;
     if (msg->next==NULL) jackd->msgq=NULL;
     else jackd->msgq = msg->next;
@@ -776,7 +774,7 @@ static int audio_process(nframes_t nframes, void *arg) {
                     }
                   }
                   nbytes=numFramesToWrite*jackd->num_output_channels*4;
-                  if (oinbuf!=NULL) lives_free(oinbuf);
+                  lives_freep((void **)&oinbuf);
                 }
                 rbytes=numFramesToWrite*jackd->num_output_channels*2;
                 audio_stream(xbuf,rbytes,jackd->astream_fd);
@@ -784,7 +782,7 @@ static int audio_process(nframes_t nframes, void *arg) {
               }
             }
 
-            if (fbuffer!=NULL) lives_free(fbuffer);
+            lives_freep((void **)&fbuffer);
 
           } else {
             if (mainw->audio_frame_buffer!=NULL&&prefs->audio_src!=AUDIO_SRC_EXT) {
@@ -1062,9 +1060,16 @@ static size_t audio_read_inner(jack_driver_t *jackd, float **in_buffer, int ofil
     size_t target=frames_out*(ofile->asampsize/8)*ofile->achans;
     // use write not lives_write - because of potential threading issues
     bytes=write(mainw->aud_rec_fd,holding_buff,target);
-
-    if (bytes<target) mainw->bad_aud_file=filename_from_fd(NULL,mainw->aud_rec_fd);
-    if (bytes<0) bytes=0;
+    if (bytes>0) {
+      mainw->aud_data_written+=bytes;
+      if (mainw->ascrap_file!=-1&&mainw->files[mainw->ascrap_file]!=NULL&&mainw->aud_rec_fd==mainw->files[mainw->ascrap_file]->cb_src)
+        add_to_ascrap_mb(bytes);
+      if (mainw->aud_data_written>AUD_WRITTEN_CHECK) {
+        mainw->aud_data_written=0;
+        check_for_disk_space();
+      }
+      if (bytes<target) mainw->bad_aud_file=filename_from_fd(NULL,mainw->aud_rec_fd);
+    }
   }
 
   lives_free(holding_buff);
@@ -1132,7 +1137,7 @@ static int audio_read(nframes_t nframes, void *arg) {
   }
 
   if (jackd->playing_file==-1) out_scale=1.0; // just listening
-  else out_scale=(float)jackd->sample_in_rate/(float)afile->arate;
+  else out_scale=(float)afile->arate/(float)jackd->sample_in_rate; // recording to ascrap_file
 
   out_unsigned=afile->signed_endian&AFORM_UNSIGNED;
 
@@ -1224,10 +1229,6 @@ static void jack_error_func(const char *desc) {
 }
 
 
-// wait 5 seconds to startup
-#define JACK_START_WAIT 500000000
-
-
 // create a new client and connect it to jack, connect the ports
 int jack_open_device(jack_driver_t *jackd) {
   const char *client_name="LiVES_audio_out";
@@ -1250,7 +1251,7 @@ int jack_open_device(jack_driver_t *jackd) {
 
   stime=lives_get_current_ticks();
 
-  while (jackd->client==NULL&&ntime<JACK_START_WAIT) {
+  while (jackd->client==NULL&&ntime<LIVES_SHORT_TIMEOUT) {
     jackd->client = jack_client_open(client_name, options, &status, server_name);
 
     lives_usleep(prefs->sleep_time);
@@ -1708,7 +1709,7 @@ uint64_t lives_jack_get_time(jack_driver_t *jackd, boolean absolute) {
 
   if (msg!=NULL&&msg->command==ASERVER_CMD_FILE_SEEK) {
     boolean timeout;
-    int alarm_handle=lives_alarm_set(LIVES_ACONNECT_TIMEOUT);
+    int alarm_handle=lives_alarm_set(LIVES_DEFAULT_TIMEOUT);
     while (!(timeout=lives_alarm_get(alarm_handle))&&jack_get_msgq(jackd)!=NULL) {
       sched_yield(); // wait for seek
     }
@@ -1738,7 +1739,7 @@ boolean jack_audio_seek_frame(jack_driver_t *jackd, int frame) {
 
   volatile aserver_message_t *jmsg;
   int64_t seekstart;
-  int alarm_handle=lives_alarm_set(LIVES_ACONNECT_TIMEOUT);
+  int alarm_handle=lives_alarm_set(LIVES_DEFAULT_TIMEOUT);
   boolean timeout;
 
   if (alarm_handle==-1) return FALSE;
@@ -1770,7 +1771,7 @@ int64_t jack_audio_seek_bytes(jack_driver_t *jackd, int64_t bytes) {
   int64_t seekstart;
 
   boolean timeout;
-  int alarm_handle=lives_alarm_set(LIVES_ACONNECT_TIMEOUT);
+  int alarm_handle=lives_alarm_set(LIVES_DEFAULT_TIMEOUT);
 
   seek_err=FALSE;
 
@@ -1850,12 +1851,12 @@ void jack_aud_pb_ready(int fileno) {
     if (sfile->achans>0&&(!mainw->preview||(mainw->preview&&mainw->is_processing))&&
         (sfile->laudio_time>0.||sfile->opening||
          (mainw->multitrack!=NULL&&mainw->multitrack->is_rendering&&
-          lives_file_test((tmpfilename=lives_build_filename(prefs->tmpdir,sfile->handle,"audio",NULL)),
+          lives_file_test((tmpfilename=lives_build_filename(prefs->workdir,sfile->handle,"audio",NULL)),
                           LIVES_FILE_TEST_EXISTS)))) {
       boolean timeout;
       int alarm_handle;
 
-      if (tmpfilename!=NULL) lives_free(tmpfilename);
+      lives_freep((void **)&tmpfilename);
       mainw->jackd->num_input_channels=sfile->achans;
       mainw->jackd->bytes_per_channel=sfile->asampsize/8;
       mainw->jackd->sample_in_rate=sfile->arate;
@@ -1866,7 +1867,7 @@ void jack_aud_pb_ready(int fileno) {
         mainw->jackd->reverse_endian=TRUE;
       else mainw->jackd->reverse_endian=FALSE;
 
-      alarm_handle=lives_alarm_set(LIVES_ACONNECT_TIMEOUT);
+      alarm_handle=lives_alarm_set(LIVES_DEFAULT_TIMEOUT);
       while (!(timeout=lives_alarm_get(alarm_handle))&&jack_get_msgq(mainw->jackd)!=NULL) {
         sched_yield(); // wait for seek
       }
