@@ -1,6 +1,6 @@
 // ldvinterface.c
 // LiVES
-// (c) G. Finch 2006-2015 <salsaman@gmail.com>
+// (c) G. Finch 2006-2016 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -8,7 +8,7 @@
 #include "support.h"
 #include "ldvcallbacks.h"
 #include "ldvinterface.h"
-
+#include "callbacks.h"
 
 struct _dvgrabw *create_camwindow(s_cam *cam, int type) {
   LiVESWidget *hbuttonbox1;
@@ -24,7 +24,7 @@ struct _dvgrabw *create_camwindow(s_cam *cam, int type) {
 
   dvgrabw->filename=NULL;
 
-  dvgrabw->dialog = lives_standard_dialog_new(_("LiVES: DVGrab"),FALSE,-1,-1);
+  dvgrabw->dialog = lives_standard_dialog_new(_("DVGrab"),FALSE,-1,-1);
   dvgrabw->playing=FALSE;
 
   if (prefs->show_gui) {
@@ -135,9 +135,6 @@ struct _dvgrabw *create_camwindow(s_cam *cam, int type) {
   lives_signal_connect(dvgrabw->grab, LIVES_WIDGET_CLICKED_SIGNAL,LIVES_GUI_CALLBACK(on_camgrab_clicked),(livespointer)cam);
   lives_signal_connect(dvgrabw->quit, LIVES_WIDGET_CLICKED_SIGNAL,LIVES_GUI_CALLBACK(on_camquit_clicked),(livespointer)cam);
 
-
-  lives_widget_show_all(dvgrabw->dialog);
-
   return dvgrabw;
 }
 
