@@ -1,6 +1,6 @@
 // yuv4mpeg.c
 // LiVES
-// (c) G. Finch 2004 - 2015 <salsaman@gmail.com>
+// (c) G. Finch 2004 - 2016 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -15,10 +15,11 @@
 #endif
 
 #include "main.h"
-
 #include "support.h"
 #include "interface.h"
 #include "lives-yuv4mpeg.h"
+#include "effects-weed.h"
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
@@ -59,7 +60,7 @@ static lives_yuv4m_t *lives_yuv4mpeg_alloc(void) {
 
 static void *y4open_thread(void *arg) {
   y4data *thread_data=(y4data *)arg;
-  int fd=open(thread_data->filename,O_RDONLY);
+  int fd=lives_open2(thread_data->filename,O_RDONLY);
   thread_data->fd=fd;
   pthread_exit(NULL);
 }
@@ -123,10 +124,6 @@ static void *y4frame_thread(void *arg) {
 
 
 
-#define YUV4_O_TIME 200000000 // ticks to wait to open fifo
-#define YUV4_H_TIME 500000000 // ticks to wait to get stream header
-
-
 static boolean lives_yuv_stream_start_read(lives_clip_t *sfile) {
   double ofps=sfile->fps;
 
@@ -155,7 +152,7 @@ static boolean lives_yuv_stream_start_read(lives_clip_t *sfile) {
 
     pthread_create(&y4thread,NULL,y4open_thread,(void *)&thread_data);
 
-    alarm_handle=lives_alarm_set(YUV4_O_TIME);
+    alarm_handle=lives_alarm_set(LIVES_SHORTEST_TIMEOUT);
 
     d_print("");
     d_print(_("Waiting for yuv4mpeg frames..."));
@@ -200,7 +197,7 @@ static boolean lives_yuv_stream_start_read(lives_clip_t *sfile) {
   // create a thread to open the stream header
   thread_data.yuv4mpeg=yuv4mpeg;
   pthread_create(&y4thread,NULL,y4header_thread,&thread_data);
-  alarm_handle=lives_alarm_set(YUV4_H_TIME);
+  alarm_handle=lives_alarm_set(LIVES_SHORT_TIMEOUT);
 
   while (!lives_alarm_get(alarm_handle)&&!pthread_kill(y4thread,0)) {
     // wait for thread to complete or timeout
@@ -267,7 +264,7 @@ void lives_yuv_stream_stop_read(lives_yuv4m_t *yuv4mpeg) {
   if (yuv4mpeg->fd!=-1) close(yuv4mpeg->fd);
 
   if (yuv4mpeg->filename!=NULL) {
-    unlink(yuv4mpeg->filename);
+    lives_rm(yuv4mpeg->filename);
     lives_free(yuv4mpeg->filename);
   }
 
@@ -279,7 +276,6 @@ void lives_yuv_stream_stop_read(lives_yuv4m_t *yuv4mpeg) {
 
 }
 
-#define YUV4_F_TIME 200000000 // ticks to wait to get stream header
 
 
 void weed_layer_set_from_yuv4m(weed_plant_t *layer, lives_clip_t *sfile) {
@@ -295,10 +291,10 @@ void weed_layer_set_from_yuv4m(weed_plant_t *layer, lives_clip_t *sfile) {
 
   if (!yuv4mpeg->ready) lives_yuv_stream_start_read(sfile);
 
-  weed_set_int_value(layer,"width",sfile->hsize);
-  weed_set_int_value(layer,"height",sfile->vsize);
-  weed_set_int_value(layer,"current_palette",WEED_PALETTE_YUV420P);
-  weed_set_int_value(layer,"YUV_subspace",WEED_YUV_SUBSPACE_YCBCR);
+  weed_set_int_value(layer,WEED_LEAF_WIDTH,sfile->hsize);
+  weed_set_int_value(layer,WEED_LEAF_HEIGHT,sfile->vsize);
+  weed_set_int_value(layer,WEED_LEAF_CURRENT_PALETTE,WEED_PALETTE_YUV420P);
+  weed_set_int_value(layer,WEED_LEAF_YUV_SUBSPACE,WEED_YUV_SUBSPACE_YCBCR);
 
   create_empty_pixel_data(layer,TRUE,TRUE);
 
@@ -306,14 +302,14 @@ void weed_layer_set_from_yuv4m(weed_plant_t *layer, lives_clip_t *sfile) {
     return;
   }
 
-  yuv4mpeg->pixel_data=weed_get_voidptr_array(layer,"pixel_data",&error);
+  yuv4mpeg->pixel_data=weed_get_voidptr_array(layer,WEED_LEAF_PIXEL_DATA,&error);
 
   // create a thread to open the stream header
 
   thread_data.yuv4mpeg=yuv4mpeg;
   pthread_create(&y4thread,NULL,y4frame_thread,&thread_data);
 
-  alarm_handle=lives_alarm_set(YUV4_F_TIME);
+  alarm_handle=lives_alarm_set(LIVES_SHORTEST_TIMEOUT);
 
   while (!lives_alarm_get(alarm_handle)&&!pthread_kill(y4thread,0)) {
     // wait for thread to complete or timeout
@@ -334,7 +330,7 @@ void weed_layer_set_from_yuv4m(weed_plant_t *layer, lives_clip_t *sfile) {
   lives_free(yuv4mpeg->pixel_data);
   yuv4mpeg->pixel_data=NULL;
 
-  weed_set_int_value(layer,"YUV_sampling",WEED_YUV_SAMPLING_MPEG);
+  weed_set_int_value(layer,WEED_LEAF_YUV_SAMPLING,WEED_YUV_SAMPLING_MPEG);
 
   return;
 }
@@ -370,6 +366,8 @@ static boolean open_yuv4m_inner(const char *filename, const char *fname, int new
   cfile->hsize=DEF_GEN_WIDTH;
   cfile->vsize=DEF_GEN_HEIGHT;
 
+  cfile->img_type=IMG_TYPE_BEST; // override the pref
+
   cfile->is_loaded=TRUE;
 
   add_to_clipmenu();
@@ -406,7 +404,7 @@ void on_open_yuv4m_activate(LiVESMenuItem *menuitem, livespointer user_data) {
   mainw->current_file=new_file;
 
   if (!strlen(prefs->yuvin))
-    filename=lives_build_filename(prefs->tmpdir,"stream.yuv",NULL);
+    filename=lives_build_filename(prefs->workdir,"stream.yuv",NULL);
   else
     filename=lives_strdup(prefs->yuvin);
 
@@ -453,23 +451,17 @@ void on_open_yuv4m_activate(LiVESMenuItem *menuitem, livespointer user_data) {
     // and we dont really care if it doesnt work
 
     // but what it means is, if we have an audio file or stream at
-    // "prefs->tmpdir/audiodump.pcm" we will try to play it
+    // "prefs->workdir/audiodump.pcm" we will try to play it
 
 
 
-    // real is tmpdir/audiodump.pcm
-    audio_real=lives_build_filename(prefs->tmpdir,"audiodump.pcm",NULL);
-    // fake is tmpdir/handle/audiodump.pcm
-    audio_fake=lives_build_filename(prefs->tmpdir,cfile->handle,"audiodump.pcm",NULL);
+    // real is workdir/audiodump.pcm
+    audio_real=lives_build_filename(prefs->workdir,"audiodump.pcm",NULL);
+    // fake is workdir/handle/audiodump.pcm
+    audio_fake=lives_build_filename(prefs->workdir,cfile->handle,"audiodump.pcm",NULL);
 
-
-#ifndef IS_MINGW
     // fake file will go away when we close the current clip
-    lives_system((tmp=lives_strdup_printf("%s -s \"%s\" \"%s\" >/dev/null 2>&1",capable->ln_cmd,
-                                          audio_real,audio_fake)),TRUE);
-#else
-    // TODO
-#endif
+    lives_ln(audio_real,audio_fake);
 
     lives_free(audio_real);
     lives_free(audio_fake);
@@ -507,7 +499,7 @@ boolean lives_yuv_stream_start_write(lives_yuv4m_t *yuv4mpeg, const char *filena
   }
   mainw->fixed_fpsd=fps;
 
-  if (filename==NULL) filename=lives_strdup_printf("%s/streamout.yuv",prefs->tmpdir);
+  if (filename==NULL) filename=lives_strdup_printf("%s/streamout.yuv",prefs->workdir);
 
   // TODO - do_threaded_dialog
   if ((yuvout=creat(filename,O_CREAT))<0) {
@@ -597,7 +589,7 @@ void on_live_tvcard_activate(LiVESMenuItem *menuitem, livespointer user_data) {
   int response;
 
   char *com,*tmp;
-  char *fifofile=lives_strdup_printf("%s/tvpic_%d.y4m",prefs->tmpdir,capable->mainpid);
+  char *fifofile;
 
   char *chanstr;
   char *devstr;
@@ -608,13 +600,19 @@ void on_live_tvcard_activate(LiVESMenuItem *menuitem, livespointer user_data) {
 
   lives_tvcardw_t *tvcardw;
 
+  if (!capable->has_mplayer&&!capable->has_mplayer2) {
+    do_need_mplayer_dialog();
+    return;
+  }
+
+  fifofile=lives_strdup_printf("%s/tvpic_%d.y4m",prefs->workdir,capable->mainpid);
+
   mainw->open_deint=FALSE;
 
-  card_dialog=create_cdtrack_dialog(4,NULL);
+  card_dialog=create_cdtrack_dialog(LIVES_DEVICE_TV_CARD,NULL);
 
   tvcardw=(lives_tvcardw_t *)lives_widget_object_get_data(LIVES_WIDGET_OBJECT(card_dialog),"tvcard_data");
 
-
   response=lives_dialog_run(LIVES_DIALOG(card_dialog));
   if (response==LIVES_RESPONSE_CANCEL) {
     lives_widget_destroy(card_dialog);
@@ -665,7 +663,7 @@ void on_live_tvcard_activate(LiVESMenuItem *menuitem, livespointer user_data) {
 
   cfile->deinterlace=mainw->open_deint;
 
-  unlink(fifofile);
+  lives_rm(fifofile);
   mkfifo(fifofile,S_IRUSR|S_IWUSR);
 
   if (!tvcardw->use_advanced) {
@@ -741,14 +739,14 @@ void on_live_fw_activate(LiVESMenuItem *menuitem, livespointer user_data) {
 
   int response;
 
-  char *fifofile=lives_strdup_printf("%s/firew_%d.y4m",prefs->tmpdir,capable->mainpid);
+  char *fifofile=lives_strdup_printf("%s/firew_%d.y4m",prefs->workdir,capable->mainpid);
   char *fname;
 
   LiVESWidget *card_dialog;
 
   mainw->open_deint=FALSE;
 
-  card_dialog=create_cdtrack_dialog(5,NULL);
+  card_dialog=create_cdtrack_dialog(LIVES_DEVICE_FW_CARD,NULL);
   response=lives_dialog_run(LIVES_DIALOG(card_dialog));
   if (response==LIVES_RESPONSE_CANCEL) {
     lives_widget_destroy(card_dialog);
@@ -779,7 +777,7 @@ void on_live_fw_activate(LiVESMenuItem *menuitem, livespointer user_data) {
   mainw->current_file=new_file;
   cfile->deinterlace=mainw->open_deint;
 
-  unlink(fifofile);
+  lives_rm(fifofile);
   mkfifo(fifofile,S_IRUSR|S_IWUSR);
 
   com=lives_strdup_printf("%s open_fw_card \"%s\" %d %d \"%s\"",prefs->backend,cfile->handle,cardno,cache,fifofile);
