@@ -1,6 +1,6 @@
 // merge.c
 // LiVES (lives-exe)
-// (c) G. Finch 2003 - 2015 (salsaman@gmail.com)
+// (c) G. Finch 2003 - 2016 (salsaman@gmail.com)
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -17,6 +17,7 @@
 #include "effects.h"
 #include "resample.h"
 #include "support.h"
+#include "callbacks.h"
 
 _merge_opts *merge_opts;
 
@@ -92,7 +93,8 @@ void create_merge_dialog(void) {
   height=scrh-SCR_HEIGHT_SAFETY;
   width=scrw-SCR_WIDTH_SAFETY;
 
-  merge_opts->merge_dialog = lives_standard_dialog_new(_("LiVES: - Merge"),FALSE,width,height);
+  merge_opts->merge_dialog = lives_standard_dialog_new(_("Merge"),FALSE,width,height);
+  lives_signal_handlers_disconnect_by_func(merge_opts->merge_dialog,return_true,NULL);
 
   accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new());
   lives_window_add_accel_group(LIVES_WINDOW(merge_opts->merge_dialog), accel_group);
@@ -206,8 +208,7 @@ void create_merge_dialog(void) {
   if (retvals!=NULL) {
     // now apply visually anything we got from onchange_init
     //param_demarshall (rfx,retvals,TRUE,TRUE);
-    lives_list_free_strings(retvals);
-    lives_list_free(retvals);
+    lives_list_free_all(&retvals);
   }
 
   // done !
@@ -287,8 +288,7 @@ void on_trans_method_changed(LiVESCombo *combo, livespointer user_data) {
   if (retvals!=NULL) {
     // now apply visually anything we got from onchange_init
     param_demarshall(rfx,retvals,TRUE,TRUE);
-    lives_list_free_strings(retvals);
-    lives_list_free(retvals);
+    lives_list_free_all(&retvals);
   }
 
   merge_opts->align_start=!merge_opts->align_start;
@@ -320,8 +320,7 @@ void on_merge_cancel_clicked(LiVESButton *button, livespointer user_data) {
   mainw->last_transition_loop_to_fit=merge_opts->loop_to_fit;
   mainw->last_transition_ins_frames=merge_opts->ins_frames;
   mainw->last_transition_align_start=merge_opts->align_start;
-  lives_list_free_strings(merge_opts->trans_list);
-  lives_list_free(merge_opts->trans_list);
+  lives_list_free_all(&merge_opts->trans_list);
   lives_free(merge_opts->list_to_rfx_index);
   lives_free(merge_opts);
 }
