@@ -38,6 +38,8 @@
 
 #define TIMELINE_TABLE_COLUMNS 40
 
+#define MENUBAR_MIN 1024
+
 ////////////////////////////////////////////////////////////////////////////////
 
 #define BLOCK_DRAW_SIMPLE 1
@@ -338,12 +340,51 @@ struct _mt {
   LiVESWidget *nb;
   LiVESWidget *nb_label;
 
+  LiVESWidget *eventbox;
+  LiVESWidget *scroll_label;
+  LiVESWidget *preview_frame;
+  LiVESWidget *preview_eventbox;
+  LiVESWidget *btoolbarx;
+  LiVESWidget *btoolbary;
+  LiVESWidget *time_label;
+  LiVESWidget *insa_label;
+  LiVESWidget *overlap_label;
+  LiVESWidget *amix_label;
+  LiVESWidget *tl_label;
+  LiVESWidget *dumlabel1;
+  LiVESWidget *dumlabel2;
+  LiVESWidget *top_eventbox;
+  LiVESWidget *tlx_eventbox;
+  LiVESWidget *amixb_eventbox;
+
+  LiVESWidget *grav_submenu;
+  LiVESWidget *ins_submenu;
+  LiVESWidget *mm_submenu;
+  LiVESWidget *ins_label;
+  LiVESWidget *mm_label;
+
+  LiVESWidget *nb_label1;
+  LiVESWidget *nb_label2;
+  LiVESWidget *nb_label3;
+  LiVESWidget *nb_label4;
+  LiVESWidget *nb_label5;
+  LiVESWidget *nb_label6;
+  LiVESWidget *nb_label7;
+
+  LiVESToolItem *sep1;
+  LiVESToolItem *sep2;
+  LiVESToolItem *sep3;
+  LiVESToolItem *sep4;
+
   LiVESWidget *btoolbar;
   LiVESWidget *btoolbar2;
   LiVESWidget *btoolbar3;
 
   LiVESWidget *menu_hbox;
 
+  LiVESWidget *hseparator;
+  LiVESWidget *hseparator2;
+
   LiVESWidget *open_menu;
 #ifdef HAVE_WEBM
   LiVESWidget *open_loc_menu;
@@ -510,7 +551,7 @@ struct _mt {
   boolean changed; ///< changed since last saved
   boolean auto_changed; ///< changed since last auto-saved
 
-  int64_t auto_back_time;
+  int64_t auto_back_time; ///< time when last backup was done (not to be confused with prefs->auto_back)
 
   // stuff to do with framedraw "special" widgets
   int inwidth;
@@ -690,6 +731,9 @@ lives_mt *multitrack(weed_plant_t *, int orig_file, double fps);  ///< create an
 void mt_init_tracks(lives_mt *, boolean set_min_max);   ///< add basic tracks, or set tracks from mt->event_list
 boolean on_multitrack_activate(LiVESMenuItem *menuitem, weed_plant_t *event_list);  ///< menuitem callback
 
+// theming
+void set_mt_colours(lives_mt *);
+
 // delete function
 boolean multitrack_delete(lives_mt *, boolean save);
 
@@ -800,6 +844,7 @@ int get_clip_for_block(track_rect *block);
 
 
 // timeline functions
+boolean resize_timeline(lives_mt *);
 void mt_tl_move_relative(lives_mt *, double pos_rel);
 void mt_tl_move(lives_mt *, double pos_abs);
 void set_timeline_end_secs(lives_mt *, double secs);
@@ -916,6 +961,7 @@ uint32_t mt_idle_add(lives_mt *);
 void recover_layout(void);
 void recover_layout_cancelled(boolean is_startup);
 boolean write_backup_layout_numbering(lives_mt *);
+boolean mt_auto_backup(livespointer mt);
 
 
 // amixer funcs
