@@ -1,6 +1,6 @@
 // omc-learn.c
 // LiVES (lives-exe)
-// (c) G. Finch 2008 - 2015
+// (c) G. Finch 2008 - 2016
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -633,10 +633,11 @@ static void cell1_edited_callback(LiVESCellRenderer *spinbutton, const char *pat
 }
 
 
+#if GTK_CHECK_VERSION(3,0,0)
 static void rowexpand(LiVESWidget *tv, LiVESTreeIter *iter, LiVESTreePath *path, livespointer ud) {
   lives_widget_queue_resize(tv);
 }
-
+#endif
 
 static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, int row, omclearn_w *omclw) {
   lives_omc_macro_t macro=omc_macros[mnode->macro];
@@ -646,7 +647,7 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, int row, omc
 
   LiVESTreeIter iter1,iter2;
 
-  LiVESObject *spinadj;
+  LiVESAdjustment *adj;
 
   char *strval=NULL,*vname;
   char *oldval=NULL,*final=NULL;
@@ -655,7 +656,7 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, int row, omc
   register int i;
 
 
-  mnode->gtkstore2 = lives_tree_store_new(NUM2_COLUMNS, LIVES_COL_TYPE_STRING, LIVES_COL_TYPE_STRING, LIVES_COL_TYPE_STRING);
+  mnode->gtkstore2 = lives_tree_store_new(NUM2_COLUMNS, LIVES_COL_TYPE_STRING, LIVES_COL_TYPE_STRING, LIVES_COL_TYPE_OBJECT);
 
   if (macro.nparams==0) return;
 
@@ -675,14 +676,18 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, int row, omc
       final=NULL;
     }
 
+    adj=NULL;
+
     if ((mfrom=mnode->map[i])!=-1) strval=lives_strdup(_("variable"));
     else {
       switch (macro.ptypes[i]) {
       case OMC_PARAM_INT:
         strval=lives_strdup_printf("%d",mnode->fvali[i]);
+        adj=lives_adjustment_new(mnode->fvali[i],macro.mini[i],macro.maxi[i],1.,1.,0.);
         break;
       case OMC_PARAM_DOUBLE:
         strval=lives_strdup_printf("%.*f",OMC_FP_FIX,mnode->fvald[i]);
+        adj=lives_adjustment_new(mnode->fvald[i],macro.mind[i],macro.maxd[i],1.,1.,0.);
         break;
 
       }
@@ -690,7 +695,7 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, int row, omc
 
     vname=macro.pname[i];
 
-    lives_tree_store_set(mnode->gtkstore2, &iter2, TITLE2_COLUMN, vname, VALUE2_COLUMN, strval, -1);
+    lives_tree_store_set(mnode->gtkstore2, &iter2, TITLE2_COLUMN, vname, VALUE2_COLUMN, strval, ADJUSTMENT, adj, -1);
   }
 
   lives_free(strval);
@@ -705,38 +710,41 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, int row, omc
   renderer = lives_cell_renderer_text_new();
   column = lives_tree_view_column_new_with_attributes(NULL,
            renderer,
-           "text", TITLE2_COLUMN,
+           LIVES_TREE_VIEW_COLUMN_TEXT, TITLE2_COLUMN,
            NULL);
 
   lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev2), column);
 
   renderer = lives_cell_renderer_spin_new();
 
-  spinadj=(LiVESObject *)lives_adjustment_new(0., -100000., 100000., 1., 10., 0);
+  if (renderer!=NULL) {
 
 #ifdef GUI_GTK
-  g_object_set(renderer, "width-chars", 7, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
-               "editable", TRUE, "xalign", 1.0, "adjustment", spinadj, NULL);
+    g_object_set(renderer, "width-chars", 7, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
+                 "editable", TRUE, "xalign", 1.0, NULL);
 
 #endif
 
-  lives_signal_connect(renderer, LIVES_WIDGET_EDITED_SIGNAL, LIVES_GUI_CALLBACK(cell1_edited_callback), mnode);
+    lives_signal_connect(renderer, LIVES_WIDGET_EDITED_SIGNAL, LIVES_GUI_CALLBACK(cell1_edited_callback), mnode);
 
 
+    //  renderer = lives_cell_renderer_text_new ();
+    column = lives_tree_view_column_new_with_attributes(_("value"),
+             renderer,
+             LIVES_TREE_VIEW_COLUMN_TEXT, VALUE2_COLUMN,
+             "adjustment", ADJUSTMENT,
+             NULL);
+    lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev2), column);
 
-  //  renderer = lives_cell_renderer_text_new ();
-  column = lives_tree_view_column_new_with_attributes(_("value"),
-           renderer,
-           "text", VALUE2_COLUMN,
-           NULL);
-  lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev2), column);
-
+  }
 
   lives_widget_show(mnode->treev2);
 
+#if GTK_CHECK_VERSION(3,0,0)
   lives_signal_connect(LIVES_GUI_OBJECT(mnode->treev2), LIVES_WIDGET_ROW_EXPANDED_SIGNAL,
                        LIVES_GUI_CALLBACK(rowexpand),
                        NULL);
+#endif
 
   lives_table_attach(LIVES_TABLE(omclw->table), mnode->treev2, 3, 4, row, row+1,
                      (LiVESAttachOptions)(LIVES_FILL|LIVES_EXPAND),
@@ -765,8 +773,10 @@ static void omc_learn_link_params(lives_omc_match_node_t *mnode) {
 
   if (lps>mps) lps=mps;
 
-  for (i=mps; i>=0; i--) {
-    if (mnode->matchp[lps]) lps++; // variable is filtered for
+  if (lps>=0) {
+    for (i=mps; i>=0; i--) {
+      if (mnode->matchp[lps]) lps++; // variable is filtered for
+    }
   }
 
   for (i=mps; i>=0; i--) {
@@ -1094,7 +1104,7 @@ static void omc_learner_add_row(int type, int detail, lives_omc_match_node_t *mn
   renderer = lives_cell_renderer_text_new();
   column = lives_tree_view_column_new_with_attributes(NULL,
            renderer,
-           "text", TITLE_COLUMN,
+           LIVES_TREE_VIEW_COLUMN_TEXT, TITLE_COLUMN,
            NULL);
 
   lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev1), column);
@@ -1102,7 +1112,7 @@ static void omc_learner_add_row(int type, int detail, lives_omc_match_node_t *mn
   renderer = lives_cell_renderer_text_new();
   column = lives_tree_view_column_new_with_attributes(_("value"),
            renderer,
-           "text", VALUE_COLUMN,
+           LIVES_TREE_VIEW_COLUMN_TEXT, VALUE_COLUMN,
            NULL);
   lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev1), column);
 
@@ -1119,70 +1129,78 @@ static void omc_learner_add_row(int type, int detail, lives_omc_match_node_t *mn
   renderer = lives_cell_renderer_text_new();
   column = lives_tree_view_column_new_with_attributes(_("range"),
            renderer,
-           "text", RANGE_COLUMN,
+           LIVES_TREE_VIEW_COLUMN_TEXT, RANGE_COLUMN,
            NULL);
   lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev1), column);
 
 
   renderer = lives_cell_renderer_spin_new();
-  lives_widget_object_set_data(LIVES_WIDGET_OBJECT(renderer), "colnum", LIVES_UINT_TO_POINTER(OFFS1_COLUMN));
 
-  spinadj=(LiVESObject *)lives_adjustment_new(0., -100000., 100000., 1., 10., 0);
+  if (renderer!=NULL) {
+    lives_widget_object_set_data(LIVES_WIDGET_OBJECT(renderer), "colnum", LIVES_UINT_TO_POINTER(OFFS1_COLUMN));
+
+    spinadj=(LiVESObject *)lives_adjustment_new(0., -100000., 100000., 1., 10., 0);
 
 #ifdef GUI_GTK
-  g_object_set(renderer, "width-chars", 7, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
-               "editable", TRUE, "xalign", 1.0, "adjustment", spinadj, NULL);
+    g_object_set(renderer, "width-chars", 7, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
+                 "editable", TRUE, "xalign", 1.0, "adjustment", spinadj, NULL);
 #endif
 
-  lives_signal_connect(renderer, LIVES_WIDGET_EDITED_SIGNAL, LIVES_GUI_CALLBACK(cell_edited_callback), mnode);
+    lives_signal_connect(renderer, LIVES_WIDGET_EDITED_SIGNAL, LIVES_GUI_CALLBACK(cell_edited_callback), mnode);
 
 
 
-  column = lives_tree_view_column_new_with_attributes(_("+ offset1"),
-           renderer,
-           "text", OFFS1_COLUMN,
-           NULL);
-  lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev1), column);
+    column = lives_tree_view_column_new_with_attributes(_("+ offset1"),
+             renderer,
+             LIVES_TREE_VIEW_COLUMN_TEXT, OFFS1_COLUMN,
+             NULL);
+    lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev1), column);
+  }
 
   renderer = lives_cell_renderer_spin_new();
 
-  spinadj=(LiVESObject *)lives_adjustment_new(1., -100000., 100000., 1., 10., 0);
+  if (renderer!=NULL) {
+
+    spinadj=(LiVESObject *)lives_adjustment_new(1., -100000., 100000., 1., 10., 0);
 
 #ifdef GUI_GTK
-  g_object_set(renderer, "width-chars", 12, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
-               "editable", TRUE, "xalign", 1.0, "adjustment", spinadj,
-               "digits", OMC_FP_FIX, NULL);
+    g_object_set(renderer, "width-chars", 12, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
+                 "editable", TRUE, "xalign", 1.0, "adjustment", spinadj,
+                 "digits", OMC_FP_FIX, NULL);
 #endif
 
-  lives_widget_object_set_data(LIVES_WIDGET_OBJECT(renderer), "colnum", LIVES_UINT_TO_POINTER(SCALE_COLUMN));
-  lives_signal_connect(renderer, LIVES_WIDGET_EDITED_SIGNAL, LIVES_GUI_CALLBACK(cell_edited_callback), mnode);
+    lives_widget_object_set_data(LIVES_WIDGET_OBJECT(renderer), "colnum", LIVES_UINT_TO_POINTER(SCALE_COLUMN));
+    lives_signal_connect(renderer, LIVES_WIDGET_EDITED_SIGNAL, LIVES_GUI_CALLBACK(cell_edited_callback), mnode);
 
 
-  column = lives_tree_view_column_new_with_attributes(_("* scale"),
-           renderer,
-           "text", SCALE_COLUMN,
-           NULL);
-  lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev1), column);
+    column = lives_tree_view_column_new_with_attributes(_("* scale"),
+             renderer,
+             LIVES_TREE_VIEW_COLUMN_TEXT, SCALE_COLUMN,
+             NULL);
+    lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev1), column);
+
+  }
 
   renderer = lives_cell_renderer_spin_new();
 
-
-  spinadj=(LiVESObject *)lives_adjustment_new(0., -100000., 100000., 1., 10., 0);
+  if (renderer!=NULL) {
+    spinadj=(LiVESObject *)lives_adjustment_new(0., -100000., 100000., 1., 10., 0);
 
 #ifdef GUI_GTK
-  g_object_set(renderer, "width-chars", 7, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
-               "editable", TRUE, "xalign", 1.0, "adjustment", spinadj, NULL);
+    g_object_set(renderer, "width-chars", 7, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
+                 "editable", TRUE, "xalign", 1.0, "adjustment", spinadj, NULL);
 #endif
 
-  lives_widget_object_set_data(LIVES_WIDGET_OBJECT(renderer), "colnum", LIVES_UINT_TO_POINTER(OFFS2_COLUMN));
-  lives_signal_connect(renderer, LIVES_WIDGET_EDITED_SIGNAL, LIVES_GUI_CALLBACK(cell_edited_callback), mnode);
+    lives_widget_object_set_data(LIVES_WIDGET_OBJECT(renderer), "colnum", LIVES_UINT_TO_POINTER(OFFS2_COLUMN));
+    lives_signal_connect(renderer, LIVES_WIDGET_EDITED_SIGNAL, LIVES_GUI_CALLBACK(cell_edited_callback), mnode);
 
 
-  column = lives_tree_view_column_new_with_attributes(_("+ offset2"),
-           renderer,
-           "text", OFFS2_COLUMN,
-           NULL);
-  lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev1), column);
+    column = lives_tree_view_column_new_with_attributes(_("+ offset2"),
+             renderer,
+             LIVES_TREE_VIEW_COLUMN_TEXT, OFFS2_COLUMN,
+             NULL);
+    lives_tree_view_append_column(LIVES_TREE_VIEW(mnode->treev1), column);
+  }
 
   lives_widget_show(mnode->treev1);
 
@@ -1191,12 +1209,14 @@ static void omc_learner_add_row(int type, int detail, lives_omc_match_node_t *mn
 #endif
 
   lives_table_attach(LIVES_TABLE(omclw->table), mnode->treev1, 1, 2, omclw->tbl_currow, omclw->tbl_currow+1,
-                     (LiVESAttachOptions)(0),
+                     (LiVESAttachOptions)(LIVES_FILL|LIVES_EXPAND),
                      (LiVESAttachOptions)(LIVES_EXPAND), 0, 0);
 
+#if GTK_CHECK_VERSION(3,0,0)
   lives_signal_connect(LIVES_GUI_OBJECT(mnode->treev1), LIVES_WIDGET_ROW_EXPANDED_SIGNAL,
                        LIVES_GUI_CALLBACK(rowexpand),
                        NULL);
+#endif
 
   combo=create_omc_macro_combo(mnode,omclw->tbl_currow,omclw);
 
@@ -1325,7 +1345,8 @@ static omclearn_w *create_omclearn_dialog(void) {
   winsize_h=scr_width-SCR_WIDTH_SAFETY;
   winsize_v=scr_height-SCR_HEIGHT_SAFETY;
 
-  omclw->dialog = lives_standard_dialog_new(_("LiVES: OMC learner"),FALSE,winsize_h,winsize_v);
+  omclw->dialog = lives_standard_dialog_new(_("OMC Learner"),FALSE,winsize_h,winsize_v);
+  lives_signal_handlers_disconnect_by_func(omclw->dialog,return_true,NULL);
 
   omclw->top_vbox = lives_dialog_get_content_area(LIVES_DIALOG(omclw->dialog));
 
@@ -2197,16 +2218,16 @@ static void write_fx_tag(const char *string, int nfixed, lives_omc_match_node_t
 
         filter=rte_keymode_get_filter(oval0,mode);
 
-        ntmpls=weed_leaf_num_elements(filter,"in_parameter_templates");
+        ntmpls=weed_leaf_num_elements(filter,WEED_LEAF_IN_PARAMETER_TEMPLATES);
 
-        ptmpls=weed_get_plantptr_array(filter,"in_parameter_templates",&error);
+        ptmpls=weed_get_plantptr_array(filter,WEED_LEAF_IN_PARAMETER_TEMPLATES,&error);
         for (k=0; k<ntmpls; k++) {
           ptmpl=ptmpls[k];
-          if (weed_plant_has_leaf(ptmpl,"host_internal_connection")) continue;
-          hint=weed_get_int_value(ptmpl,"hint",&error);
-          flags=weed_get_int_value(ptmpl,"flags",&error);
+          if (weed_plant_has_leaf(ptmpl,WEED_LEAF_HOST_INTERNAL_CONNECTION)) continue;
+          hint=weed_get_int_value(ptmpl,WEED_LEAF_HINT,&error);
+          flags=weed_get_int_value(ptmpl,WEED_LEAF_FLAGS,&error);
           if (flags&WEED_PARAMETER_VARIABLE_ELEMENTS) flags^=WEED_PARAMETER_VARIABLE_ELEMENTS;
-          if ((hint==WEED_HINT_INTEGER||hint==WEED_HINT_FLOAT)&&flags==0&&weed_leaf_num_elements(ptmpl,"default")==1) {
+          if ((hint==WEED_HINT_INTEGER||hint==WEED_HINT_FLOAT)&&flags==0&&weed_leaf_num_elements(ptmpl,WEED_LEAF_DEFAULT)==1) {
             if (oval1==0) {
               if (hint==WEED_HINT_INTEGER) {
                 // **int
@@ -2304,14 +2325,14 @@ OSCbuf *omc_learner_decode(int type, int idx, const char *string) {
         if (macro==25 && i==1 && mainw->vpp!=NULL && mainw->vpp->play_params!=NULL && oval0<mainw->vpp->num_play_params) {
           // auto scale for playback plugin params
 
-          weed_plant_t *ptmpl=weed_get_plantptr_value((weed_plant_t *)pp_get_param(mainw->vpp->play_params,oval0),"template",&error);
-          hint=weed_get_int_value(ptmpl,"hint",&error);
-          if ((hint==WEED_HINT_INTEGER||hint==WEED_HINT_FLOAT)&&weed_leaf_num_elements(ptmpl,"default")==1) {
+          weed_plant_t *ptmpl=weed_get_plantptr_value((weed_plant_t *)pp_get_param(mainw->vpp->play_params,oval0),WEED_LEAF_TEMPLATE,&error);
+          hint=weed_get_int_value(ptmpl,WEED_LEAF_HINT,&error);
+          if ((hint==WEED_HINT_INTEGER||hint==WEED_HINT_FLOAT)&&weed_leaf_num_elements(ptmpl,WEED_LEAF_DEFAULT)==1) {
             if (hint==WEED_HINT_INTEGER) {
               int omin=mnode->min[j];
               int omax=mnode->max[j];
-              int mini=weed_get_int_value(ptmpl,"min",&error);
-              int maxi=weed_get_int_value(ptmpl,"max",&error);
+              int mini=weed_get_int_value(ptmpl,WEED_LEAF_MIN,&error);
+              int maxi=weed_get_int_value(ptmpl,WEED_LEAF_MAX,&error);
 
               int oval=(int)((double)(vals[j]-omin)/(double)(omax-omin)*(double)(maxi-mini))+mini;
               OSC_writeIntArg(&obuf,oval);
@@ -2319,8 +2340,8 @@ OSCbuf *omc_learner_decode(int type, int idx, const char *string) {
               // float
               int omin=mnode->min[j];
               int omax=mnode->max[j];
-              double minf=weed_get_double_value(ptmpl,"min",&error);
-              double maxf=weed_get_double_value(ptmpl,"max",&error);
+              double minf=weed_get_double_value(ptmpl,WEED_LEAF_MIN,&error);
+              double maxf=weed_get_double_value(ptmpl,WEED_LEAF_MAX,&error);
 
               double oval=(double)(vals[j]-omin)/(double)(omax-omin)*(maxf-minf)+minf;
               OSC_writeFloatArg(&obuf,(float)oval);
@@ -2338,21 +2359,21 @@ OSCbuf *omc_learner_decode(int type, int idx, const char *string) {
 
             filter=rte_keymode_get_filter(oval0,mode);
 
-            ntmpls=weed_leaf_num_elements(filter,"in_parameter_templates");
+            ntmpls=weed_leaf_num_elements(filter,WEED_LEAF_IN_PARAMETER_TEMPLATES);
 
-            ptmpls=weed_get_plantptr_array(filter,"in_parameter_templates",&error);
+            ptmpls=weed_get_plantptr_array(filter,WEED_LEAF_IN_PARAMETER_TEMPLATES,&error);
             for (k=0; k<ntmpls; k++) {
               ptmpl=ptmpls[k];
-              if (weed_plant_has_leaf(ptmpl,"host_internal_connection")) continue;
-              hint=weed_get_int_value(ptmpl,"hint",&error);
-              flags=weed_get_int_value(ptmpl,"flags",&error);
-              if ((hint==WEED_HINT_INTEGER||hint==WEED_HINT_FLOAT)&&flags==0&&weed_leaf_num_elements(ptmpl,"default")==1) {
+              if (weed_plant_has_leaf(ptmpl,WEED_LEAF_HOST_INTERNAL_CONNECTION)) continue;
+              hint=weed_get_int_value(ptmpl,WEED_LEAF_HINT,&error);
+              flags=weed_get_int_value(ptmpl,WEED_LEAF_FLAGS,&error);
+              if ((hint==WEED_HINT_INTEGER||hint==WEED_HINT_FLOAT)&&flags==0&&weed_leaf_num_elements(ptmpl,WEED_LEAF_DEFAULT)==1) {
                 if (oval1==0) {
                   if (hint==WEED_HINT_INTEGER) {
                     int omin=mnode->min[j];
                     int omax=mnode->max[j];
-                    int mini=weed_get_int_value(ptmpl,"min",&error);
-                    int maxi=weed_get_int_value(ptmpl,"max",&error);
+                    int mini=weed_get_int_value(ptmpl,WEED_LEAF_MIN,&error);
+                    int maxi=weed_get_int_value(ptmpl,WEED_LEAF_MAX,&error);
 
                     int oval=(int)((double)(vals[j]-omin)/(double)(omax-omin)*(double)(maxi-mini))+mini;
                     OSC_writeIntArg(&obuf,oval);
@@ -2360,8 +2381,8 @@ OSCbuf *omc_learner_decode(int type, int idx, const char *string) {
                     // float
                     int omin=mnode->min[j];
                     int omax=mnode->max[j];
-                    double minf=weed_get_double_value(ptmpl,"min",&error);
-                    double maxf=weed_get_double_value(ptmpl,"max",&error);
+                    double minf=weed_get_double_value(ptmpl,WEED_LEAF_MIN,&error);
+                    double maxf=weed_get_double_value(ptmpl,WEED_LEAF_MAX,&error);
 
                     double oval=(double)(vals[j]-omin)/(double)(omax-omin)*(maxf-minf)+minf;
                     OSC_writeFloatArg(&obuf,(float)oval);
