@@ -1,7 +1,7 @@
 // pangotext.c
 // text handling code
 // (c) A. Penkov 2010
-// (c) G. Finch 2010 - 2015
+// (c) G. Finch 2010 - 2016
 // pieces of code taken and modified from scribbler.c
 // released under the GNU GPL 3 or later
 // see file COPYING or www.gnu.org for details
@@ -23,6 +23,7 @@
 
 #include "main.h"
 #include "pangotext.h"
+#include "effects-weed.h"
 
 #ifdef GUI_GTK
 #include <pango/pangocairo.h>
@@ -136,7 +137,7 @@ static int font_cmp(const void *p1, const void *p2) {
 
 
 LingoLayout *render_text_to_cr(LiVESWidget *widget, lives_painter_t *cr, const char *text, const char *fontname,
-                               double size, lives_text_mode_t mode, lives_colRGBA32_t *fg, lives_colRGBA32_t *bg,
+                               double size, lives_text_mode_t mode, lives_colRGBA64_t *fg, lives_colRGBA64_t *bg,
                                boolean center, boolean rising, double top, int offs_x, int width, int height) {
 
   // fontname may be eg. "Sans"
@@ -154,9 +155,9 @@ LingoLayout *render_text_to_cr(LiVESWidget *widget, lives_painter_t *cr, const c
 
   LingoLayout *layout;
 
-  double x_pos, y_pos;
+  double x_pos=0., y_pos=0.;
   double x_text, y_text;
-  double dwidth, dheight;
+  double dwidth=width, dheight=height;
 
   double b_alpha=1.;
   double f_alpha=1.;
@@ -187,7 +188,10 @@ LingoLayout *render_text_to_cr(LiVESWidget *widget, lives_painter_t *cr, const c
   layout = new LingoLayout(text, fontname, size);
 #endif
 
-  getxypos(layout, &x_pos, &y_pos, width, height, center, &dwidth, &dheight);
+#ifndef GUI_QT
+  if (rising||center||mode==LIVES_TEXT_MODE_FOREGROUND_AND_BACKGROUND)
+#endif
+    getxypos(layout, &x_pos, &y_pos, width, height, center, &dwidth, &dheight);
 
   if (!rising) y_pos = y_text = height*top;
 
@@ -236,7 +240,7 @@ LingoLayout *render_text_to_cr(LiVESWidget *widget, lives_painter_t *cr, const c
 
 
 weed_plant_t *render_text_to_layer(weed_plant_t *layer, const char *text, const char *fontname,
-                                   double size, lives_text_mode_t mode, lives_colRGBA32_t *fg_col, lives_colRGBA32_t *bg_col,
+                                   double size, lives_text_mode_t mode, lives_colRGBA64_t *fg_col, lives_colRGBA64_t *bg_col,
                                    boolean center, boolean rising, double top) {
   // render text to layer and return a new layer, which may have a new "rowstrides", "width" and/or "current_palette"
   // original layer is freed in the process and should not be used
@@ -251,8 +255,8 @@ weed_plant_t *render_text_to_layer(weed_plant_t *layer, const char *text, const
 
   int width, height, error;
 
-  width=weed_get_int_value(layer,"width",&error);
-  height=weed_get_int_value(layer,"height",&error);
+  width=weed_get_int_value(layer,WEED_LEAF_WIDTH,&error);
+  height=weed_get_int_value(layer,WEED_LEAF_HEIGHT,&error);
 
   // do cairo and pango things
 
@@ -437,8 +441,7 @@ boolean get_srt_text(lives_clip_t *sfile, double xtime) {
 
   if (sfile->subt->last_time!=-1. && xtime>sfile->subt->last_time) {
     // past end of subtitles
-    if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
-    sfile->subt->text=NULL;
+    lives_freep((void **)&sfile->subt->text);
     sfile->subt->current=NULL;
     return TRUE;
   }
@@ -451,14 +454,13 @@ boolean get_srt_text(lives_clip_t *sfile, double xtime) {
 
   while (index_ptr) {
     if (index_ptr->start_time > xtime) {
-      if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
-      sfile->subt->text=NULL;
+      lives_freep((void **)&sfile->subt->text);
       sfile->subt->current = NULL;
       return (TRUE);
     }
     if (index_ptr->end_time >= xtime) {
       sfile->subt->current = index_ptr;
-      if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
+      lives_freep((void **)&sfile->subt->text);
       sfile->subt->text=srt_read_text(sfile->subt->tfile,sfile->subt->current);
       return (TRUE);
     }
@@ -481,8 +483,7 @@ boolean get_srt_text(lives_clip_t *sfile, double xtime) {
 
     if (!fgets(data,sizeof(data), pf)) {
       // EOF
-      if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
-      sfile->subt->text=NULL;
+      lives_freep((void **)&sfile->subt->text);
       sfile->subt->current=NULL;
       sub_get_last_time(sfile->subt);
       return FALSE;
@@ -535,13 +536,12 @@ boolean get_srt_text(lives_clip_t *sfile, double xtime) {
 
       if (node) {
         if (node->start_time > xtime) {
-          if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
-          sfile->subt->text=NULL;
+          lives_freep((void **)&sfile->subt->text);
           sfile->subt->current = NULL;
           return TRUE;
         }
         if (node->end_time >= xtime) {
-          if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
+          lives_freep((void **)&sfile->subt->text);
           sfile->subt->current = node;
           sfile->subt->text=srt_read_text(sfile->subt->tfile,sfile->subt->current);
           return TRUE;
@@ -555,8 +555,7 @@ boolean get_srt_text(lives_clip_t *sfile, double xtime) {
 
   // EOF
   sfile->subt->current=NULL;
-  if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
-  sfile->subt->text=NULL;
+  lives_freep((void **)&sfile->subt->text);
   sub_get_last_time(sfile->subt);
   return FALSE;
 }
@@ -587,8 +586,7 @@ boolean get_sub_text(lives_clip_t *sfile, double xtime) {
 
   if (sfile->subt->last_time!=-1. && xtime>sfile->subt->last_time) {
     // past end of subtitles
-    if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
-    sfile->subt->text=NULL;
+    lives_freep((void **)&sfile->subt->text);
     sfile->subt->current=NULL;
     return TRUE;
   }
@@ -601,14 +599,13 @@ boolean get_sub_text(lives_clip_t *sfile, double xtime) {
 
   while (index_ptr) {
     if (index_ptr->start_time > xtime) {
-      if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
-      sfile->subt->text=NULL;
+      lives_freep((void **)&sfile->subt->text);
       sfile->subt->current = NULL;
       return (TRUE);
     }
     if (index_ptr->end_time >= xtime) {
       sfile->subt->current = index_ptr;
-      if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
+      lives_freep((void **)&sfile->subt->text);
       sfile->subt->text=sub_read_text(sfile->subt->tfile,sfile->subt->current);
       return (TRUE);
     }
@@ -686,13 +683,12 @@ boolean get_sub_text(lives_clip_t *sfile, double xtime) {
 
       if (node) {
         if (node->start_time > xtime) {
-          if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
-          sfile->subt->text=NULL;
+          lives_freep((void **)&sfile->subt->text);
           sfile->subt->current = NULL;
           return TRUE;
         }
         if (node->end_time >= xtime) {
-          if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
+          lives_freep((void **)&sfile->subt->text);
           sfile->subt->current = node;
           sfile->subt->text=sub_read_text(sfile->subt->tfile,sfile->subt->current);
           return TRUE;
@@ -705,8 +701,7 @@ boolean get_sub_text(lives_clip_t *sfile, double xtime) {
 
   // EOF
   sfile->subt->current=NULL;
-  if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
-  sfile->subt->text=NULL;
+  lives_freep((void **)&sfile->subt->text);
   sub_get_last_time(sfile->subt);
   return TRUE;
 }
@@ -725,14 +720,13 @@ void subtitles_free(lives_clip_t *sfile) {
 
     sfile->subt->index = (lives_subtitle_t *)sfile->subt->index->next;
 
-    if (to_delete->style != NULL) lives_free(to_delete->style);
-    lives_free(to_delete);
+    lives_freep((void **)&to_delete->style);
+    lives_freep((void **)&to_delete);
   }
 
-  if (sfile->subt->text!=NULL) lives_free(sfile->subt->text);
+  lives_freep((void **)&sfile->subt->text);
+  lives_freep((void **)&sfile->subt);
 
-  lives_free(sfile->subt);
-  sfile->subt=NULL;
 }
 
 
@@ -842,7 +836,7 @@ boolean save_srt_subtitles(lives_clip_t *sfile, double start_time, double end_ti
 
   fclose(pf);
   if (!num_saves) // don't keep the empty file
-    unlink(filename);
+    lives_rm(filename);
 
   if (subt->last_time <= -1.)
     fseek(subt->tfile, savepos, SEEK_SET);
@@ -925,7 +919,7 @@ boolean save_sub_subtitles(lives_clip_t *sfile, double start_time, double end_ti
 
   fclose(pf);
   if (!num_saves) // don't keep the empty file
-    unlink(filename);
+    lives_rm(filename);
 
   if (subt->last_time <= -1.)
     fseek(subt->tfile, savepos, SEEK_SET);
