@@ -1,6 +1,6 @@
 // resample.c
 // LiVES
-// (c) G. Finch 2004 - 2015 <salsaman@gmail.com>
+// (c) G. Finch 2004 - 2016 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -31,6 +31,7 @@ static boolean reorder_leave_back=FALSE;
 /////////////////////////////////////////////////////
 
 LIVES_INLINE weed_timecode_t q_gint64(weed_timecode_t in, double fps) {
+  // quantise timecode to fps
   if (in>(weed_timecode_t)0) return ((weed_timecode_t)((long double)in/(long double)U_SEC*(long double)fps+(long double).5)/
                                        (long double)fps)*(weed_timecode_t)U_SECL; // quantise to frame timing
   if (in<(weed_timecode_t)0) return ((weed_timecode_t)((long double)in/(long double)U_SEC*(long double)fps-(long double).5)/
@@ -45,6 +46,7 @@ LIVES_INLINE weed_timecode_t q_gint64_floor(weed_timecode_t in, double fps) {
 }
 
 LIVES_INLINE weed_timecode_t q_dbl(double in, double fps) {
+  // quantise (double)in to fps
   if (in>0.) return ((weed_timecode_t)((long double)in*(long double)fps+(long double).5)/(long double)fps)*
                       (weed_timecode_t)U_SECL; // quantise to frame timing
   if (in<0.) return ((weed_timecode_t)((long double)in*(long double)fps-(long double).5)/(long double)fps)*
@@ -172,7 +174,7 @@ boolean auto_resample_resize(int width,int height,double fps,int fps_num,int fps
           cfile->progress_start=1;
           cfile->progress_end=cfile->frames;
 
-          unlink(cfile->info_file);
+          lives_rm(cfile->info_file);
           mainw->com_failed=FALSE;
           lives_system(com,FALSE);
           lives_free(com);
@@ -190,9 +192,9 @@ boolean auto_resample_resize(int width,int height,double fps,int fps_num,int fps
           rs_builtin=FALSE;
           resize_rfx=mainw->fx_candidates[FX_CANDIDATE_RESIZER].rfx;
           first_out=get_enabled_channel((weed_plant_t *)resize_rfx->source,0,FALSE);
-          ctmpl=weed_get_plantptr_value(first_out,"template",&error);
-          weed_set_int_value(ctmpl,"host_width",width);
-          weed_set_int_value(ctmpl,"host_height",height);
+          ctmpl=weed_get_plantptr_value(first_out,WEED_LEAF_TEMPLATE,&error);
+          weed_set_int_value(ctmpl,WEED_LEAF_HOST_WIDTH,width);
+          weed_set_int_value(ctmpl,WEED_LEAF_HOST_HEIGHT,height);
         }
 
         cfile->nokeep=TRUE;
@@ -369,7 +371,7 @@ boolean auto_resample_resize(int width,int height,double fps,int fps_num,int fps
 
         cfile->undo1_dbl=cfile->fps;
 
-        unlink(cfile->info_file);
+        lives_rm(cfile->info_file);
         mainw->com_failed=FALSE;
         lives_system(com,FALSE);
         lives_free(com);
@@ -385,9 +387,9 @@ boolean auto_resample_resize(int width,int height,double fps,int fps_num,int fps
         rs_builtin=FALSE;
         resize_rfx=mainw->fx_candidates[FX_CANDIDATE_RESIZER].rfx;
         first_out=get_enabled_channel((weed_plant_t *)resize_rfx->source,0,FALSE);
-        ctmpl=weed_get_plantptr_value(first_out,"template",&error);
-        weed_set_int_value(ctmpl,"host_width",width);
-        weed_set_int_value(ctmpl,"host_height",height);
+        ctmpl=weed_get_plantptr_value(first_out,WEED_LEAF_TEMPLATE,&error);
+        weed_set_int_value(ctmpl,WEED_LEAF_HOST_WIDTH,width);
+        weed_set_int_value(ctmpl,WEED_LEAF_HOST_HEIGHT,height);
       }
 
       cfile->nokeep=TRUE;
@@ -451,8 +453,7 @@ boolean auto_resample_resize(int width,int height,double fps,int fps_num,int fps
 
 //////////////////////////////////////////////////////////////////
 
-WARN_UNUSED weed_plant_t *
-quantise_events(weed_plant_t *in_list, double qfps, boolean allow_gap) {
+weed_plant_t *quantise_events(weed_plant_t *in_list, double qfps, boolean allow_gap) {
   // new style event system, now we quantise from event_list_t *in_list to *out_list with period tl/U_SEC
 
   // the timecode of the midpoint of our last frame events will match as near as possible the old length
@@ -481,9 +482,9 @@ quantise_events(weed_plant_t *in_list, double qfps, boolean allow_gap) {
 
   out_list=weed_plant_new(WEED_PLANT_EVENT_LIST);
   weed_add_plant_flags(out_list,WEED_LEAF_READONLY_PLUGIN);
-  weed_set_voidptr_value(out_list,"first",NULL);
-  weed_set_voidptr_value(out_list,"last",NULL);
-  weed_set_double_value(out_list,"fps",qfps);
+  weed_set_voidptr_value(out_list,WEED_LEAF_FIRST,NULL);
+  weed_set_voidptr_value(out_list,WEED_LEAF_LAST,NULL);
+  weed_set_double_value(out_list,WEED_LEAF_FPS,qfps);
 
   last_frame_event=get_last_frame_event(in_list);
 
@@ -534,9 +535,9 @@ quantise_events(weed_plant_t *in_list, double qfps, boolean allow_gap) {
         needs_audio=TRUE;
         if (aclips!=NULL) lives_free(aclips);
         if (aseeks!=NULL) lives_free(aseeks);
-        num_aclips=weed_leaf_num_elements(event,"audio_clips");
-        aclips=weed_get_int_array(event,"audio_clips",&error);
-        aseeks=weed_get_double_array(event,"audio_seeks",&error);
+        num_aclips=weed_leaf_num_elements(event,WEED_LEAF_AUDIO_CLIPS);
+        aclips=weed_get_int_array(event,WEED_LEAF_AUDIO_CLIPS,&error);
+        aseeks=weed_get_double_array(event,WEED_LEAF_AUDIO_SEEKS,&error);
       }
       in_tc=get_event_timecode(event);
       if ((next_frame_event=get_next_frame_event(event))!=NULL) {
@@ -559,9 +560,9 @@ quantise_events(weed_plant_t *in_list, double qfps, boolean allow_gap) {
       if (out_clips!=NULL) lives_free(out_clips);
       if (out_frames!=NULL) lives_free(out_frames);
 
-      numframes=weed_leaf_num_elements(event,"clips");
-      out_clips=weed_get_int_array(event,"clips",&error);
-      out_frames=weed_get_int_array(event,"frames",&error);
+      numframes=weed_leaf_num_elements(event,WEED_LEAF_CLIPS);
+      out_clips=weed_get_int_array(event,WEED_LEAF_CLIPS,&error);
+      out_frames=weed_get_int_array(event,WEED_LEAF_FRAMES,&error);
       if (last_audio_event==event&&needs_audio) add_audio=TRUE;
       if (error==WEED_ERROR_MEMORY_ALLOCATION) {
         do_memory_error_dialog();
@@ -582,9 +583,9 @@ quantise_events(weed_plant_t *in_list, double qfps, boolean allow_gap) {
             if (out_clips!=NULL) lives_free(out_clips);
             if (out_frames!=NULL) lives_free(out_frames);
 
-            numframes=weed_leaf_num_elements(event,"clips");
-            out_clips=weed_get_int_array(event,"clips",&error);
-            out_frames=weed_get_int_array(event,"frames",&error);
+            numframes=weed_leaf_num_elements(event,WEED_LEAF_CLIPS);
+            out_clips=weed_get_int_array(event,WEED_LEAF_CLIPS,&error);
+            out_frames=weed_get_int_array(event,WEED_LEAF_FRAMES,&error);
             if (last_audio_event==event&&needs_audio) add_audio=TRUE;
             if (error==WEED_ERROR_MEMORY_ALLOCATION) {
               do_memory_error_dialog();
@@ -600,13 +601,13 @@ quantise_events(weed_plant_t *in_list, double qfps, boolean allow_gap) {
             return NULL;
           }
           if (add_audio) {
-            weed_set_int_array(shortcut,"audio_clips",num_aclips,aclips);
-            weed_set_double_array(shortcut,"audio_seeks",num_aclips,aseeks);
+            weed_set_int_array(shortcut,WEED_LEAF_AUDIO_CLIPS,num_aclips,aclips);
+            weed_set_double_array(shortcut,WEED_LEAF_AUDIO_SEEKS,num_aclips,aseeks);
             needs_audio=add_audio=FALSE;
           }
           nearest_tc=LONG_MAX;
           if (is_first) {
-            weed_set_voidptr_value(out_list,"first",get_last_event(out_list));
+            weed_set_voidptr_value(out_list,WEED_LEAF_FIRST,get_last_event(out_list));
             is_first=FALSE;
           }
         }
@@ -639,16 +640,16 @@ quantise_events(weed_plant_t *in_list, double qfps, boolean allow_gap) {
       if (out_clips!=NULL) lives_free(out_clips);
       if (out_frames!=NULL) lives_free(out_frames);
 
-      numframes=weed_leaf_num_elements(event,"clips");
-      out_clips=weed_get_int_array(event,"clips",&error);
-      out_frames=weed_get_int_array(event,"frames",&error);
+      numframes=weed_leaf_num_elements(event,WEED_LEAF_CLIPS);
+      out_clips=weed_get_int_array(event,WEED_LEAF_CLIPS,&error);
+      out_frames=weed_get_int_array(event,WEED_LEAF_FRAMES,&error);
 
       if (insert_frame_event_at(out_list,0.,numframes,out_clips,out_frames,NULL)==NULL) {
         do_memory_error_dialog();
         event_list_free(out_list);
         return NULL;
       }
-      if (get_first_event(out_list)==NULL) weed_set_voidptr_value(out_list,"first",get_last_event(out_list));
+      if (get_first_event(out_list)==NULL) weed_set_voidptr_value(out_list,WEED_LEAF_FIRST,get_last_event(out_list));
     }
   }
 
@@ -671,16 +672,12 @@ static void on_reorder_activate(int rwidth, int rheight) {
 
   if (!(prefs->warning_mask&WARN_MASK_LAYOUT_ALTER_FRAMES)&&(mainw->xlays=layout_frame_is_affected(mainw->current_file,1))!=NULL) {
     if (!do_layout_alter_frames_warning()) {
-      lives_list_free_strings(mainw->xlays);
-      lives_list_free(mainw->xlays);
-      mainw->xlays=NULL;
+      lives_list_free_all(&mainw->xlays);
       return;
     }
     add_lmap_error(LMAP_ERROR_ALTER_FRAMES,cfile->name,(livespointer)cfile->layout_map,mainw->current_file,0,0.,cfile->stored_layout_frame>0);
     has_lmap_error=TRUE;
-    lives_list_free_strings(mainw->xlays);
-    lives_list_free(mainw->xlays);
-    mainw->xlays=NULL;
+    lives_list_free_all(&mainw->xlays);
   }
 
   cfile->old_frames=cfile->frames;
@@ -792,17 +789,13 @@ void on_resaudio_ok_clicked(LiVESButton *button, LiVESEntry *entry) {
   if (!(prefs->warning_mask&WARN_MASK_LAYOUT_ALTER_AUDIO)&&(mainw->xlays=layout_audio_is_affected
       (mainw->current_file,0.))) {
     if (!do_layout_alter_audio_warning()) {
-      lives_list_free_strings(mainw->xlays);
-      lives_list_free(mainw->xlays);
-      mainw->xlays=NULL;
+      lives_list_free_all(&mainw->xlays);
       return;
     }
     add_lmap_error(LMAP_ERROR_ALTER_AUDIO,cfile->name,(livespointer)cfile->layout_map,mainw->current_file,0,0.,
                    cfile->stored_layout_audio>0.);
     has_lmap_error=TRUE;
-    lives_list_free_strings(mainw->xlays);
-    lives_list_free(mainw->xlays);
-    mainw->xlays=NULL;
+    lives_list_free_all(&mainw->xlays);
   }
 
   // store old values for undo/redo
@@ -820,7 +813,7 @@ void on_resaudio_ok_clicked(LiVESButton *button, LiVESEntry *entry) {
     if (cfile->arps!=cfile->arate) {
       double audio_stretch=(double)cfile->arps/(double)cfile->arate;
       // pb rate != real rate - stretch to pb rate and resample
-      unlink(cfile->info_file);
+      lives_rm(cfile->info_file);
       com=lives_strdup_printf("%s resample_audio \"%s\" %d %d %d %d %d %d %d %d %d %d %.4f",prefs->backend,
                               cfile->handle,cfile->arps,
                               cfile->achans,cfile->asampsize,cur_signed,cur_endian,arps,cfile->achans,cfile->asampsize,
@@ -832,14 +825,14 @@ void on_resaudio_ok_clicked(LiVESButton *button, LiVESEntry *entry) {
       lives_free(com);
       cfile->arate=cfile->arps=arps;
     } else {
-      unlink(cfile->info_file);
+      lives_rm(cfile->info_file);
       com=lives_strdup_printf("%s resample_audio \"%s\" %d %d %d %d %d %d %d %d %d %d",prefs->backend,
                               cfile->handle,cfile->arps,
                               cfile->achans,cfile->asampsize,cur_signed,cur_endian,arps,achans,asampsize,asigned,aendian);
       mainw->com_failed=FALSE;
       mainw->cancelled=CANCEL_NONE;
       mainw->error=FALSE;
-      unlink(cfile->info_file);
+      lives_rm(cfile->info_file);
       lives_system(com,FALSE);
       check_backend_return(cfile);
       if (mainw->com_failed) return;
@@ -954,8 +947,7 @@ static void on_resaudw_achans_changed(LiVESWidget *widg, livespointer user_data)
 
 
 
-void
-on_resaudw_asamps_changed(LiVESWidget *irrelevant, livespointer rubbish) {
+void on_resaudw_asamps_changed(LiVESWidget *irrelevant, livespointer rubbish) {
   if (atoi(lives_entry_get_text(LIVES_ENTRY(resaudw->entry_asamps)))==8) {
     lives_widget_set_sensitive(resaudw->rb_bigend,FALSE);
     lives_widget_set_sensitive(resaudw->rb_littleend,FALSE);
@@ -975,9 +967,7 @@ on_resaudw_asamps_changed(LiVESWidget *irrelevant, livespointer rubbish) {
 
 
 
-void
-on_resample_video_activate(LiVESMenuItem     *menuitem,
-                           livespointer         user_data) {
+void on_resample_video_activate(LiVESMenuItem *menuitem, livespointer user_data) {
   // change speed from the menu
   create_new_pb_speed(2);
   mainw->fx1_val=cfile->fps;
@@ -1212,16 +1202,17 @@ _resaudw *create_resaudw(short type, render_details *rdet, LiVESWidget *top_vbox
     char *title=NULL;
 
     if (type==1) {
-      title=lives_strdup(_("LiVES: - Resample Audio"));
+      title=lives_strdup(_("Resample Audio"));
     } else if (type==2) {
-      title=lives_strdup(_("LiVES: - Insert Silence"));
+      title=lives_strdup(_("Insert Silence"));
     } else if (type==5||type==11||type==6||type==7) {
-      title=lives_strdup(_("LiVES: - New Clip Audio"));
+      title=lives_strdup(_("New Clip Audio"));
     } else if (type==9||type==8) {
-      title=lives_strdup(_("LiVES: - External Clip Settings"));
+      title=lives_strdup(_("External Clip Settings"));
     }
 
     resaudw->dialog = lives_standard_dialog_new(title,FALSE,DEF_DIALOG_WIDTH,DEF_DIALOG_HEIGHT);
+    lives_signal_handlers_disconnect_by_func(resaudw->dialog,return_true,NULL);
     lives_free(title);
 
     accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new());
@@ -1239,15 +1230,10 @@ _resaudw *create_resaudw(short type, render_details *rdet, LiVESWidget *top_vbox
   } else vboxx=top_vbox;
 
   if (type==1) {
-    frame = lives_frame_new(NULL);
-    lives_container_set_border_width(LIVES_CONTAINER(frame), widget_opts.border_width);
+    frame = lives_standard_frame_new(_("Current"),0.,FALSE);
 
     lives_box_pack_start(LIVES_BOX(vboxx), frame, TRUE, TRUE, 0);
 
-    if (palette->style&STYLE_1) {
-      lives_widget_set_bg_color(frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
-    }
-
     hbox2 = lives_hbox_new(FALSE, 0);
     lives_container_add(LIVES_CONTAINER(frame), hbox2);
     lives_container_set_border_width(LIVES_CONTAINER(hbox2), widget_opts.packing_width);
@@ -1328,25 +1314,20 @@ _resaudw *create_resaudw(short type, render_details *rdet, LiVESWidget *top_vbox
     lives_widget_set_sensitive(radiobutton_b1, FALSE);
     lives_widget_set_sensitive(radiobutton_l1, FALSE);
 
-    label = lives_standard_label_new(_("Current"));
-
-    lives_frame_set_label_widget(LIVES_FRAME(frame), label);
-
   }
 
   resaudw->aud_checkbutton = NULL;
 
   if (type<9||type==11) {
-    frame = lives_frame_new(NULL);
-    lives_container_set_border_width(LIVES_CONTAINER(frame), widget_opts.border_width);
+    if (type>=3&&type!=11) tmp=lives_strdup(_("Audio"));
+    else tmp=lives_strdup(_("New"));
+
+    frame = lives_standard_frame_new(tmp,0.,FALSE);
+    lives_free(tmp);
 
     if (type==4) lives_box_pack_start(LIVES_BOX(vboxx), frame, FALSE, FALSE, widget_opts.packing_height);
     else lives_box_pack_start(LIVES_BOX(vboxx), frame, TRUE, TRUE, 0);
 
-    if (palette->style&STYLE_1) {
-      lives_widget_set_bg_color(frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
-    }
-
     vbox2 = lives_vbox_new(FALSE, 0);
     lives_container_add(LIVES_CONTAINER(frame), vbox2);
 
@@ -1498,24 +1479,13 @@ _resaudw *create_resaudw(short type, render_details *rdet, LiVESWidget *top_vbox
                          LIVES_GUI_CALLBACK(on_resaudw_asamps_changed),
                          NULL);
 
-    if (type>=3&&type!=11) label_aud = lives_standard_label_new(_("Audio"));
-    else label_aud = lives_standard_label_new(_("New"));
-
-    if (type==3&&type!=11&&palette->style&STYLE_1) lives_widget_set_bg_color(frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
-
-    lives_frame_set_label_widget(LIVES_FRAME(frame), label_aud);
 
   }
 
   if (type>7&&type!=11) {
-    frame = lives_frame_new(NULL);
-    lives_container_set_border_width(LIVES_CONTAINER(frame), widget_opts.border_width);
+    frame = lives_standard_frame_new(_("Video"),0.,FALSE);
     lives_box_pack_start(LIVES_BOX(vboxx), frame, TRUE, TRUE, 0);
 
-    if (palette->style&STYLE_1) {
-      lives_widget_set_bg_color(frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
-    }
-
     hbox = lives_hbox_new(FALSE, 0);
     lives_container_add(LIVES_CONTAINER(frame), hbox);
     lives_container_set_border_width(LIVES_CONTAINER(hbox), widget_opts.border_width);
@@ -1524,10 +1494,6 @@ _resaudw *create_resaudw(short type, render_details *rdet, LiVESWidget *top_vbox
     resaudw->fps_spinbutton = lives_standard_spin_button_new(_("_Frames Per Second "),TRUE,
                               prefs->default_fps,1.,FPS_MAX,1.,1.,3,LIVES_BOX(hbox),NULL);
 
-
-    label = lives_standard_label_new(_("Video"));
-
-    lives_frame_set_label_widget(LIVES_FRAME(frame), label);
   }
 
   if (type>4&&type!=11) {
@@ -1668,12 +1634,13 @@ void create_new_pb_speed(short type) {
   char *title=NULL;
 
   if (type==1) {
-    title=lives_strdup(_("LiVES: - Change playback speed"));
+    title=lives_strdup(_("Change Playback Speed"));
   } else {
-    title=lives_strdup(_("LiVES: - Resample Video"));
+    title=lives_strdup(_("Resample Video"));
   }
 
   new_pb_speed = lives_standard_dialog_new(title,FALSE,-1,-1);
+  lives_signal_handlers_disconnect_by_func(new_pb_speed,return_true,NULL);
   lives_free(title);
 
   accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new());
@@ -1803,9 +1770,7 @@ void create_new_pb_speed(short type) {
 
 
 
-void
-on_change_speed_activate(LiVESMenuItem     *menuitem,
-                         livespointer         user_data) {
+void on_change_speed_activate(LiVESMenuItem *menuitem, livespointer user_data) {
   // change speed from the menu
   create_new_pb_speed(1);
   mainw->fx1_bool=mainw->fx2_bool=FALSE;
@@ -1836,17 +1801,13 @@ void on_change_speed_ok_clicked(LiVESButton *button, livespointer user_data) {
     if ((mainw->xlays=layout_frame_is_affected(mainw->current_file,new_frames))!=NULL) {
       if (!do_warning_dialog(
             _("\nSpeeding up the clip will cause missing frames in some multitrack layouts.\nAre you sure you wish to change the speed ?\n"))) {
-        lives_list_free_strings(mainw->xlays);
-        lives_list_free(mainw->xlays);
-        mainw->xlays=NULL;
+        lives_list_free_all(&mainw->xlays);
         return;
       }
       add_lmap_error(LMAP_ERROR_DELETE_FRAMES,cfile->name,(livespointer)cfile->layout_map,mainw->current_file,new_frames,0.,
                      new_frames<=count_resampled_frames(cfile->stored_layout_frame,cfile->stored_layout_fps,cfile->fps));
       has_lmap_error=TRUE;
-      lives_list_free_strings(mainw->xlays);
-      lives_list_free(mainw->xlays);
-      mainw->xlays=NULL;
+      lives_list_free_all(&mainw->xlays);
     }
   }
 
@@ -1855,17 +1816,13 @@ void on_change_speed_ok_clicked(LiVESButton *button, livespointer user_data) {
     if ((mainw->xlays=layout_audio_is_affected(mainw->current_file,(new_frames-1.)/cfile->fps))!=NULL) {
       if (!do_warning_dialog(
             _("\nSpeeding up the clip will cause missing audio in some multitrack layouts.\nAre you sure you wish to change the speed ?\n"))) {
-        lives_list_free_strings(mainw->xlays);
-        lives_list_free(mainw->xlays);
-        mainw->xlays=NULL;
+        lives_list_free_all(&mainw->xlays);
         return;
       }
       add_lmap_error(LMAP_ERROR_DELETE_AUDIO,cfile->name,(livespointer)cfile->layout_map,mainw->current_file,0,(new_frames-1.)/cfile->fps,
                      (new_frames-1.)/cfile->fps<cfile->stored_layout_audio);
       has_lmap_error=TRUE;
-      lives_list_free_strings(mainw->xlays);
-      lives_list_free(mainw->xlays);
-      mainw->xlays=NULL;
+      lives_list_free_all(&mainw->xlays);
     }
   }
 
@@ -1873,62 +1830,48 @@ void on_change_speed_ok_clicked(LiVESButton *button, livespointer user_data) {
       (mainw->xlays=layout_frame_is_affected(mainw->current_file,1))!=NULL) {
     if (!do_warning_dialog(
           _("\nChanging the speed will cause frames to shift in some multitrack layouts.\nAre you sure you wish to continue ?\n"))) {
-      lives_list_free_strings(mainw->xlays);
-      lives_list_free(mainw->xlays);
-      mainw->xlays=NULL;
+      lives_list_free_all(&mainw->xlays);
       return;
     }
     add_lmap_error(LMAP_ERROR_SHIFT_FRAMES,cfile->name,(livespointer)cfile->layout_map,mainw->current_file,0,0.,cfile->stored_layout_frame>0);
     has_lmap_error=TRUE;
-    lives_list_free_strings(mainw->xlays);
-    lives_list_free(mainw->xlays);
-    mainw->xlays=NULL;
+    lives_list_free_all(&mainw->xlays);
   }
 
   if (mainw->fx1_bool&&!has_lmap_error&&!(prefs->warning_mask&WARN_MASK_LAYOUT_SHIFT_AUDIO)&&
       (mainw->xlays=layout_audio_is_affected(mainw->current_file,0.))!=NULL) {
     if (!do_warning_dialog(
           _("\nChanging the speed will cause audio to shift in some multitrack layouts.\nAre you sure you wish to continue ?\n"))) {
-      lives_list_free_strings(mainw->xlays);
+      lives_list_free_all(&mainw->xlays);
       lives_list_free(mainw->xlays);
       mainw->xlays=NULL;
       return;
     }
     add_lmap_error(LMAP_ERROR_SHIFT_AUDIO,cfile->name,(livespointer)cfile->layout_map,mainw->current_file,0,0.,cfile->stored_layout_audio>0.);
     has_lmap_error=TRUE;
-    lives_list_free_strings(mainw->xlays);
-    lives_list_free(mainw->xlays);
-    mainw->xlays=NULL;
+    lives_list_free_all(&mainw->xlays);
   }
 
   if (!has_lmap_error&&!(prefs->warning_mask&WARN_MASK_LAYOUT_ALTER_FRAMES)&&
       (mainw->xlays=layout_frame_is_affected(mainw->current_file,1))!=NULL) {
     if (!do_layout_alter_frames_warning()) {
-      lives_list_free_strings(mainw->xlays);
-      lives_list_free(mainw->xlays);
-      mainw->xlays=NULL;
+      lives_list_free_all(&mainw->xlays);
       return;
     }
     add_lmap_error(LMAP_ERROR_ALTER_FRAMES,cfile->name,(livespointer)cfile->layout_map,mainw->current_file,0,0.,cfile->stored_layout_frame>0);
     has_lmap_error=TRUE;
-    lives_list_free_strings(mainw->xlays);
-    lives_list_free(mainw->xlays);
-    mainw->xlays=NULL;
+    lives_list_free_all(&mainw->xlays);
   }
 
   if (mainw->fx1_bool&&!has_lmap_error&&!(prefs->warning_mask&WARN_MASK_LAYOUT_ALTER_AUDIO)&&
       (mainw->xlays=layout_audio_is_affected(mainw->current_file,0.))!=NULL) {
     if (!do_layout_alter_audio_warning()) {
-      lives_list_free_strings(mainw->xlays);
-      lives_list_free(mainw->xlays);
-      mainw->xlays=NULL;
+      lives_list_free_all(&mainw->xlays);
       return;
     }
     add_lmap_error(LMAP_ERROR_ALTER_AUDIO,cfile->name,(livespointer)cfile->layout_map,mainw->current_file,0,0.,cfile->stored_layout_audio>0.);
     has_lmap_error=TRUE;
-    lives_list_free_strings(mainw->xlays);
-    lives_list_free(mainw->xlays);
-    mainw->xlays=NULL;
+    lives_list_free_all(&mainw->xlays);
   }
 
   if (button==NULL) {
@@ -2035,7 +1978,7 @@ int reorder_frames(int rwidth, int rheight) {
     cfile->event_list=NULL;
   }
 
-  unlink(cfile->info_file);
+  lives_rm(cfile->info_file);
   mainw->error=FALSE;
   mainw->com_failed=FALSE;
   lives_system(com,FALSE);
@@ -2104,7 +2047,7 @@ int deorder_frames(int old_frames, boolean leave_bak) {
                           perf_start,cfile->frames,perf_end,
                           get_image_ext_for_type(cfile->img_type),leave_bak);
 
-  unlink(cfile->info_file);
+  lives_rm(cfile->info_file);
   mainw->com_failed=FALSE;
   lives_system(com,TRUE);
   if (mainw->com_failed) return cfile->frames;
@@ -2151,7 +2094,7 @@ boolean resample_clipboard(double new_fps) {
     // copy .mgk to .img_ext and .img_ext to .bak (i.e redo the resample)
     com=lives_strdup_printf("%s redo \"%s\" %d %d \"%s\"",prefs->backend,cfile->handle,1,new_frames,
                             get_image_ext_for_type(cfile->img_type));
-    unlink(cfile->info_file);
+    lives_rm(cfile->info_file);
     mainw->com_failed=FALSE;
     lives_system(com,FALSE);
 
@@ -2181,7 +2124,7 @@ boolean resample_clipboard(double new_fps) {
       mainw->current_file=0;
       com=lives_strdup_printf("%s undo \"%s\" %d %d \"%s\"",prefs->backend,cfile->handle,old_frames+1,cfile->frames,
                               get_image_ext_for_type(cfile->img_type));
-      unlink(cfile->info_file);
+      lives_rm(cfile->info_file);
       lives_system(com,FALSE);
       cfile->progress_start=old_frames+1;
       cfile->progress_end=cfile->frames;
