@@ -1,6 +1,6 @@
 // rte_window.c
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2014
+// (c) G. Finch 2005 - 2016
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -103,7 +103,7 @@ void rte_window_set_interactive(boolean interactive) {
 }
 
 
-void ret_set_key_check_state(void) {
+void rtew_set_key_check_state(void) {
   // set (delayed) keycheck state
   register int i;
   for (i=0; i<prefs->rte_keys_virtual; i++) {
@@ -164,8 +164,7 @@ boolean on_clear_all_clicked(LiVESButton *button, livespointer user_data) {
     for (j=modes-1; j>=0; j--) {
       weed_delete_effectkey(i+1,j);
       if (rte_window!=NULL) {
-        lives_entry_set_text(LIVES_ENTRY(combo_entries[i*modes+j]),"");
-        type_label_set_text(i,j);
+        rtew_combo_set_text(i,j,"");
       }
     }
     if (mainw->ce_thumbs) ce_thumbs_reset_combo(i);
@@ -508,19 +507,19 @@ static boolean on_save_keymap_clicked(LiVESButton *button, livespointer user_dat
   // if we have default values, save them
   if (has_key_defaults()) {
     if (!save_keymap2_file(keymap_file2)) {
-      unlink(keymap_file2);
+      lives_rm(keymap_file2);
       retval=LIVES_RESPONSE_CANCEL;
     }
-  } else unlink(keymap_file2);
+  } else lives_rm(keymap_file2);
 
 
   // if we have data connections, save them
   if (mainw->pconx!=NULL||mainw->cconx!=NULL) {
     if (!save_keymap3_file(keymap_file3)) {
-      unlink(keymap_file3);
+      lives_rm(keymap_file3);
       retval=LIVES_RESPONSE_CANCEL;
     }
-  } else unlink(keymap_file3);
+  } else lives_rm(keymap_file3);
 
 
   lives_free(keymap_file3);
@@ -564,9 +563,6 @@ void on_save_rte_defs_activate(LiVESMenuItem *menuitem, livespointer user_data)
       retval=do_abort_cancel_retry_dialog(msg,LIVES_WINDOW(rte_window));
       lives_free(msg);
     } else {
-#ifdef IS_MINGW
-      setmode(fd, O_BINARY);
-#endif
       msg=lives_strdup("LiVES filter defaults file version 1.1\n");
       mainw->write_failed=FALSE;
       lives_write_buffered(fd,msg,strlen(msg),TRUE);
@@ -596,9 +592,6 @@ void on_save_rte_defs_activate(LiVESMenuItem *menuitem, livespointer user_data)
       retval=do_write_failed_error_s_with_retry(prefs->fxsizesfile,lives_strerror(errno),LIVES_WINDOW(rte_window));
       lives_free(msg);
     } else {
-#ifdef IS_MINGW
-      setmode(fd, O_BINARY);
-#endif
       msg=lives_strdup("LiVES generator default sizes file version 2\n");
       mainw->write_failed=FALSE;
       lives_write_buffered(fd,msg,strlen(msg),TRUE);
@@ -650,9 +643,6 @@ void load_rte_defs(void) {
       if ((fd=lives_open_buffered_rdonly(prefs->fxdefsfile))==-1) {
         retval=do_read_failed_error_s_with_retry(prefs->fxdefsfile,lives_strerror(errno),NULL);
       } else {
-#ifdef IS_MINGW
-        setmode(fd, O_BINARY);
-#endif
         mainw->read_failed=FALSE;
         d_print(_("Loading real time effect defaults from %s..."),prefs->fxdefsfile);
 
@@ -695,9 +685,6 @@ void load_rte_defs(void) {
         retval=do_read_failed_error_s_with_retry(prefs->fxsizesfile,lives_strerror(errno),NULL);
         if (retval==LIVES_RESPONSE_CANCEL) return;
       } else {
-#ifdef IS_MINGW
-        setmode(fd, O_BINARY);
-#endif
         d_print(_("Loading generator default sizes from %s..."),prefs->fxsizesfile);
 
         msg=lives_strdup("LiVES generator default sizes file version 2\n");
@@ -804,9 +791,7 @@ static boolean load_datacons(const char *fname, uint8_t **badkeymap) {
     if ((kfd=lives_open_buffered_rdonly(fname))==-1) {
       retval=do_read_failed_error_s_with_retry(fname,lives_strerror(errno),NULL);
     } else {
-#ifdef IS_MINGW
-      setmode(fd, O_BINARY);
-#endif
+
       mainw->read_failed=FALSE;
 
       bytes=lives_read_le_buffered(kfd,&version,4,TRUE);
@@ -905,10 +890,10 @@ static boolean load_datacons(const char *fname, uint8_t **badkeymap) {
 
           // check ocnum
           filter=rte_keymode_get_filter(okey+1,omode);
-          nochans=weed_leaf_num_elements(filter,"out_channel_templates");
+          nochans=weed_leaf_num_elements(filter,WEED_LEAF_OUT_CHANNEL_TEMPLATES);
           if (ocnum>=nochans) is_valid2=FALSE;
           else {
-            ochans=weed_get_plantptr_array(filter,"out_channel_templates",&error);
+            ochans=weed_get_plantptr_array(filter,WEED_LEAF_OUT_CHANNEL_TEMPLATES,&error);
             if (!has_alpha_palette(ochans[ocnum])) is_valid2=FALSE;
             lives_free(ochans);
           }
@@ -989,10 +974,10 @@ static boolean load_datacons(const char *fname, uint8_t **badkeymap) {
 
             // check icnum
             filter=rte_keymode_get_filter(ikey+1,imode);
-            nichans=weed_leaf_num_elements(filter,"in_channel_templates");
+            nichans=weed_leaf_num_elements(filter,WEED_LEAF_IN_CHANNEL_TEMPLATES);
             if (icnum>=nichans) is_valid2=FALSE;
             else {
-              ichans=weed_get_plantptr_array(filter,"in_channel_templates",&error);
+              ichans=weed_get_plantptr_array(filter,WEED_LEAF_IN_CHANNEL_TEMPLATES,&error);
               if (!has_alpha_palette(ichans[icnum])) is_valid2=FALSE;
               lives_free(ichans);
             }
@@ -1112,7 +1097,7 @@ static boolean load_datacons(const char *fname, uint8_t **badkeymap) {
 
           // check opnum
           filter=rte_keymode_get_filter(okey+1,omode);
-          noparams=weed_leaf_num_elements(filter,"out_parameter_templates");
+          noparams=weed_leaf_num_elements(filter,WEED_LEAF_OUT_PARAMETER_TEMPLATES);
           if (opnum>=noparams) is_valid2=FALSE;
 
           bytes=lives_read_le_buffered(kfd,&nconns,4,TRUE);
@@ -1190,12 +1175,12 @@ static boolean load_datacons(const char *fname, uint8_t **badkeymap) {
 
             // check ipnum
             filter=rte_keymode_get_filter(ikey+1,imode);
-            niparams=weed_leaf_num_elements(filter,"in_parameter_templates");
+            niparams=weed_leaf_num_elements(filter,WEED_LEAF_IN_PARAMETER_TEMPLATES);
             if (ipnum>=niparams) is_valid2=FALSE;
             else {
               if (ipnum>=0) {
-                iparams=weed_get_plantptr_array(filter,"in_parameter_templates",&error);
-                if (weed_plant_has_leaf(iparams[ipnum],"host_internal_connection")) is_valid2=FALSE;
+                iparams=weed_get_plantptr_array(filter,WEED_LEAF_IN_PARAMETER_TEMPLATES,&error);
+                if (weed_plant_has_leaf(iparams[ipnum],WEED_LEAF_HOST_INTERNAL_CONNECTION)) is_valid2=FALSE;
                 lives_free(iparams);
               }
             }
@@ -1312,8 +1297,7 @@ boolean on_load_keymap_clicked(LiVESButton *button, livespointer user_data) {
     lives_free(keymap_file);
     keymap_file=keymap_file2;
   } else {
-    lives_free(keymap_file2);
-    keymap_file2=NULL;
+    lives_freep((void **)&keymap_file2);
   }
 
   d_print(_("Loading default keymap from %s..."),keymap_file);
@@ -1322,13 +1306,7 @@ boolean on_load_keymap_clicked(LiVESButton *button, livespointer user_data) {
     retval=0;
 
     if (keymap_file2!=NULL) {
-      if ((kfd=lives_open_buffered_rdonly(keymap_file))==-1) has_error=TRUE;
-#ifdef IS_MINGW
-      else {
-        setmode(kfd, O_BINARY);
-      }
-#endif
-
+      if ((kfd=lives_open_buffered_rdonly(keymap_file))<0) has_error=TRUE;
     } else {
       if (!(kfile=fopen(keymap_file,"r"))) {
         has_error=TRUE;
@@ -1418,7 +1396,7 @@ boolean on_load_keymap_clicked(LiVESButton *button, livespointer user_data) {
       if (!strcmp(array[0],"defaults")) {
         lives_strfreev(array);
         array=lives_strsplit(line,"|",2);
-        if (prefs->fxdefsfile!=NULL) lives_free(prefs->fxdefsfile);
+        lives_freep((void **)&prefs->fxdefsfile);
         prefs->fxdefsfile=lives_strdup(array[1]);
         lives_strfreev(array);
         continue;
@@ -1427,7 +1405,7 @@ boolean on_load_keymap_clicked(LiVESButton *button, livespointer user_data) {
       if (!strcmp(array[0],"sizes")) {
         lives_strfreev(array);
         array=lives_strsplit(line,"|",2);
-        if (prefs->fxsizesfile!=NULL) lives_free(prefs->fxsizesfile);
+        lives_freep((void **)&prefs->fxsizesfile);
         prefs->fxsizesfile=lives_strdup(array[1]);
         lives_strfreev(array);
         continue;
@@ -1565,7 +1543,7 @@ boolean on_load_keymap_clicked(LiVESButton *button, livespointer user_data) {
       int idx=(key-1)*modes+mode;
       int fx_idx=rte_keymode_get_filter_idx(key,mode);
 
-      lives_entry_set_text(LIVES_ENTRY(combo_entries[idx]),(tmp=rte_keymode_get_filter_name(key,mode)));
+      rtew_combo_set_text(key,mode,(tmp=rte_keymode_get_filter_name(key,mode)));
       lives_free(tmp);
 
       if (fx_idx!=-1) {
@@ -1586,14 +1564,12 @@ boolean on_load_keymap_clicked(LiVESButton *button, livespointer user_data) {
 
 
   if (keymap_file2==NULL) {
-    lives_list_free_strings(list);
-    lives_list_free(list);
+    lives_list_free_all(&list);
 
     if (update>0) {
       d_print(_("update required.\n"));
       on_save_keymap_clicked(NULL,new_list);
-      lives_list_free_strings(new_list);
-      lives_list_free(new_list);
+      lives_list_free_all(&new_list);
       on_load_keymap_clicked(NULL,NULL);
     } else d_print_done();
   } else {
@@ -1645,6 +1621,7 @@ void on_rte_info_clicked(LiVESButton *button, livespointer user_data) {
   LiVESWidget *dialog;
 
   LiVESWidget *vbox;
+  LiVESWidget *abox;
   LiVESWidget *hbox;
   LiVESWidget *label;
   LiVESWidget *textview;
@@ -1653,13 +1630,19 @@ void on_rte_info_clicked(LiVESButton *button, livespointer user_data) {
 
   char *filter_name;
   char *filter_author;
+  char *filter_copyright;
   char *filter_extra_authors=NULL;
   char *filter_description;
+  char *url;
+  char *license;
   char *tmp;
   char *type;
   char *plugin_name;
 
   boolean has_desc=FALSE;
+  boolean has_url=FALSE;
+  boolean has_license=FALSE;
+  boolean has_copyright=FALSE;
 
   int filter_version;
   int weed_error;
@@ -1678,17 +1661,31 @@ void on_rte_info_clicked(LiVESButton *button, livespointer user_data) {
 
   plugin_name=rte_keymode_get_plugin_name(key+1,mode);
   filter=rte_keymode_get_filter(key+1,mode);
-  filter_name=weed_get_string_value(filter,"name",&weed_error);
-  filter_author=weed_get_string_value(filter,"author",&weed_error);
-  if (weed_plant_has_leaf(filter,"extra_authors")) filter_extra_authors=weed_get_string_value(filter,"extra_authors",&weed_error);
-  if (weed_plant_has_leaf(filter,"description")) {
-    filter_description=weed_get_string_value(filter,"description",&weed_error);
+  filter_name=weed_get_string_value(filter,WEED_LEAF_NAME,&weed_error);
+  filter_author=weed_get_string_value(filter,WEED_LEAF_AUTHOR,&weed_error);
+  if (weed_plant_has_leaf(filter,WEED_LEAF_EXTRA_AUTHORS)) filter_extra_authors=weed_get_string_value(filter,WEED_LEAF_EXTRA_AUTHORS,
+        &weed_error);
+  if (weed_plant_has_leaf(filter,WEED_LEAF_COPYRIGHT)) {
+    filter_copyright=weed_get_string_value(filter,WEED_LEAF_COPYRIGHT,&weed_error);
+    has_copyright=TRUE;
+  }
+  if (weed_plant_has_leaf(filter,WEED_LEAF_DESCRIPTION)) {
+    filter_description=weed_get_string_value(filter,WEED_LEAF_DESCRIPTION,&weed_error);
     has_desc=TRUE;
   }
+  if (weed_plant_has_leaf(filter,WEED_LEAF_URL)) {
+    url=weed_get_string_value(filter,WEED_LEAF_URL,&weed_error);
+    has_url=TRUE;
+  }
 
-  filter_version=weed_get_int_value(filter,"version",&weed_error);
+  if (weed_plant_has_leaf(filter,WEED_LEAF_LICENSE)) {
+    license=weed_get_string_value(filter,WEED_LEAF_LICENSE,&weed_error);
+    has_license=TRUE;
+  }
 
-  tmp=lives_strdup_printf(_("LiVES: Information for %s"),filter_name);
+  filter_version=weed_get_int_value(filter,WEED_LEAF_VERSION,&weed_error);
+
+  tmp=lives_strdup_printf(_("Information for %s"),filter_name);
 
   dialog=lives_standard_dialog_new(tmp,FALSE,RTE_INFO_WIDTH,RTE_INFO_HEIGHT);
 
@@ -1718,10 +1715,17 @@ void on_rte_info_clicked(LiVESButton *button, livespointer user_data) {
     lives_box_pack_start(LIVES_BOX(vbox), label, TRUE, FALSE, widget_opts.packing_height);
   }
 
+  if (has_url) {
+    label = lives_standard_label_new((tmp=lives_strdup_printf(_("URL: %s"),url)));
+    lives_free(tmp);
+    lives_box_pack_start(LIVES_BOX(vbox), label, TRUE, FALSE, widget_opts.packing_height);
+  }
+
   label = lives_standard_label_new((tmp=lives_strdup_printf(_("Version: %d"),filter_version)));
   lives_free(tmp);
   lives_box_pack_start(LIVES_BOX(vbox), label, TRUE, FALSE, widget_opts.packing_height);
 
+
   if (has_desc) {
     hbox = lives_hbox_new(FALSE, widget_opts.packing_width);
     lives_box_pack_start(LIVES_BOX(vbox), hbox, TRUE, FALSE, widget_opts.packing_height);
@@ -1729,25 +1733,41 @@ void on_rte_info_clicked(LiVESButton *button, livespointer user_data) {
     label = lives_standard_label_new(_("Description: "));
     lives_box_pack_start(LIVES_BOX(hbox), label, FALSE, FALSE, widget_opts.packing_height);
 
-    textview = lives_text_view_new();
+    textview = lives_standard_text_view_new(filter_description,NULL);
 
     if (palette->style&STYLE_1) {
       lives_widget_set_text_color(textview, LIVES_WIDGET_STATE_NORMAL, &palette->normal_fore);
       lives_widget_set_base_color(textview, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
     }
 
-    lives_text_view_set_editable(LIVES_TEXT_VIEW(textview), FALSE);
-    lives_text_view_set_wrap_mode(LIVES_TEXT_VIEW(textview), LIVES_WRAP_WORD);
-    lives_text_view_set_cursor_visible(LIVES_TEXT_VIEW(textview), FALSE);
-
-    lives_text_view_set_text(LIVES_TEXT_VIEW(textview), filter_description,-1);
     lives_box_pack_start(LIVES_BOX(hbox), textview, TRUE, TRUE, widget_opts.packing_height);
+
+  }
+
+  if (has_license) {
+    label = lives_standard_label_new((tmp=lives_strdup_printf(_("License: %s"),license)));
+    lives_free(tmp);
+    lives_box_pack_start(LIVES_BOX(vbox), label, TRUE, FALSE, widget_opts.packing_height);
+  }
+
+
+  if (has_copyright) {
+    label = lives_standard_label_new((tmp=lives_strdup_printf(_("Copyright: %s"),filter_copyright)));
+    lives_free(tmp);
+    lives_box_pack_start(LIVES_BOX(vbox), label, TRUE, FALSE, widget_opts.packing_height);
   }
 
 
   ok_button = lives_button_new_from_stock(LIVES_STOCK_OK,NULL);
   lives_dialog_add_action_widget(LIVES_DIALOG(dialog), ok_button, LIVES_RESPONSE_OK);
 
+  abox=lives_dialog_get_action_area(LIVES_DIALOG(dialog));
+#if !GTK_CHECK_VERSION(3,0,0)
+  lives_button_box_set_layout(LIVES_BUTTON_BOX(abox),LIVES_BUTTONBOX_CENTER);
+#else
+  if (LIVES_IS_BOX(abox)) add_fill_to_box(LIVES_BOX(abox));
+#endif
+
   lives_widget_set_can_focus_and_default(ok_button);
   lives_widget_grab_default(ok_button);
 
@@ -1759,8 +1779,11 @@ void on_rte_info_clicked(LiVESButton *button, livespointer user_data) {
 
   lives_free(filter_name);
   lives_free(filter_author);
-  if (filter_extra_authors!=NULL) lives_free(filter_extra_authors);
+  lives_freep((void **)&filter_extra_authors);
   if (has_desc) lives_free(filter_description);
+  if (has_url) lives_free(url);
+  if (has_license) lives_free(license);
+  if (has_copyright) lives_free(filter_copyright);
   lives_free(plugin_name);
   lives_free(type);
 
@@ -1805,8 +1828,7 @@ void on_clear_clicked(LiVESButton *button, livespointer user_data) {
     if (rte_window!=NULL) {
       int fx_idx=rte_keymode_get_filter_idx(key,mode);
       idx=key*modes+i;
-      lives_entry_set_text(LIVES_ENTRY(combo_entries[idx]),lives_entry_get_text(LIVES_ENTRY(combo_entries[idx+1])));
-      type_label_set_text(key,i);
+      rtew_combo_set_text(key,i,lives_entry_get_text(LIVES_ENTRY(combo_entries[idx+1])));
 
       if (fx_idx!=-1) {
         char *hashname=(char *)lives_list_nth_data(hash_list,fx_idx);
@@ -1820,7 +1842,7 @@ void on_clear_clicked(LiVESButton *button, livespointer user_data) {
   idx++;
 
   if (rte_window!=NULL) {
-    lives_entry_set_text(LIVES_ENTRY(combo_entries[idx]),"");
+    rtew_combo_set_text(key,i,"");
     lives_widget_object_set_data(LIVES_WIDGET_OBJECT(combos[idx]),"hashname",empty_string);
 
     // set parameters button sensitive/insensitive
@@ -1873,7 +1895,8 @@ static void on_params_clicked(LiVESButton *button, livespointer user_data) {
     weed_plant_t *ninst=inst;
     do {
       weed_instance_ref(ninst);
-    } while (weed_plant_has_leaf(ninst,"host_next_instance")&&(ninst=weed_get_plantptr_value(ninst,"host_next_instance",&error))!=NULL);
+    } while (weed_plant_has_leaf(ninst,WEED_LEAF_HOST_NEXT_INSTANCE)&&
+             (ninst=weed_get_plantptr_value(ninst,WEED_LEAF_HOST_NEXT_INSTANCE,&error))!=NULL);
   }
 
 
@@ -1890,7 +1913,7 @@ static void on_params_clicked(LiVESButton *button, livespointer user_data) {
   on_fx_pre_activate(rfx,1,NULL);
 
   // record the key so we know whose parameters to record later
-  weed_set_int_value((weed_plant_t *)rfx->source,"host_key",key);
+  weed_set_int_value((weed_plant_t *)rfx->source,WEED_LEAF_HOST_KEY,key);
 
   lives_widget_object_set_data(LIVES_WIDGET_OBJECT(fx_dialog[1]),"key",LIVES_INT_TO_POINTER(key));
   lives_widget_object_set_data(LIVES_WIDGET_OBJECT(fx_dialog[1]),"mode",LIVES_INT_TO_POINTER(mode));
@@ -1904,23 +1927,9 @@ static boolean on_rtew_delete_event(LiVESWidget *widget, LiVESXEventDelete *even
     old_rte_keys_virtual=prefs->rte_keys_virtual;
     lives_widget_hide(rte_window);
   } else {
-    if (hash_list!=NULL) {
-      lives_list_free_strings(hash_list);
-      lives_list_free(hash_list);
-      hash_list=NULL;
-    }
-
-    if (name_list!=NULL) {
-      lives_list_free_strings(name_list);
-      lives_list_free(name_list);
-      name_list=NULL;
-    }
-
-    if (name_type_list!=NULL) {
-      lives_list_free_strings(name_type_list);
-      lives_list_free(name_type_list);
-      name_type_list=NULL;
-    }
+    lives_list_free_all(&hash_list);
+    lives_list_free_all(&name_list);
+    lives_list_free_all(&name_type_list);
 
     lives_free(key_checks);
     lives_free(key_grabs);
@@ -1966,6 +1975,13 @@ enum {
 };
 
 
+void rtew_combo_set_text(int key, int mode, const char *txt) {
+  // key is zero based
+  int key_mode=key*rte_getmodespk()+mode;
+  lives_entry_set_text(LIVES_ENTRY(combo_entries[key_mode]),txt);
+  type_label_set_text(key,mode);
+}
+
 
 void fx_changed(LiVESCombo *combo, livespointer user_data) {
   LiVESTreeIter iter1;
@@ -2025,7 +2041,7 @@ void fx_changed(LiVESCombo *combo, livespointer user_data) {
   model=lives_combo_get_model(combo);
 
   lives_tree_model_get(model,&iter1,NAME_COLUMN,&txt,-1);
-  lives_entry_set_text(LIVES_ENTRY(combo_entries[key_mode]),txt);
+  rtew_combo_set_text(key,mode,txt);
   lives_free(txt);
 
   lives_widget_object_set_data(LIVES_WIDGET_OBJECT(combo),"hashname",hashname1);
@@ -2066,12 +2082,12 @@ static LiVESTreeModel *rte_window_fx_model(void) {
 
   while (list!=NULL) {
     weed_plant_t *filter=get_weed_filter(weed_get_idx_for_hashname((char *)lives_list_nth_data(hash_list,fx_idx),TRUE));
-    int filter_flags=weed_get_int_value(filter,"flags",&error);
-    if ((weed_plant_has_leaf(filter,"plugin_unstable")&&weed_get_boolean_value(filter,"plugin_unstable",&error)==
+    int filter_flags=weed_get_int_value(filter,WEED_LEAF_FLAGS,&error);
+    if ((weed_plant_has_leaf(filter,WEED_LEAF_PLUGIN_UNSTABLE)&&weed_get_boolean_value(filter,WEED_LEAF_PLUGIN_UNSTABLE,&error)==
          WEED_TRUE&&!prefs->unstable_fx)||((enabled_in_channels(filter,FALSE)>1&&
                                             !has_video_chans_in(filter,FALSE))||
-                                           (weed_plant_has_leaf(filter,"host_menu_hide")&&
-                                            weed_get_boolean_value(filter,"host_menu_hide",&error)==WEED_TRUE)
+                                           (weed_plant_has_leaf(filter,WEED_LEAF_HOST_MENU_HIDE)&&
+                                            weed_get_boolean_value(filter,WEED_LEAF_HOST_MENU_HIDE,&error)==WEED_TRUE)
                                            ||(filter_flags&WEED_FILTER_IS_CONVERTER))) {
       list = list->next;
       fx_idx++;
@@ -2084,8 +2100,7 @@ static LiVESTreeModel *rte_window_fx_model(void) {
     if ((pkgstring=strstr(fxname,": "))!=NULL) {
       // package effect
       if (pkg!=NULL&&strncmp(pkg,fxname,strlen(pkg))) {
-        lives_free(pkg);
-        pkg=NULL;
+        lives_freep((void **)&pkg);
         lives_tree_store_append(tstore, &iter1, NULL);   /* Acquire an iterator */
         lives_tree_store_set(tstore,&iter1,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
                              HASH_COLUMN,lives_list_nth_data(hash_list,fx_idx),-1);
@@ -2105,8 +2120,7 @@ static LiVESTreeModel *rte_window_fx_model(void) {
       lives_tree_store_set(tstore,&iter2,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
                            HASH_COLUMN,lives_list_nth_data(hash_list,fx_idx),-1);
     } else {
-      if (pkg!=NULL) lives_free(pkg);
-      pkg=NULL;
+      if (pkg!=NULL) lives_freep((void **)&pkg);
       lives_tree_store_append(tstore, &iter1, NULL);   /* Acquire an iterator */
       lives_tree_store_set(tstore,&iter1,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
                            HASH_COLUMN,lives_list_nth_data(hash_list,fx_idx),-1);
@@ -2118,7 +2132,7 @@ static LiVESTreeModel *rte_window_fx_model(void) {
     fx_idx++;
   }
 
-  if (pkg!=NULL) lives_free(pkg);
+  lives_freep((void **)&pkg);
 
   return (LiVESTreeModel *)tstore;
 }
@@ -2204,7 +2218,7 @@ LiVESWidget *create_rte_window(void) {
     lives_widget_set_bg_color(rte_window, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars);
     lives_widget_set_text_color(rte_window, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars_fore);
   }
-  lives_window_set_title(LIVES_WINDOW(rte_window), _("LiVES: Real time effect mapping"));
+  lives_window_set_title(LIVES_WINDOW(rte_window), _("Real Time Effect Mapping"));
   lives_window_add_accel_group(LIVES_WINDOW(rte_window), mainw->accel_group);
 
   table = lives_table_new(prefs->rte_keys_virtual, modes+1, FALSE);
@@ -2367,6 +2381,12 @@ LiVESWidget *create_rte_window(void) {
   lives_container_add(LIVES_CONTAINER(rte_window), top_vbox);
 
   hbuttonbox = lives_hbutton_box_new();
+  label=add_fill_to_box(LIVES_BOX(hbuttonbox));
+
+  if (palette->style&STYLE_1) {
+    lives_widget_set_bg_color(label, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars);
+  }
+
   lives_box_pack_start(LIVES_BOX(top_vbox), hbuttonbox, FALSE, TRUE, widget_opts.packing_height*2);
 
   lives_container_add(LIVES_CONTAINER(hbuttonbox), clear_all_button);
@@ -2387,11 +2407,19 @@ LiVESWidget *create_rte_window(void) {
   lives_container_add(LIVES_CONTAINER(hbuttonbox), ok_button);
   lives_widget_set_can_focus_and_default(ok_button);
 
+  label=add_fill_to_box(LIVES_BOX(hbuttonbox));
+
+  if (palette->style&STYLE_1) {
+    lives_widget_set_bg_color(label, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars);
+  }
+
+
   lives_button_box_set_button_width(LIVES_BUTTON_BOX(hbuttonbox), clear_all_button, DEF_BUTTON_WIDTH);
   lives_button_box_set_button_width(LIVES_BUTTON_BOX(hbuttonbox), save_keymap_button, DEF_BUTTON_WIDTH);
   lives_button_box_set_button_width(LIVES_BUTTON_BOX(hbuttonbox), load_keymap_button, DEF_BUTTON_WIDTH);
   lives_button_box_set_button_width(LIVES_BUTTON_BOX(hbuttonbox), ok_button, DEF_BUTTON_WIDTH);
 
+
   rtew_accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new());
   lives_window_add_accel_group(LIVES_WINDOW(rte_window), rtew_accel_group);
 
@@ -2501,30 +2529,27 @@ void redraw_pwindow(int key, int mode) {
   LiVESList *child_list;
   lives_rfx_t *rfx;
 
-  LiVESWidget *content_area;
+  LiVESWidget *content_area,*button;
 
   int keyw=0,modew=0;
   int i;
 
   if (fx_dialog[1]!=NULL) {
     rfx=(lives_rfx_t *)lives_widget_object_get_data(LIVES_WIDGET_OBJECT(fx_dialog[1]),"rfx");
+    button=(LiVESWidget *)lives_widget_object_get_data(LIVES_WIDGET_OBJECT(fx_dialog[1]),"button");
     if (!rfx->is_template) {
       keyw=LIVES_POINTER_TO_INT(lives_widget_object_get_data(LIVES_WIDGET_OBJECT(fx_dialog[1]),"key"));
       modew=LIVES_POINTER_TO_INT(lives_widget_object_get_data(LIVES_WIDGET_OBJECT(fx_dialog[1]),"mode"));
     }
     if (rfx->is_template||(key==keyw&&mode==modew)) {
       // rip out the contents
-      if (mainw->invis==NULL) mainw->invis=lives_vbox_new(FALSE,0);
       content_area=lives_dialog_get_content_area(LIVES_DIALOG(fx_dialog[1]));
       child_list=lives_container_get_children(LIVES_CONTAINER(content_area));
       // remove focus from any widget we are ripping out
-      lives_container_set_focus_child(LIVES_CONTAINER(content_area),NULL);
       for (i=0; i<lives_list_length(child_list); i++) {
         LiVESWidget *widget=(LiVESWidget *)lives_list_nth_data(child_list,i);
-        // we have to do this, because using lives_widget_destroy() here
-        // can causes a crash [bug in gtk+ ???]
-        // TODO - test: is this still the case ?
-        lives_widget_reparent(widget,mainw->invis);
+        if (lives_widget_is_ancestor(LIVES_WIDGET(button),widget)) continue;
+        lives_widget_destroy(widget);
       }
       if (child_list!=NULL) lives_list_free(child_list);
       on_paramwindow_cancel_clicked(NULL,NULL);
@@ -2604,7 +2629,7 @@ void rte_set_key_defs(LiVESButton *button, lives_rfx_t *rfx) {
 void rte_set_defs_ok(LiVESButton *button, lives_rfx_t *rfx) {
   weed_plant_t *ptmpl,*filter;
 
-  lives_colRGB24_t *rgbp;
+  lives_colRGB48_t *rgbp;
 
   register int i;
 
@@ -2619,21 +2644,22 @@ void rte_set_defs_ok(LiVESButton *button, lives_rfx_t *rfx) {
       ptmpl=weed_filter_in_paramtmpl(filter,i,FALSE);
       switch (rfx->params[i].type) {
       case LIVES_PARAM_COLRGB24:
-        rgbp=(lives_colRGB24_t *)rfx->params[i].value;
+        rgbp=(lives_colRGB48_t *)rfx->params[i].value;
         update_weed_color_value(filter,i,rgbp->red,rgbp->green,rgbp->blue,0);
         break;
       case LIVES_PARAM_STRING:
-        weed_set_string_value(ptmpl,"host_default",(char *)rfx->params[i].value);
+        weed_set_string_value(ptmpl,WEED_LEAF_HOST_DEFAULT,(char *)rfx->params[i].value);
         break;
       case LIVES_PARAM_STRING_LIST:
-        weed_set_int_array(ptmpl,"host_default",1,(int *)rfx->params[i].value);
+        weed_set_int_array(ptmpl,WEED_LEAF_HOST_DEFAULT,1,(int *)rfx->params[i].value);
         break;
       case LIVES_PARAM_NUM:
-        if (weed_leaf_seed_type(ptmpl,"default")==WEED_SEED_DOUBLE) weed_set_double_array(ptmpl,"host_default",1,(double *)rfx->params[i].value);
-        else weed_set_int_array(ptmpl,"host_default",1,(int *)rfx->params[i].value);
+        if (weed_leaf_seed_type(ptmpl,WEED_LEAF_DEFAULT)==WEED_SEED_DOUBLE) weed_set_double_array(ptmpl,WEED_LEAF_HOST_DEFAULT,1,
+              (double *)rfx->params[i].value);
+        else weed_set_int_array(ptmpl,WEED_LEAF_HOST_DEFAULT,1,(int *)rfx->params[i].value);
         break;
       case LIVES_PARAM_BOOL:
-        weed_set_boolean_array(ptmpl,"host_default",1,(int *)rfx->params[i].value);
+        weed_set_boolean_array(ptmpl,WEED_LEAF_HOST_DEFAULT,1,(int *)rfx->params[i].value);
         break;
       default:
         break;
@@ -2688,9 +2714,9 @@ void rte_reset_defs_clicked(LiVESButton *button, lives_rfx_t *rfx) {
 
     if (is_generic_defs) {
       // for generic, reset from plugin supplied defs
-      ptmpls=weed_get_plantptr_array(filter,"in_parameter_templates",&error);
+      ptmpls=weed_get_plantptr_array(filter,WEED_LEAF_IN_PARAMETER_TEMPLATES,&error);
       for (i=0; i<rfx->num_params; i++) {
-        if (weed_plant_has_leaf(ptmpls[i],"host_default")) weed_leaf_delete(ptmpls[i],"host_default");
+        if (weed_plant_has_leaf(ptmpls[i],WEED_LEAF_HOST_DEFAULT)) weed_leaf_delete(ptmpls[i],WEED_LEAF_HOST_DEFAULT);
       }
       lives_free(ptmpls);
     }
@@ -2712,12 +2738,12 @@ resetdefs1:
     xinp[x]=NULL;
     poffset+=ninpar;
 
-    weed_set_plantptr_array(inst,"in_parameters",weed_flagset_array_count(xinp,TRUE),xinp);
+    weed_set_plantptr_array(inst,WEED_LEAF_IN_PARAMETERS,weed_flagset_array_count(xinp,TRUE),xinp);
     lives_free(xinp);
 
-    if (weed_plant_has_leaf(inst,"host_next_instance")) {
+    if (weed_plant_has_leaf(inst,WEED_LEAF_HOST_NEXT_INSTANCE)) {
       // handle compound fx
-      inst=weed_get_plantptr_value(inst,"host_next_instance",&error);
+      inst=weed_get_plantptr_value(inst,WEED_LEAF_HOST_NEXT_INSTANCE,&error);
       add_pcons=TRUE;
       goto resetdefs1;
     }
@@ -2738,14 +2764,14 @@ resetdefs1:
   }
 
   if (is_generic_defs) {
-    if (weed_plant_has_leaf(filter,"host_fps")) weed_leaf_delete(filter,"host_fps");
+    if (weed_plant_has_leaf(filter,WEED_LEAF_HOST_FPS)) weed_leaf_delete(filter,WEED_LEAF_HOST_FPS);
 
-    if (weed_plant_has_leaf(filter,"out_channel_templates")) {
-      ctmpls=weed_get_plantptr_array(filter,"out_channel_templates",&error);
-      nchans=weed_leaf_num_elements(filter,"out_channel_templates");
+    if (weed_plant_has_leaf(filter,WEED_LEAF_OUT_CHANNEL_TEMPLATES)) {
+      ctmpls=weed_get_plantptr_array(filter,WEED_LEAF_OUT_CHANNEL_TEMPLATES,&error);
+      nchans=weed_leaf_num_elements(filter,WEED_LEAF_OUT_CHANNEL_TEMPLATES);
       for (i=0; i<nchans; i++) {
-        if (weed_plant_has_leaf(ctmpls[i],"host_width")) weed_leaf_delete(ctmpls[i],"host_width");
-        if (weed_plant_has_leaf(ctmpls[i],"host_height")) weed_leaf_delete(ctmpls[i],"host_height");
+        if (weed_plant_has_leaf(ctmpls[i],WEED_LEAF_HOST_WIDTH)) weed_leaf_delete(ctmpls[i],WEED_LEAF_HOST_WIDTH);
+        if (weed_plant_has_leaf(ctmpls[i],WEED_LEAF_HOST_HEIGHT)) weed_leaf_delete(ctmpls[i],WEED_LEAF_HOST_HEIGHT);
       }
     }
   } else {
@@ -2760,17 +2786,14 @@ resetdefs1:
 
   // redraw the window
 
-  if (mainw->invis==NULL) mainw->invis=lives_vbox_new(FALSE,0);
   content_area=lives_dialog_get_content_area(LIVES_DIALOG(fx_dialog[1]));
   child_list=lives_container_get_children(LIVES_CONTAINER(content_area));
   // remove focus from any widget we are ripping out
   lives_container_set_focus_child(LIVES_CONTAINER(content_area),NULL);
   for (i=0; i<lives_list_length(child_list); i++) {
     LiVESWidget *widget=(LiVESWidget *)lives_list_nth_data(child_list,i);
-    // we have to do this, because using lives_widget_destroy() here
-    // can causes a crash [bug in gtk+ ???]
-    // TODO - test: is this still the case ?
-    lives_widget_reparent(widget,mainw->invis);
+    if (lives_widget_is_ancestor(LIVES_WIDGET(button),widget)) continue;
+    lives_widget_destroy(widget);
   }
 
   if (child_list!=NULL) lives_list_free(child_list);
@@ -2790,7 +2813,7 @@ void load_default_keymap(void) {
   char *dir=lives_build_filename(capable->home_dir,LIVES_CONFIG_DIR,NULL);
   char *keymap_file=lives_build_filename(dir,"default.keymap",NULL);
   char *keymap_template=lives_build_filename(prefs->prefix_dir,DATA_DIR,"default.keymap",NULL);
-  char *com,*tmp;
+  char *tmp;
 
   int retval;
 
@@ -2806,14 +2829,8 @@ void load_default_keymap(void) {
         lives_mkdir_with_parents(dir,S_IRWXU);
       }
 
-#ifndef IS_MINGW
-      com=lives_strdup_printf("%s \"%s\" \"%s\"",capable->cp_cmd,keymap_template,keymap_file);
-#else
-      com=lives_strdup_printf("cp.exe \"%s\" \"%s\"",keymap_template,keymap_file);
-#endif
+      lives_cp(keymap_template,keymap_file);
 
-      lives_system(com,TRUE); // allow this to fail - we will check for errors below
-      lives_free(com);
     }
     if (!lives_file_test(keymap_file, LIVES_FILE_TEST_EXISTS)) {
       // give up
