@@ -1,6 +1,6 @@
 // startup.c
 // LiVES
-// (c) G. Finch 2010 - 2015 <salsaman@gmail.com>
+// (c) G. Finch 2010 - 2016 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -56,34 +56,45 @@ static boolean prompt_new_dir(char *dirname, uint64_t freespace, boolean wrtable
 }
 
 
+void close_file(int current_file, boolean tshoot) {
+  char *com;
+
+  if (tshoot) close_current_file(current_file);
+  else {
+#ifdef IS_MINGW
+    // kill any active processes: for other OSes the backend does this
+    lives_kill_subprocesses(cfile->handle,TRUE);
+#endif
+
+    com=lives_strdup_printf("%s close \"%s\"",prefs->backend_sync,cfile->handle);
+    lives_system(com,TRUE);
+    lives_free(com);
+  }
+}
 
 
-boolean do_tempdir_query(void) {
-  _entryw *tdentry;
+
+boolean do_workdir_query(void) {
   uint64_t freesp;
 
   int response;
   boolean ok=FALSE;
 
   char *dirname;
-#ifndef IS_MINGW
-  char *com;
-#endif
 
 top:
 
-  tdentry=create_rename_dialog(6);
+  renamew=create_rename_dialog(6);
 
   while (!ok) {
-    response=lives_dialog_run(LIVES_DIALOG(tdentry->dialog));
+    response=lives_dialog_run(LIVES_DIALOG(renamew->dialog));
 
-    if (response==LIVES_RESPONSE_CANCEL) {
-      return FALSE;
-    }
-    dirname=lives_strdup(lives_entry_get_text(LIVES_ENTRY(tdentry->entry)));
+    if (response==LIVES_RESPONSE_CANCEL) return FALSE;
 
-    if (strcmp(dirname+strlen(dirname)-1,LIVES_DIR_SEPARATOR_S)) {
-      char *tmp=lives_strdup_printf("%s%s",dirname,LIVES_DIR_SEPARATOR_S);
+    dirname=lives_strdup(lives_entry_get_text(LIVES_ENTRY(renamew->entry)));
+
+    if (strcmp(dirname+strlen(dirname)-1,LIVES_DIR_SEP)) {
+      char *tmp=lives_strdup_printf("%s%s",dirname,LIVES_DIR_SEP);
       lives_free(dirname);
       dirname=tmp;
     }
@@ -118,13 +129,13 @@ top:
       if (is_writeable_dir(dirname)) {
         freesp=get_fs_free(dirname);
         if (!prompt_new_dir(dirname,freesp,TRUE)) {
-          rmdir(dirname);
+          lives_rmdir(dirname,FALSE);
           lives_free(dirname);
           continue;
         }
       } else {
         if (!prompt_new_dir(dirname,0,FALSE)) {
-          rmdir(dirname);
+          lives_rmdir(dirname,FALSE);
           lives_free(dirname);
           continue;
         }
@@ -134,32 +145,23 @@ top:
     ok=TRUE;
   }
 
-  lives_widget_destroy(tdentry->dialog);
-  lives_free(tdentry);
+  lives_widget_destroy(renamew->dialog);
+  lives_freep((void **)&renamew);
 
   mainw->com_failed=FALSE;
 
   if (!lives_file_test(dirname,LIVES_FILE_TEST_IS_DIR)) {
-    if (lives_mkdir_with_parents(dirname,S_IRWXU)==-1) goto top;
+    if (lives_mkdir_with_parents(dirname,capable->umask)==-1) goto top;
   }
 
-#ifndef IS_MINGW
-  com=lives_strdup_printf("%s 777 \"%s\" 2>/dev/null",capable->chmod_cmd,dirname);
-  lives_system(com,FALSE);
-  lives_free(com);
-#endif
 
-  lives_snprintf(prefs->tmpdir,PATH_MAX,"%s",dirname);
-  lives_snprintf(future_prefs->tmpdir,PATH_MAX,"%s",prefs->tmpdir);
+  lives_snprintf(prefs->workdir,PATH_MAX,"%s",dirname);
+  lives_snprintf(future_prefs->workdir,PATH_MAX,"%s",prefs->workdir);
 
-  set_pref("tempdir",prefs->tmpdir);
-  set_pref("session_tempdir",prefs->tmpdir);
+  set_pref(PREF_WORKING_DIR,prefs->workdir);
+  set_pref(PREF_SESSION_WORKDIR,prefs->workdir);
 
-#ifndef IS_MINGW
-  lives_snprintf(mainw->first_info_file,PATH_MAX,"%s"LIVES_DIR_SEPARATOR_S".info.%d",prefs->tmpdir,capable->mainpid);
-#else
-  lives_snprintf(mainw->first_info_file,PATH_MAX,"%s"LIVES_DIR_SEPARATOR_S"info.%d",prefs->tmpdir,capable->mainpid);
-#endif
+  lives_snprintf(mainw->first_info_file,PATH_MAX,"%s"LIVES_DIR_SEP LIVES_INFO_FILE_NAME".%d",prefs->workdir,capable->mainpid);
 
   lives_free(dirname);
   return TRUE;
@@ -178,19 +180,19 @@ static void on_init_aplayer_toggled(LiVESToggleButton *tbutton, livespointer use
 
   switch (audp) {
   case AUD_PLAYER_PULSE:
-    set_pref("audio_player","pulse");
+    set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_PULSE);
     break;
   case AUD_PLAYER_JACK:
-    set_pref("audio_player","jack");
+    set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_JACK);
     break;
   case AUD_PLAYER_SOX:
-    set_pref("audio_player","sox");
+    set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_SOX);
     break;
   case AUD_PLAYER_MPLAYER:
-    set_pref("audio_player","mplayer");
+    set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_MPLAYER);
     break;
   case AUD_PLAYER_MPLAYER2:
-    set_pref("audio_player","mplayer2");
+    set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_MPLAYER2);
     break;
   }
 
@@ -247,7 +249,8 @@ boolean do_audio_choice_dialog(short startup_phase) {
     txt4=lives_strdup(_(", but you do not have jackd installed. You may wish to install jackd first before running LiVES.\n\n"));
   } else {
     txt4=lives_strdup(
-           _(", but may prevent LiVES from starting on some systems.\nIf LiVES will not start with jack, you can restart and try with another audio player instead.\n\n"));
+           _(", but may prevent LiVES from starting on some systems.\nIf LiVES will not start with jack,"
+             "you can restart and try with another audio player instead.\n\n"));
   }
 #endif
 
@@ -276,7 +279,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
   lives_free(txt6);
   lives_free(txt7);
 
-  dialog = lives_standard_dialog_new(_("LiVES: - Choose an audio player"),FALSE,-1,-1);
+  dialog = lives_standard_dialog_new(_("Choose an audio player"),FALSE,-1,-1);
 
   accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new());
   lives_window_add_accel_group(LIVES_WINDOW(dialog), accel_group);
@@ -300,7 +303,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
   if (prefs->audio_player==AUD_PLAYER_PULSE) {
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton0),TRUE);
-    set_pref("audio_player","pulse");
+    set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_PULSE);
   }
 
   lives_signal_connect(LIVES_GUI_OBJECT(radiobutton0), LIVES_WIDGET_TOGGLED_SIGNAL,
@@ -321,7 +324,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
   if (prefs->audio_player==AUD_PLAYER_JACK||!capable->has_pulse_audio||prefs->audio_player==-1) {
     prefs->audio_player=AUD_PLAYER_JACK;
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton1),TRUE);
-    set_pref("audio_player","jack");
+    set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_JACK);
   }
 
   lives_signal_connect(LIVES_GUI_OBJECT(radiobutton1), LIVES_WIDGET_TOGGLED_SIGNAL,
@@ -342,7 +345,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
     if (prefs->audio_player==AUD_PLAYER_SOX) {
       lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton2),TRUE);
-      set_pref("audio_player","sox");
+      set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_SOX);
     }
 
     lives_signal_connect(LIVES_GUI_OBJECT(radiobutton2), LIVES_WIDGET_TOGGLED_SIGNAL,
@@ -362,7 +365,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
     if (prefs->audio_player==AUD_PLAYER_MPLAYER) {
       lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton3),TRUE);
-      set_pref("audio_player","mplayer");
+      set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_MPLAYER);
     }
 
     lives_signal_connect(LIVES_GUI_OBJECT(radiobutton3), LIVES_WIDGET_TOGGLED_SIGNAL,
@@ -382,7 +385,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
     if (prefs->audio_player==AUD_PLAYER_MPLAYER2) {
       lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton4),TRUE);
-      set_pref("audio_player","mplayer2");
+      set_pref(PREF_AUDIO_PLAYER,AUDIO_PLAYER_MPLAYER2);
     }
 
     lives_signal_connect(LIVES_GUI_OBJECT(radiobutton4), LIVES_WIDGET_TOGGLED_SIGNAL,
@@ -518,9 +521,14 @@ boolean do_startup_tests(boolean tshoot) {
 
   LiVESAccelGroup *accel_group;
 
+  char mppath[PATH_MAX];
+
   char *com,*rname,*afile,*tmp;
   char *image_ext=lives_strdup(prefs->image_ext);
-  char *title;
+  char *title,*msg;
+
+  const char *mp_cmd;
+  const char *lookfor;
 
   uint8_t *abuff;
 
@@ -546,9 +554,9 @@ boolean do_startup_tests(boolean tshoot) {
   }
 
   if (!tshoot) {
-    title=lives_strdup(_("LiVES: - Testing Configuration"));
+    title=lives_strdup(_("Testing Configuration"));
   } else {
-    title=lives_strdup(_("LiVES: - Troubleshoot"));
+    title=lives_strdup(_("Troubleshoot"));
   }
 
 
@@ -607,7 +615,7 @@ boolean do_startup_tests(boolean tshoot) {
   // test if sox can convert raw 44100 -> wav 22050
   add_test(table,1,_("Checking if sox can convert audio"),success);
 
-  if (!tshoot) set_pref("default_image_format","png");
+  if (!tshoot) set_pref(PREF_DEFAULT_IMAGE_FORMAT,LIVES_IMAGE_TYPE_PNG);
   lives_snprintf(prefs->image_ext,16,"%s",LIVES_FILE_EXT_PNG);
 
   get_temp_handle(mainw->first_free_file,TRUE);
@@ -616,26 +624,24 @@ boolean do_startup_tests(boolean tshoot) {
 
     info_fd=-1;
 
-    unlink(cfile->info_file);
+    lives_rm(cfile->info_file);
 
     // write 1 second of silence
-    afile=lives_build_filename(prefs->tmpdir,cfile->handle,"audio",NULL);
-    out_fd=open(afile,O_WRONLY|O_CREAT,S_IRUSR|S_IWUSR);
+    afile=lives_build_filename(prefs->workdir,cfile->handle,"audio",NULL);
+    out_fd=lives_open3(afile,O_WRONLY|O_CREAT,S_IRUSR|S_IWUSR);
 
     if (out_fd<0) mainw->write_failed=TRUE;
     else mainw->write_failed=FALSE;
 
     if (!mainw->write_failed) {
+      int bytes=44100*4;
       abuff=(uint8_t *)lives_calloc(44100,4);
       if (!abuff) {
-        tmp=lives_strdup(_("Unable to allocate 176400 bytes memory."));
+        tmp=lives_strdup_printf(_("Unable to allocate %d bytes memory."),bytes);
         fail_test(table,1,tmp);
         lives_free(tmp);
       } else {
-#ifdef IS_MINGW
-        setmode(out_fd, O_BINARY);
-#endif
-        lives_write(out_fd,abuff,176400,TRUE);
+        lives_write(out_fd,abuff,bytes,TRUE);
         close(out_fd);
         lives_free(abuff);
       }
@@ -650,7 +656,7 @@ boolean do_startup_tests(boolean tshoot) {
     lives_free(afile);
 
     if (!mainw->write_failed) {
-      afile=lives_build_filename(prefs->tmpdir,cfile->handle,"testout.wav",NULL);
+      afile=lives_build_filename(prefs->workdir,cfile->handle,"testout.wav",NULL);
 
       mainw->com_failed=FALSE;
       com=lives_strdup_printf("%s export_audio \"%s\" 0. 0. 44100 2 16 0 22050 \"%s\"",prefs->backend_sync,cfile->handle,afile);
@@ -674,7 +680,7 @@ boolean do_startup_tests(boolean tshoot) {
         lives_sync();
 
         fsize=sget_file_size(afile);
-        unlink(afile);
+        lives_rm(afile);
         lives_free(afile);
 
         if (fsize==0) {
@@ -691,7 +697,7 @@ boolean do_startup_tests(boolean tshoot) {
 
   if (mainw->cancelled!=CANCEL_NONE) {
     mainw->cancelled=CANCEL_NONE;
-    close_current_file(current_file);
+    close_file(current_file,tshoot);
     lives_widget_destroy(dialog);
     mainw->suppress_dprint=FALSE;
 
@@ -705,20 +711,33 @@ boolean do_startup_tests(boolean tshoot) {
 
 
   // check for mplayer presence
+  success2=TRUE;
 
-  // TODO: mpv
+#ifdef ALLOW_MPV
+  add_test(table,2,_("Checking for \"mplayer\", \"mplayer2\" or \"mpv\" presence"),TRUE);
 
-  add_test(table,2,_("Checking for \"mplayer\" presence"),TRUE);
+  if (!capable->has_mplayer&&!capable->has_mplayer2&&!capable->has_mpv) {
+    success2=fail_test(table,2,_("You should install mplayer, mplayer2 or mpv to be able to use all the decoding features in LiVES"));
+  }
 
+  if (!success&&!capable->has_mplayer2&&!capable->has_mplayer) {
+    success2=FALSE;
+  }
+
+#else
+  add_test(table,2,_("Checking for \"mplayer\" or \"mplayer2\" presence"),TRUE);
 
   if (!capable->has_mplayer&&!capable->has_mplayer2) {
     success2=fail_test(table,2,_("You should install mplayer or mplayer2 to be able to use all the decoding features in LiVES"));
+  }
 
+#endif
+  if (!success2) {
     if (!success) {
       lives_widget_destroy(dialog);
       lives_widget_context_update();
       do_no_mplayer_sox_error();
-      close_current_file(current_file);
+      close_file(current_file,tshoot);
       mainw->suppress_dprint=FALSE;
 
       if (mainw->multitrack!=NULL) {
@@ -737,42 +756,44 @@ boolean do_startup_tests(boolean tshoot) {
 
   // check if mplayer can decode audio
 
-  add_test(table,3,_("Checking if mplayer can convert audio"),success2);
+  if (capable->has_mplayer) mp_cmd=AUDIO_PLAYER_MPLAYER;
+  else if (capable->has_mplayer2) mp_cmd=AUDIO_PLAYER_MPLAYER2;
+  else mp_cmd="mpv";
+
+  get_location(mp_cmd,mppath,PATH_MAX);
+  lives_snprintf(prefs->video_open_command,PATH_MAX+2,"\"%s\"",mppath);
+  set_pref(PREF_VIDEO_OPEN_COMMAND,prefs->video_open_command);
+
+  msg=lives_strdup_printf(_("Checking if %s can convert audio"),mp_cmd);
+  add_test(table,3,msg,success2);
+  lives_free(msg);
 
   res=1;
 
   if (success2) {
-    if (capable->has_mplayer) {
 #ifndef IS_MINGW
-      res=system("LANG=en LANGUAGE=en mplayer -ao help | grep pcm >/dev/null 2>&1");
+    com=lives_strdup_printf("LANG=en LANGUAGE=en %s -ao help | grep pcm >/dev/null 2>&1",prefs->video_open_command);
+    res=lives_system(com,TRUE);
+    lives_free(com);
 #else
-      res=system("mplayer -ao help | grep pcm >NUL 2>&1");
+    com=lives_strdup_printf("%s -ao help | grep pcm >NUL 2>&1",prefs->video_open_command);
+    res=lives_system(com,TRUE);
+    lives_free(com);
 #endif
-    } else if (capable->has_mplayer2) {
-#ifndef IS_MINGW
-      res=system("LANG=en LANGUAGE=en mplayer2 -ao help | grep pcm >/dev/null 2>&1");
-#else
-      res=system("mplayer2 -ao help | grep pcm >NUL 2>&1");
-#endif
-    } else {
-#ifdef ALLOW_MPV
-#ifndef IS_MINGW
-      res=system("LANG=en LANGUAGE=en mpv --ao help | grep pcm >/dev/null 2>&1");
-#else
-      res=system("mpv --ao help | grep pcm >NUL 2>&1");
-#endif
-#endif
-    }
+  }
 
-    if (res==0) {
-      pass_test(table,3);
-    } else {
-      fail_test(table,3,_("You should install mplayer or mplayer2 with pcm/wav support"));
-    }
+  if (res==0) {
+    pass_test(table,3);
+  } else {
+#ifdef ALLOW_MPV
+    fail_test(table,3,_("You should install mplayer,mplayer2 or mpv with pcm/wav support"));
+#else
+    fail_test(table,3,_("You should install mplayer or mplayer2 with pcm/wav support"));
+#endif
   }
 
 
-  // check if mplayer can decode to png/alpha
+  // check if mplayer can decode to png/(alpha)
 
   rname=get_resource("");
 
@@ -784,9 +805,13 @@ boolean do_startup_tests(boolean tshoot) {
 
   lives_free(rname);
 
-  // TODO: mpv
-
-  add_test(table,4,_("Checking if mplayer can decode to png/alpha"),success2&&success4);
+#ifdef ALLOW_PNG24
+  msg=lives_strdup_printf(_("Checking if %s can decode to png"),mp_cmd);
+#else
+  msg=lives_strdup_printf(_("Checking if %s can decode to png/alpha"),mp_cmd);
+#endif
+  add_test(table,4,msg,success2&&success4);
+  lives_free(msg);
 
   success3=FALSE;
 
@@ -796,11 +821,11 @@ boolean do_startup_tests(boolean tshoot) {
 
     info_fd=-1;
 
-    unlink(cfile->info_file);
+    lives_rm(cfile->info_file);
 
     rname=get_resource("vidtest.avi");
 
-    com=lives_strdup_printf("%s open_test \"%s\" \"%s\" 0 png",prefs->backend_sync,cfile->handle,
+    com=lives_strdup_printf("%s open_test \"%s\" %s \"%s\" 0 png",prefs->backend_sync,cfile->handle,prefs->video_open_command,
                             (tmp=lives_filename_from_utf8(rname,-1,NULL,NULL,NULL)));
     lives_free(tmp);
     lives_free(rname);
@@ -829,7 +854,9 @@ boolean do_startup_tests(boolean tshoot) {
       get_frame_count(mainw->current_file);
 
       if (cfile->frames==0) {
-        fail_test(table,4,_("You may wish to upgrade mplayer to a newer version"));
+        msg=lives_strdup_printf(_("You may wish to upgrade %s to a newer version"),mp_cmd);
+        fail_test(table,4,msg);
+        lives_free(msg);
       }
 
       else {
@@ -841,7 +868,7 @@ boolean do_startup_tests(boolean tshoot) {
 
   if (mainw->cancelled!=CANCEL_NONE) {
     mainw->cancelled=CANCEL_NONE;
-    close_current_file(current_file);
+    close_file(current_file,tshoot);
     lives_widget_destroy(dialog);
     mainw->suppress_dprint=FALSE;
 
@@ -855,46 +882,51 @@ boolean do_startup_tests(boolean tshoot) {
 
   // check if mplayer can decode to jpeg
 
-  add_test(table,5,_("Checking if mplayer can decode to jpeg"),success2);
+  msg=lives_strdup_printf(_("Checking if %s can decode to jpeg"),mp_cmd);
+  add_test(table,5,msg,success2);
+  lives_free(msg);
 
   res=1;
 
-  if (success2) {
-    if (capable->has_mplayer) {
-#ifndef IS_MINGW
-      res=system("LANG=en LANGUAGE=en mplayer -vo help | grep -i \"jpeg file\" >/dev/null 2>&1");
-#else
-      res=system("mplayer -vo help | grep -i \"jpeg file\" >NUL 2>&1");
-#endif
-    } else if (capable->has_mplayer2) {
-#ifndef IS_MINGW
-      res=system("LANG=en LANGUAGE=en mplayer2 -vo help | grep -i \"jpeg file\" >/dev/null 2>&1");
-#else
-      res=system("mplayer2 -vo help | grep -i \"jpeg file\" >NUL 2>&1");
-#endif
-    } else {
-#ifdef ALLOW_MPV
-#ifndef IS_MINGW
-      res=system("LANG=en LANGUAGE=en mpv --vo help | grep -i \"image\" >/dev/null 2>&1");
-#else
-      res=system("mpv --vo help | grep -i \"image\" >NUL 2>&1");
-#endif
-#endif
-    }
+  if (!strcmp(mp_cmd,"mpv")) lookfor="image";
+  else lookfor="jpeg file";
 
-    if (res==0) {
-      pass_test(table,5);
-      if (!success3) {
-        if (!strcmp(prefs->image_ext,LIVES_FILE_EXT_PNG)) imgext_switched=TRUE;
-        set_pref("default_image_format","jpeg");
-        lives_snprintf(prefs->image_ext,16,"%s",LIVES_FILE_EXT_JPG);
-      }
+  if (success2) {
+#ifndef IS_MINGW
+    com=lives_strdup_printf("LANG=en LANGUAGE=en %s -vo help | grep -i \"%s\" >/dev/null 2>&1",prefs->video_open_command,lookfor);
+    res=lives_system(com,TRUE);
+    lives_free(com);
+#else
+    com=lives_strdup_printf("%s -vo help | grep -i \"%s\" >NUL 2>&1",prefs->video_open_command,lookfor);
+    res=lives_system(com,TRUE);
+    lives_free(com);
+#endif
+  }
+
+  if (res==0) {
+    pass_test(table,5);
+    if (!success3) {
+      if (!strcmp(prefs->image_ext,LIVES_FILE_EXT_PNG)) imgext_switched=TRUE;
+      set_pref(PREF_DEFAULT_IMAGE_FORMAT,LIVES_IMAGE_TYPE_JPEG);
+      lives_snprintf(prefs->image_ext,16,"%s",LIVES_FILE_EXT_JPG);
+    }
+  } else {
+    if (!success3) {
+#ifdef ALLOW_PNG24
+      msg=lives_strdup_printf(_("You should install %s with either png or jpeg support"),mp_cmd);
+#else
+      msg=lives_strdup_printf(_("You should install %s with either png/alpha or jpeg support"),mp_cmd);
+#endif
+      fail_test(table,5,msg);
+      lives_free(msg);
     } else {
-      if (!success3) fail_test(table,5,_("You should install mplayer with either png/alpha or jpeg support"));
-      else fail_test(table,5,_("You may wish to add jpeg output support to mplayer"));
+      msg=lives_strdup_printf(_("You may wish to add jpeg output support to %s"),mp_cmd);
+      fail_test(table,5,msg);
+      lives_free(msg);
     }
   }
 
+
   // TODO - check each enabled decoder plugin in turn
 
 
@@ -910,9 +942,18 @@ boolean do_startup_tests(boolean tshoot) {
   }
 
 
-  close_current_file(current_file);
+  close_file(current_file,tshoot);
+  mainw->current_file=current_file;
 
   lives_widget_set_sensitive(okbutton,TRUE);
+
+  if (!capable->has_mplayer&&!capable->has_mplayer2&&capable->has_mpv) {
+    label=lives_standard_label_new(
+            _("\n\nLiVES has experimental support for 'mpv' but it is advisable to install\n"
+              "'mplayer' or 'mplayer2' in order to use all the features of LiVES"));
+    lives_container_add(LIVES_CONTAINER(dialog_vbox), label);
+  }
+
   if (tshoot) {
     lives_widget_hide(cancelbutton);
     if (imgext_switched) {
@@ -968,7 +1009,7 @@ void do_startup_interface_query(void) {
   lives_free(txt2);
   lives_free(txt3);
 
-  dialog = lives_standard_dialog_new(_("LiVES: - Choose the startup interface"),FALSE,-1,-1);
+  dialog = lives_standard_dialog_new(_("Choose the Startup Interface"),FALSE,-1,-1);
 
   dialog_vbox = lives_dialog_get_content_area(LIVES_DIALOG(dialog));
 
@@ -1000,7 +1041,6 @@ void do_startup_interface_query(void) {
 
   okbutton = lives_button_new_from_stock(LIVES_STOCK_GO_FORWARD,_("_Finish"));
 
-  lives_widget_show(okbutton);
   lives_dialog_add_action_widget(LIVES_DIALOG(dialog), okbutton, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default(okbutton);
   lives_widget_grab_default(okbutton);
@@ -1015,7 +1055,7 @@ void do_startup_interface_query(void) {
   if (lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(radiobutton1)))
     future_prefs->startup_interface=prefs->startup_interface=STARTUP_MT;
 
-  set_int_pref("startup_interface",prefs->startup_interface);
+  set_int_pref(PREF_STARTUP_INTERFACE,prefs->startup_interface);
 
   lives_widget_destroy(dialog);
 
