@@ -1,6 +1,6 @@
 // stream.c
 // LiVES
-// (c) G. Finch 2008 - 2015 <salsaman@gmail.com>
+// (c) G. Finch 2008 - 2016 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -11,6 +11,7 @@
 #include "htmsocket.h"
 #include "support.h"
 #include "interface.h"
+#include "effects-weed.h"
 
 #ifdef HAVE_SYSTEM_WEED
 #include <weed/weed.h>
@@ -32,7 +33,7 @@ static boolean has_last_delta_ticks;
 static char *hdr=NULL;
 static boolean fps_can_change;
 
-static LIVES_INLINE __attribute__((__const__)) int64_t abs64(int64_t a) {
+static LIVES_INLINE int64_t abs64(int64_t a) {
   return ((a>0)?a:-a);
 }
 
@@ -809,22 +810,22 @@ void weed_layer_set_from_lives2lives(weed_plant_t *layer, int clip, lives_vstrea
 
     width=height=0;
 
-    if (weed_plant_has_leaf(layer,"height")) height=weed_get_int_value(layer,"height",&error);
-    if (weed_plant_has_leaf(layer,"width")) width=weed_get_int_value(layer,"width",&error);
+    if (weed_plant_has_leaf(layer,WEED_LEAF_HEIGHT)) height=weed_get_int_value(layer,WEED_LEAF_HEIGHT,&error);
+    if (weed_plant_has_leaf(layer,WEED_LEAF_WIDTH)) width=weed_get_int_value(layer,WEED_LEAF_WIDTH,&error);
 
     if (lstream->hsize!=width||lstream->vsize!=height) {
       weed_layer_pixel_data_free(layer);
     }
 
-    if (!weed_plant_has_leaf(layer,"pixel_data")||weed_get_voidptr_value(layer,"pixel_data",&error)==NULL) {
-      weed_set_int_value(layer,"width",lstream->hsize);
-      weed_set_int_value(layer,"height",lstream->vsize);
-      weed_set_int_value(layer,"current_palette",lstream->palette);
-      weed_set_int_value(layer,"YUV_clamping",lstream->YUV_clamping);
+    if (!weed_plant_has_leaf(layer,WEED_LEAF_PIXEL_DATA)||weed_get_voidptr_value(layer,WEED_LEAF_PIXEL_DATA,&error)==NULL) {
+      weed_set_int_value(layer,WEED_LEAF_WIDTH,lstream->hsize);
+      weed_set_int_value(layer,WEED_LEAF_HEIGHT,lstream->vsize);
+      weed_set_int_value(layer,WEED_LEAF_CURRENT_PALETTE,lstream->palette);
+      weed_set_int_value(layer,WEED_LEAF_YUV_CLAMPING,lstream->YUV_clamping);
       create_empty_pixel_data(layer,FALSE,TRUE);
     }
 
-    pixel_data=weed_get_voidptr_array(layer,"pixel_data",&error);
+    pixel_data=weed_get_voidptr_array(layer,WEED_LEAF_PIXEL_DATA,&error);
 
     switch (lstream->palette) {
     case WEED_PALETTE_RGB24:
@@ -921,7 +922,7 @@ void weed_layer_set_from_lives2lives(weed_plant_t *layer, int clip, lives_vstrea
         target_size=((lstream->hsize*lstream->vsize*5)>>2)-framedataread;
         if (target_size>=lstream->dsize) {
           lives_stream_in_chunks(lstream,lstream->dsize,
-                                 (uint8_t *)(pixel_data[1]+framedataread-lstream->hsize*lstream->vsize),0);
+                                 ((uint8_t *)pixel_data[1]+framedataread-lstream->hsize*lstream->vsize),0);
           if (mainw->cancelled) {
             lives_free(pixel_data);
             return;
@@ -966,7 +967,7 @@ void weed_layer_set_from_lives2lives(weed_plant_t *layer, int clip, lives_vstrea
         target_size=((lstream->hsize*lstream->vsize*3)>>1)-framedataread;
         if (target_size>=lstream->dsize) target_size=lstream->dsize;
         lives_stream_in_chunks(lstream,target_size,
-                               (uint8_t *)(pixel_data[2]+framedataread-((lstream->hsize*lstream->vsize*5)>>2)),0);
+                               ((uint8_t *)pixel_data[2]+framedataread-((lstream->hsize*lstream->vsize*5)>>2)),0);
         if (mainw->cancelled) {
           lives_free(pixel_data);
           return;
@@ -1095,7 +1096,7 @@ lives_pandh_w *create_pandh_dialog(int type) {
 
   char *tmp,*tmp2;
 
-  pandhw->dialog = lives_standard_dialog_new(_("LiVES: - Receive LiVES stream"),TRUE,-1,-1);
+  pandhw->dialog = lives_standard_dialog_new(_("Receive LiVES Stream"),TRUE,-1,-1);
 
   if (prefs->show_gui) {
     lives_window_set_transient_for(LIVES_WINDOW(pandhw->dialog),LIVES_WINDOW(mainw->LiVES));
