@@ -1,6 +1,6 @@
 // widget-helper-gtk.h
 // LiVES
-// (c) G. Finch 2012 - 2015 <salsaman@gmail.com>
+// (c) G. Finch 2012 - 2016 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -15,7 +15,6 @@
 #define GTK_RADIO_MENU_BUG // a bug where gtk_radio_menu_item_set_active() does not update visually
 #define GTK_SUBMENU_SENS_BUG // a bug where setting a menuitem insensitive fails if it has a submenu
 #define GTK_TEXT_VIEW_CSS_BUG // a bug where named textviews cannot be set by CSS
-#define GTK_RENDER_BACKGROUND_BUG // a bug where bg of custom widgets is not rendered
 #define GTK_TEXT_VIEW_DRAW_BUG // a bug where textview crashes if too much text in it
 
 
@@ -111,9 +110,10 @@ typedef cairo_fill_rule_t lives_painter_fill_rule_t;
 
 #include "support.h"
 
+#if GTK_CHECK_VERSION(2,28,0)
 #define USE_MONOTONIC_TIME
 #define lives_get_monotonic_time() g_get_monotonic_time()
-
+#endif
 
 //#if GTK_CHECK_VERSION(3,8,0)
 //#define USE_GDK_FRAME_CLOCK
@@ -178,17 +178,17 @@ typedef gint(*LiVESCompareFunc)(gconstpointer a, gconstpointer b);
 
 #define LIVES_GUI_CALLBACK(f) ((LiVESGuiCallback) (f))
 
-#define lives_printerr(args...) g_printerr(args)
-#define lives_strdup_printf(args...) g_strdup_printf(args)
-#define lives_strdup_vprintf(args...) g_strdup_vprintf(args)
-#define lives_strndup_printf(args...) g_strndup_printf(args)
+#define lives_printerr(...) g_printerr(__VA_ARGS__)
+#define lives_strdup_printf(...) g_strdup_printf(__VA_ARGS__)
+#define lives_strdup_vprintf(...) g_strdup_vprintf(__VA_ARGS__)
+#define lives_strndup_printf(...) g_strndup_printf(__VA_ARGS__)
 #define lives_strndup(a,b) g_strndup(a,b)
-#define lives_snprintf(a,b,args...) g_snprintf(a,b,args)
+#define lives_snprintf(a,b,...) g_snprintf(a,b,__VA_ARGS__)
 #define lives_strsplit(a,b,c) g_strsplit(a,b,c)
 #define lives_strfreev(a) g_strfreev(a)
 #define lives_ascii_strcasecmp(a,b) g_ascii_strcasecmp(a,b)
 #define lives_ascii_strncasecmp(a,b,c) g_ascii_strncasecmp(a,b,c)
-#define lives_strconcat(a,args...) g_strconcat(a,args)
+#define lives_strconcat(a,...) g_strconcat(a,__VA_ARGS__)
 #define lives_strstrip(a) g_strstrip(a)
 #define lives_strrstr(a,b) g_strrstr(a,b)
 #define lives_strstr_len(a,b,c) g_strstr_len(a,b,c)
@@ -203,6 +203,7 @@ typedef gint(*LiVESCompareFunc)(gconstpointer a, gconstpointer b);
 #define lives_list_nth(list,i) g_list_nth(list,i)
 #define lives_list_length(list) g_list_length(list)
 #define lives_list_free(list) g_list_free(list)
+#define lives_slist_free(list) g_slist_free(list)
 #define lives_list_append(list,data) g_list_append(list,data)
 #define lives_list_prepend(list,data) g_list_prepend(list,data)
 #define lives_list_find(list,data) g_list_find(list,data)
@@ -224,7 +225,7 @@ typedef gint(*LiVESCompareFunc)(gconstpointer a, gconstpointer b);
 #define lives_slist_nth_data(list,i) g_slist_nth_data(list,i)
 #define lives_slist_append(list,data) g_slist_append(list,data)
 
-#define lives_build_filename(args...) g_build_filename(args)
+#define lives_build_filename(...) g_build_filename(__VA_ARGS__)
 #define lives_filename_to_utf8(a,b,c,d,e) g_filename_to_utf8(a,b,c,d,e)
 #define lives_filename_from_utf8(a,b,c,d,e) g_filename_from_utf8(a,b,c,d,e)
 
@@ -272,8 +273,6 @@ typedef gint(*LiVESCompareFunc)(gconstpointer a, gconstpointer b);
 #define LIVES_FILE_TEST_IS_DIR G_FILE_TEST_IS_DIR
 #define LIVES_FILE_TEST_IS_REGULAR G_FILE_TEST_IS_REGULAR
 
-#define LIVES_DIR_SEPARATOR_S G_DIR_SEPARATOR_S
-
 typedef GtkJustification LiVESJustification;
 
 #define LIVES_JUSTIFY_LEFT   GTK_JUSTIFY_LEFT
@@ -294,12 +293,17 @@ typedef GdkEventExpose                    LiVESXEventExpose;
 typedef GdkEventCrossing                  LiVESXEventCrossing;
 typedef GdkEventConfigure                 LiVESXEventConfigure;
 typedef GdkEventFocus                     LiVESXEventFocus;
+typedef GdkEventKey                       LiVESXEventKey;
 typedef GdkEvent                          LiVESXEventDelete;
 typedef GdkDisplay                        LiVESXDisplay;
 typedef GdkScreen                         LiVESXScreen;
 typedef GdkDevice                         LiVESXDevice;
 
 
+#define LIVES_KEY_RELEASE GDK_KEY_RELEASE
+#define LIVES_KEY_PRESS GDK_KEY_PRESS
+
+
 #define LIVES_SCROLL_UP   GDK_SCROLL_UP
 #define LIVES_SCROLL_DOWN GDK_SCROLL_DOWN
 
@@ -323,6 +327,11 @@ typedef GdkDeviceManager                  LiVESXDeviceManager;
 
 #define LIVES_WIDGET_OBJECT(a) G_OBJECT(a)
 
+
+#define lives_object_freeze_notify(a) g_object_freeze_notify(a)
+#define lives_object_thaw_notify(a) g_object_thaw_notify(a)
+
+
 #if GTK_CHECK_VERSION(3,0,0)
 #define NO_MEM_OVERRIDE TRUE
 #else
@@ -349,6 +358,8 @@ typedef GdkFilterReturn LiVESFilterReturn;
 #define LIVES_WIDGET_LEAVE_NOTIFY_EVENT "leave-notify-event"
 #define LIVES_WIDGET_FOCUS_OUT_EVENT "focus-out-event"
 #define LIVES_WIDGET_DELETE_EVENT "delete-event"
+#define LIVES_WIDGET_KEY_PRESS_EVENT "key-press-event"
+#define LIVES_WIDGET_KEY_RELEASE_EVENT "key-release-event"
 
 // signals
 #define LIVES_WIDGET_CLICKED_SIGNAL "clicked"
@@ -423,6 +434,7 @@ typedef GtkAboutDialog                    LiVESAboutDialog;
 
 
 // values here are long unsigned int
+#define LIVES_COL_TYPE_OBJECT G_TYPE_OBJECT
 #define LIVES_COL_TYPE_STRING G_TYPE_STRING
 #define LIVES_COL_TYPE_INT G_TYPE_INT
 #define LIVES_COL_TYPE_UINT G_TYPE_UINT
@@ -438,6 +450,9 @@ typedef GtkTreeViewColumnSizing LiVESTreeViewColumnSizing;
 #define LIVES_TREE_VIEW_COLUMN_AUTOSIZE GTK_TREE_VIEW_COLUMN_AUTOSIZE
 #define LIVES_TREE_VIEW_COLUMN_FIXED GTK_TREE_VIEW_COLUMN_FIXED
 
+#define LIVES_TREE_VIEW_COLUMN_TEXT "text"
+#define LIVES_TREE_VIEW_COLUMN_PIXBUF "pixbuf"
+
 
 typedef GtkCellRenderer                   LiVESCellRenderer;
 typedef GtkTreeModel                      LiVESTreeModel;
@@ -479,8 +494,10 @@ typedef GtkEditable                       LiVESEditable;
 #if GTK_CHECK_VERSION(3,0,0)
 #define LIVES_WIDGET_COLOR_HAS_ALPHA (1)
 #define LIVES_WIDGET_COLOR_SCALE(x) (x) ///< macro to get 0. to 1.
-#define LIVES_WIDGET_COLOR_SCALE_255(x) ((double)x/255.) ///< macro to convert from (0. - 255.) to component
-typedef GdkRGBA                           LiVESWidgetColor;
+#define LIVES_WIDGET_COLOR_STRETCH(x) (x*65535.) ///< macro to get 0. to 1.
+#define LIVES_WIDGET_COLOR_SCALE_65535(x) ((double)x/65535.) ///< macro to convert from (0. - 65535.) to widget color
+#define LIVES_WIDGET_COLOR_SCALE_255(x) ((double)x/255.) ///< macro to convert from (0. - 255.) to widget color
+typedef GdkRGBA                           LiVESWidgetColor; ///< component values are 0. to 1.
 
 typedef GtkStateFlags LiVESWidgetState;
 
@@ -495,9 +512,11 @@ typedef GtkStateFlags LiVESWidgetState;
 
 #else
 #define LIVES_WIDGET_COLOR_HAS_ALPHA (0)
-#define LIVES_WIDGET_COLOR_SCALE(x) ((double)x/65535.)     ///< macro to get 0. to 1.
-#define LIVES_WIDGET_COLOR_SCALE_255(x) ((int)((double)x*256.+.5))     ///< macro to get 0 - 255
-typedef GdkColor                          LiVESWidgetColor;
+#define LIVES_WIDGET_COLOR_SCALE(x) ((double)x/65535.)     ///< macro to get 0. to 1. from widget color
+#define LIVES_WIDGET_COLOR_STRETCH(x) (x)     ///< macro to get 0 to 65535 from widget color
+#define LIVES_WIDGET_COLOR_SCALE_65535(x) (x)     ///< macro to get 0 - 65535 to widget color
+#define LIVES_WIDGET_COLOR_SCALE_255(x) ((int)((double)x*256.+.5))     ///< macro to get 0 - 255 to widget color
+typedef GdkColor                          LiVESWidgetColor;  ///< component values are 0 to 65535
 typedef GtkStateType LiVESWidgetState;
 
 #define LIVES_WIDGET_STATE_NORMAL         GTK_STATE_NORMAL
@@ -816,6 +835,7 @@ typedef GdkInterpType                     LiVESInterpType;
 #define LIVES_IS_XWINDOW(widget) GDK_IS_WINDOW(widget)
 #define LIVES_IS_PIXBUF(widget) GDK_IS_PIXBUF(widget)
 #define LIVES_IS_CONTAINER(widget) GTK_IS_CONTAINER(widget)
+#define LIVES_IS_BIN(widget) GTK_IS_BIN(widget)
 
 #if GTK_CHECK_VERSION(3,0,0)
 #define LIVES_IS_HBOX(widget) (GTK_IS_BOX(widget)&&gtk_orientable_get_orientation(GTK_ORIENTABLE(widget))==GTK_ORIENTATION_HORIZONTAL)
@@ -832,6 +852,7 @@ typedef GdkInterpType                     LiVESInterpType;
 #define LIVES_IS_EVENT_BOX(widget) GTK_IS_EVENT_BOX(widget)
 
 #define LIVES_IS_COMBO(widget) GTK_IS_COMBO_BOX(widget)
+#define LIVES_IS_DIALOG(widget) GTK_IS_DIALOG(widget)
 #define LIVES_IS_LABEL(widget) GTK_IS_LABEL(widget)
 #define LIVES_IS_BUTTON(widget) GTK_IS_BUTTON(widget)
 #define LIVES_IS_SPIN_BUTTON(widget) GTK_IS_SPIN_BUTTON(widget)
