@@ -92,7 +92,14 @@ lives_painter_format_t lives_painter_image_surface_get_format(lives_painter_surf
 
 boolean widget_helper_init(void);
 
-boolean widget_rgba_to_lives_rgba(lives_colRGBA32_t *, LiVESWidgetColor *);
+boolean widget_color_to_lives_rgba(lives_colRGBA64_t *, LiVESWidgetColor *);
+boolean lives_rgba_to_widget_color(LiVESWidgetColor *, lives_colRGBA64_t *);
+
+void lives_painter_set_source_rgb_from_lives_rgba(lives_painter_t *cr, lives_colRGBA64_t *col);
+void lives_painter_set_source_rgb_from_lives_rgb(lives_painter_t *cr, lives_colRGB48_t *col);
+
+boolean lives_rgba_equal(lives_colRGBA64_t *col1, lives_colRGBA64_t *col2);
+void lives_rgba_copy(lives_colRGBA64_t *col1, lives_colRGBA64_t *col2);
 
 
 // object funcs.
@@ -139,13 +146,12 @@ boolean lives_pixbuf_saturate_and_pixelate(const LiVESPixbuf *src, LiVESPixbuf *
 
 // basic widget fns (TODO - amend all void to return boolean)
 
-boolean lives_mem_set_vtable(LiVESMemVTable *alt_vtable);
-
 
 #ifdef GUI_GTK
 
 #define lives_signal_connect(instance, detailed_signal, c_handler, data) g_signal_connect(instance, detailed_signal, c_handler, data)
 #define lives_signal_connect_after(instance, detailed_signal, c_handler, data) g_signal_connect_after(instance, detailed_signal, c_handler, data)
+#define lives_signal_handlers_disconnect_by_func(instance, func, data) g_signal_handlers_disconnect_by_func(instance, func, data)
 #define lives_signal_handlers_block_by_func(instance, func, data) g_signal_handlers_block_by_func(instance, func, data)
 #define lives_signal_handlers_unblock_by_func(instance, func, data) g_signal_handlers_unblock_by_func(instance, func, data)
 #else
@@ -160,6 +166,8 @@ boolean lives_signal_handler_unblock(livespointer instance, unsigned long handle
 boolean lives_signal_handler_disconnect(livespointer instance, unsigned long handler_id);
 boolean lives_signal_stop_emission_by_name(livespointer instance, const char *detailed_signal);
 
+boolean lives_grab_add(LiVESWidget *widget);
+boolean lives_grab_remove(LiVESWidget *widget);
 
 boolean lives_widget_set_sensitive(LiVESWidget *, boolean state);
 boolean lives_widget_get_sensitive(LiVESWidget *);
@@ -173,9 +181,12 @@ boolean lives_widget_queue_draw(LiVESWidget *);
 boolean lives_widget_queue_draw_area(LiVESWidget *, int x, int y, int width, int height);
 boolean lives_widget_queue_resize(LiVESWidget *);
 boolean lives_widget_set_size_request(LiVESWidget *, int width, int height);
-
+boolean lives_widget_set_minimum_size(LiVESWidget *widget, int width, int height);
+boolean lives_widget_set_maximum_size(LiVESWidget *widget, int width, int height);
 boolean lives_widget_reparent(LiVESWidget *, LiVESWidget *new_parent);
 
+boolean lives_widget_is_ancestor(LiVESWidget *widget, LiVESWidget *ancestor);
+
 boolean lives_widget_set_app_paintable(LiVESWidget *widget, boolean paintable);
 
 LiVESWidget *lives_event_box_new(void);
@@ -188,6 +199,8 @@ const char *lives_label_get_text(LiVESLabel *);
 boolean lives_label_set_text(LiVESLabel *, const char *text);
 boolean lives_label_set_text_with_mnemonic(LiVESLabel *, const char *text);
 
+boolean lives_label_set_xalign(LiVESLabel *, double align);
+
 boolean lives_label_set_markup(LiVESLabel *, const char *markup);
 boolean lives_label_set_markup_with_mnemonic(LiVESLabel *, const char *markup);
 
@@ -230,6 +243,7 @@ boolean lives_widget_get_bg_state_color(LiVESWidget *, LiVESWidgetState state, L
 boolean lives_color_parse(const char *spec, LiVESWidgetColor *);
 
 LiVESWidgetColor *lives_widget_color_copy(LiVESWidgetColor *c1orNULL, const LiVESWidgetColor *c2);
+boolean lives_widget_color_equal(LiVESWidgetColor *, const LiVESWidgetColor *);
 
 LiVESWidget *lives_event_box_new(void);
 
@@ -584,6 +598,7 @@ boolean lives_grid_remove_row(LiVESGrid *, int posn);
 
 LiVESWidget *lives_frame_new(const char *label);
 boolean lives_frame_set_label(LiVESFrame *, const char *label);
+boolean lives_frame_set_label_align(LiVESFrame *, float xalign, float yalign);
 boolean lives_frame_set_label_widget(LiVESFrame *, LiVESWidget *);
 LiVESWidget *lives_frame_get_label_widget(LiVESFrame *);
 boolean lives_frame_set_shadow_type(LiVESFrame *, LiVESShadowType);
@@ -714,6 +729,8 @@ boolean lives_window_set_auto_startup_notification(boolean set);
 LiVESWidget *lives_standard_label_new(const char *text);
 LiVESWidget *lives_standard_label_new_with_mnemonic(const char *text, LiVESWidget *mnemonic_widget);
 
+LiVESWidget *lives_standard_frame_new(const char *labeltext, float xalign, boolean invisible_outline);
+
 LiVESWidget *lives_standard_check_button_new(const char *labeltext, boolean use_mnemonic, LiVESBox *box, const char *tooltip);
 LiVESWidget *lives_standard_radio_button_new(const char *labeltext, boolean use_mnemonic, LiVESSList *rbgroup,
     LiVESBox *, const char *tooltip);
@@ -738,12 +755,21 @@ LiVESWidget *lives_volume_button_new(LiVESOrientation orientation, LiVESAdjustme
 
 LiVESWidget *lives_standard_file_button_new(boolean is_dir, const char *def_dir);
 
+LiVESWidget *lives_standard_color_button_new(LiVESBox *parent, char *name, boolean use_mnemonic, boolean use_alpha, lives_colRGBA64_t *rgba,
+    LiVESWidget **sb_red, LiVESWidget **sb_green, LiVESWidget **sb_blue, LiVESWidget **sb_alpha);
+
+LiVESWidget *lives_standard_text_view_new(const char *text, LiVESTextBuffer *tbuff);
+
+
 LiVESXCursor *lives_cursor_new_from_pixbuf(LiVESXDisplay *, LiVESPixbuf *, int x, int y);
 
 // util functions
 
 void lives_widget_apply_theme(LiVESWidget *, LiVESWidgetState state); // normal theme colours
-void lives_widget_apply_theme2(LiVESWidget *, LiVESWidgetState state); // menu and bars colours (bg only...)
+void lives_widget_apply_theme2(LiVESWidget *, LiVESWidgetState state, boolean set_fg); // menu and bars colours
+void lives_widget_apply_theme3(LiVESWidget *, LiVESWidgetState state); // info base/text
+
+boolean global_recent_manager_add(const char *file_name);
 
 void lives_cursor_unref(LiVESXCursor *cursor);
 
@@ -787,8 +813,9 @@ boolean widget_act_toggle(LiVESWidget *, LiVESToggleButton *);
 
 void toggle_button_toggle(LiVESToggleButton *);
 
-// must retain this fn prototype as a callback
-void set_child_colour(LiVESWidget *widget, livespointer set_all);
+
+void set_child_colour(LiVESWidget *widget, boolean set_all);
+void set_child_alt_colour(LiVESWidget *widget, boolean set_all);
 
 void funkify_dialog(LiVESWidget *dialog);
 
@@ -851,6 +878,8 @@ typedef struct {
   LiVESWidget *last_label; // label widget of last standard widget (spin,radio,check,entry,combo) [readonly]
   LiVESJustification justify; // justify for labels
   LiVESJustification default_justify;
+  char **image_filter; /// NULL or NULL terminated list of image extensions which can be loaded
+  char *title_prefix; // Text which is prepended to window titles, etc.
 } widget_opts_t;
 
 
@@ -873,7 +902,9 @@ const widget_opts_t def_widget_opts = {
   8, // def fill width (in chars)
   NULL, // last_label
   LIVES_JUSTIFY_LEFT, // justify
-  LIVES_JUSTIFY_LEFT // default justify
+  LIVES_JUSTIFY_LEFT, // default justify
+  NULL, // image_filter
+  "" // title_prefix
 };
 
 #else
